@@ -17,7 +17,7 @@
 #include <floatingpoint.h>
 #endif
 
-void readOneLine();
+#include "util.h" 
 
 #ifdef WIN32 
 extern void SciEnv(void);
@@ -39,9 +39,7 @@ char * UsageStr[]={
 
 char entete[160];
 
-void WriteTeX(filename,wide,height)
-     double wide,height;
-     char filename[];
+void WriteTeX(char *filename, double wide, double height)
 {
   char filename1[255];
   FILE *fdo;
@@ -85,18 +83,28 @@ void WriteTeX(filename,wide,height)
  file et en ecrivant sur fdo
 -------------------------------------------------------*/
 
-void Sed(file,strin1,strout1,strin2,strout2,strin3,strout3,fdo)
-     FILE *fdo;
-     char file[],strin1[],strout1[],strout3[];
-     char strin2[],strout2[],strin3[];
+void Sed(char *file, char *strin1, char *strout1, char *strin2, char *strout2, char *strin3, char *strout3, FILE *fdo)
 {
   FILE *fd;
+
+  static char *buff = NULL;
+  static int buflen = 512;
+  if ( buff == NULL) 
+    {
+      buff = malloc(buflen*sizeof(char));
+      if ( buff == NULL) 
+	{
+	  fprintf(stderr,"Running out of space \n");
+	  exit(1);
+	}
+    }
+
   fd=fopen(file,"r");
   if (fd != 0)
     { int stop=0;
       while ( stop != 1)
-	{  char buff[512];
-	   readOneLine (buff,&stop,fd); 
+	{  
+	   read_one_line (&buff,&stop,fd,&buflen); 
 	   if (strncmp(buff,strin1,strlen(strin1))==0)
 	     fprintf(fdo,"%s\n",strout1);
 	   else
@@ -121,19 +129,7 @@ void Sed(file,strin1,strout1,strin2,strout2,strin3,strout3,fdo)
     }
 }
 
-/*-----------------------------------------------
-  lit une ligne dans fd et la stocke dans buff
----------------------------------------------------*/
 
-void readOneLine(buff,stop,fd)
-     char buff[];
-     int *stop;
-     FILE *fd;
-{ int i ,c ;
-  for ( i = 0 ;  (c =getc(fd)) !=  '\n' && c != EOF ; i++) buff[i]= c ;
-  buff[i]='\n';buff[i+1]='\0';
-  if ( c == EOF) {*stop = 1;}
-}
 
 /*-----------------------------------------------
   calcule la taille pour un dessin suivant le nombre de dessin a 
@@ -144,9 +140,7 @@ void readOneLine(buff,stop,fd)
   (*wt et *ht sont la hauteur totale et la argeur totale)
 -----------------------------------------------------*/
 
-void ComputeSize(num,i,x,y,w,h,wt,ht)
-     int num,i;
-     double *x,*y,*w,*h,*wt,*ht;
+void ComputeSize(int num, int i, double *x, double *y, double *w, double *h, double *wt, double *ht)
 {
   switch (num)
     {
@@ -160,9 +154,7 @@ void ComputeSize(num,i,x,y,w,h,wt,ht)
 
 
 
-int main(argc, argv)
-     int argc;
-     char *argv[];
+int main(int argc, char **argv)
 {
   char *env;
   char filename1[255];
