@@ -27,7 +27,7 @@ extern void    /* 15  */ C2F(metane)();
 extern void    /* 16  */ C2F(polelm)();
 extern void    /* 17  */ C2F(lstelm)();
 extern void    /* 18  */ C2F(sigelm)();
-extern void    /* 19  */ C2F(datatf)();
+extern void    /* 19  */ C2F(intinterp)();
 extern void    /* 20  */ C2F(polaut)();
 extern void    /* 21  */ C2F(strelm)();
 extern void    /* 22  */ C2F(fmlelm)();
@@ -47,6 +47,7 @@ extern void    /* 35  */ C2F(coselm)();
 extern void    /* 36  */ C2F(specfun)();
 extern void    /* 37  */ C2F(dcd)();
 extern void    /* 38  */ C2F(randlib)();
+extern void    /* 39  */ C2F(otherspfunlib)();
 
 #ifdef WITH_TK
 extern void    /* 40  */ C2F(tksciInterf)();
@@ -64,7 +65,9 @@ extern void    /* 42  */ C2F(intpvm)();
 extern void    /* 43  */ C2F(intelm)();
 extern void    /* 44  */ C2F(intlapack)();
 extern void    /* 45  */ C2F(intslicot)();
-
+extern void    /* 46  */ C2F(intarpack)();
+extern void    /* 47  */ C2F(intcscicos)();
+extern void    /* 47  */ C2F(intcscicos)();
 static OpTab Interfaces[] ={
             /* 01  */ {C2F(matlu)},
 	    /* 02  */ {C2F(matdsr)},
@@ -84,7 +87,7 @@ static OpTab Interfaces[] ={
 	    /* 16  */ {C2F(polelm)},
 	    /* 17  */ {C2F(lstelm)},
 	    /* 18  */ {C2F(sigelm)},
-	    /* 19  */ {C2F(datatf)},
+	    /* 19  */ {C2F(intinterp)},
 	    /* 20  */ {C2F(polaut)},
 	    /* 21  */ {C2F(strelm)},
 	    /* 22  */ {C2F(fmlelm)},
@@ -104,11 +107,13 @@ static OpTab Interfaces[] ={
 	    /* 36  */ {C2F(specfun)},
 	    /* 37  */ {C2F(dcd)},
      	    /* 38  */ {C2F(randlib)},
-     	    /* 39  */ {C2F(matus2)}, /* free position may be used */
+     	    /* 39  */ {C2F(otherspfunlib)},
      	    /* 40  */ {TKINTERF},
 	    /* 41  */ {C2F(lstelmi)},
 	    /* 42  */ {PVMINTERF},
             /* 43  */ {C2F(intelm)},
             /* 44  */ {C2F(intlapack)},
-            /* 44  */ {C2F(intslicot)},
+            /* 45  */ {C2F(intslicot)},
+            /* 46  */ {C2F(intarpack)},
+	    /* 47  */ {C2F(intcscicos)},
 };
