@@ -46,6 +46,10 @@
 #include <varargs.h>
 #endif 
 
+#ifdef WIN32
+	#include <stdlib.h> /*pour exit()*/
+#endif
+
 #include "../calelm/calelm.h"
 static char *the_current_mex_name;
 
@@ -61,6 +65,7 @@ extern int  C2F(hmcreate)  __PARAMS((int *lw,int *nz,int *sz,int *typv,int *ifla
 extern int  C2F(stcreate)  __PARAMS((int *lw1,int *ndim,int *dims, int *nfields, char **field_names, int *retval));
 extern double C2F(dlamch)  __PARAMS((char *CMACH, unsigned long int));
 extern int arr2num __PARAMS(( mxArray  *ptr ));
+extern int arr2numcst __PARAMS((const mxArray  *ptr ));
 
 extern int C2F(changetoref) __PARAMS((int number, int pointed));
 
@@ -284,7 +289,7 @@ mxClassID mxGetClassID(const mxArray *ptr)
       case 12:
 	return  mxUINT16_CLASS;
       case 14:
-	return  mxUINT16_CLASS;
+	return  mxUINT32_CLASS;
       default:
 	return mxUNKNOWN_CLASS;
       }
@@ -297,32 +302,32 @@ mxClassID mxGetClassID(const mxArray *ptr)
 }
 
 
-bool mxIsInt8(mxArray *ptr)
+bool mxIsInt8(const mxArray *ptr)
 {
   return mxGetClassID(ptr)==mxINT8_CLASS;
 }
 
-bool mxIsInt16(mxArray *ptr)
+bool mxIsInt16(const mxArray *ptr)
 {
   return mxGetClassID(ptr)==mxINT16_CLASS;
 }
 
-bool mxIsInt32(mxArray *ptr)
+bool mxIsInt32(const mxArray *ptr)
 {
   return mxGetClassID(ptr)==mxINT32_CLASS;
 }
 
-bool mxIsUint8(mxArray *ptr)
+bool mxIsUint8(const mxArray *ptr)
 {
   return mxGetClassID(ptr)==mxUINT8_CLASS;
 }
 
-bool mxIsUint16(mxArray *ptr)
+bool mxIsUint16(const mxArray *ptr)
 {
   return mxGetClassID(ptr)==mxUINT16_CLASS;
 }
 
-bool mxIsUint32(mxArray *ptr)
+bool mxIsUint32(const mxArray *ptr)
 {
   return mxGetClassID(ptr)==mxUINT32_CLASS;
 }
@@ -350,28 +355,28 @@ y=x/x;
   return y;
 }
 
-int mxIsInf(double x)
+bool mxIsInf(double x)
 {
   if (x == x+1)
     return 1;
   else return 0;
 }
 
-int mxIsFinite(double x)
+bool mxIsFinite(double x)
 {
   if (x < x+1)
     return 1;
   else return 0;
 }
 
-int mxIsNaN(double x)
+bool mxIsNaN(double x)
 {
   if ( x != x ) 
     return 1;
   else return 0;
 }
 
-int *RawHeader(mxArray *ptr)
+int *RawHeader(const mxArray *ptr)
 {
   /* Utility function : return an integer pointer to   *
    * a Scilab variable. The variable can be            *
@@ -380,7 +385,7 @@ int *RawHeader(mxArray *ptr)
   return header;
 }
 
-int Is1x1(mxArray *ptr)
+int Is1x1(const mxArray *ptr)
 {
   int proddims,k;
   int *header = RawHeader(ptr);
@@ -409,16 +414,22 @@ mxArray *mxCreateData(int m)
 }
 
 
-int mxGetNumberOfElements(mxArray *ptr)
+int mxGetNumberOfElements(const mxArray *ptr)
 {
-  int m, commonlength;
+  int m, commonlength, k, proddims;
+  int *headerdims;
   int *header=Header(ptr);
   switch (header[0]) {
   case DOUBLEMATRIX: case INTMATRIX:
     return header[1]*header[2];
   case MLIST:   /* TO BE DONE */
-    return header[6+2*(header[4]-1)+1];
-    /* debut=listentry(header,3); (debut)... */
+  headerdims = listentry(header,2);
+  proddims=1;
+  for (k=0; k<headerdims[1]*headerdims[2]; k++) {
+    proddims=proddims*headerdims[4+k];
+  }
+  return proddims;
+  /*  return header[6+2*(header[4]-1)+1];  */
   case STRINGMATRIX:
     m=header[1];
     commonlength=header[5]-header[4];
@@ -430,7 +441,7 @@ int mxGetNumberOfElements(mxArray *ptr)
 }
 
 
-double *mxGetPr(mxArray *ptr)
+double *mxGetPr(const mxArray *ptr)
 {
   double *value;
   int *header = Header(ptr);
@@ -460,7 +471,7 @@ double *mxGetPr(mxArray *ptr)
 
 
 
-double *mxGetPi(mxArray *ptr)
+double *mxGetPi(const mxArray *ptr)
 { 
   int debut; int m,n,it;
   /*  double *value = (double *) stkptr((long int)ptr); */
@@ -477,6 +488,7 @@ double *mxGetPi(mxArray *ptr)
     case DOUBLEMATRIX: case INTMATRIX:
       m=header[debut+1];n=header[debut+2];
       it=header[debut+3];  /* it should be 1 */
+      if (it==0) return NULL;
       return (double *) &header[debut+4+2*m*n];
     default:
       return 0;
@@ -489,7 +501,7 @@ double *mxGetPi(mxArray *ptr)
  }
 }
 
-int mxGetNumberOfDimensions(mxArray *ptr)
+int mxGetNumberOfDimensions(const mxArray *ptr)
 {
   int *header1;
   int *header = Header(ptr);
@@ -511,7 +523,7 @@ int mxGetNumberOfDimensions(mxArray *ptr)
   }
 }
 
-int *mxGetDimensions(mxArray *ptr)
+int *mxGetDimensions(const mxArray *ptr)
 {
   int *header1;
   int *header = Header(ptr);
@@ -534,7 +546,7 @@ int *mxGetDimensions(mxArray *ptr)
   return 0;
 }
 
-int mxGetM(mxArray *ptr)
+int mxGetM(const mxArray *ptr)
 {
   int *header1;
   int *header = Header(ptr);
@@ -576,7 +588,7 @@ void mxSetM(mxArray *ptr, int M)
     break;
   case DOUBLEMATRIX: case INTMATRIX: 
     /* make ptr a reference */
-    size=2+M*header[2];  /*  oldN=header[2] */
+    size=2+M*header[2]*(header[3]+1);  /*  oldN=header[2] */
     mxNew = mxCreateData(size);   /* performs Nbvars++ */
     headernew = (int *) stkptr((long int) mxNew);
     headernew[0]=header[0];
@@ -584,7 +596,7 @@ void mxSetM(mxArray *ptr, int M)
     headernew[2]=header[2];
     headernew[3]=header[3];
     valueold = (double *) &header[4]; valuenew = (double *) &headernew[4];
-    memcpy(valuenew, valueold, M*header[2]*sizeof(double));
+    memcpy(valuenew, valueold, M*header[2]*(header[3]+1)*sizeof(double));
     ChangeToRef(arr2num(ptr),Nbvars);
     break;
   default:
@@ -593,7 +605,7 @@ void mxSetM(mxArray *ptr, int M)
 }
 
 
-int *mxGetJc(mxArray *ptr)
+int *mxGetJc(const mxArray *ptr)
 {
   int *header = Header(ptr);
   if (header[0] != SPARSEMATRIX) {
@@ -603,7 +615,7 @@ int *mxGetJc(mxArray *ptr)
   return &header[5];
 }
 
-int *mxGetIr(mxArray *ptr)
+int *mxGetIr(const mxArray *ptr)
 {
   int *header = Header(ptr);
   /* ... N=header[2],  nzmax=header[4]; then Jc,  then Ir   */
@@ -658,7 +670,7 @@ void mxSetNzmax(mxArray *array_ptr, int nzmax)
   ChangeToRef(arr2num(array_ptr),Nbvars);
 }
 
-int mxGetN(mxArray *ptr)
+int mxGetN(const mxArray *ptr)
 {
   int ret;int j;
   int *header1;
@@ -708,7 +720,7 @@ void mxSetN(mxArray *ptr, int N)
     break;
   case DOUBLEMATRIX: case INTMATRIX: 
     /* make ptr a reference */
-    size=2+header[1]*N;  /*  oldM=header[1] */
+    size=2+header[1]*N*(header[3]+1);  /*  oldM=header[1] */
     mxNew = mxCreateData(size);
     headernew = (int *) stkptr((long int) mxNew);
     headernew[0]=header[0];
@@ -717,7 +729,7 @@ void mxSetN(mxArray *ptr, int N)
     headernew[3]=header[3];
     new = Nbvars;
     valueold = (double *) &header[4]; valuenew = (double *) &headernew[4];
-    memcpy(valuenew, valueold, header[1]*N*sizeof(double));
+    memcpy(valuenew, valueold, header[1]*N*(header[3]+1)*sizeof(double));
     ChangeToRef(arr2num(ptr),new);
     break;
   case SPARSEMATRIX:
@@ -729,7 +741,7 @@ void mxSetN(mxArray *ptr, int N)
 }
 
 
-int mxIsString(mxArray *ptr)
+bool mxIsString(const mxArray *ptr)
 {
   int *header = Header(ptr);
   if (header[0] == STRINGMATRIX) 
@@ -737,7 +749,7 @@ int mxIsString(mxArray *ptr)
   else return 0;
 } 
 
-int mxIsChar(mxArray *ptr)
+bool mxIsChar(const mxArray *ptr)
 {
   int *header = Header(ptr);
   switch (header[0]) {
@@ -755,7 +767,7 @@ int mxIsChar(mxArray *ptr)
   } 
 }
 
-int mxIsNumeric(mxArray *ptr)
+bool mxIsNumeric(const mxArray *ptr)
 {
   int *header = Header(ptr);
   if (header[0] != STRINGMATRIX)
@@ -764,7 +776,7 @@ int mxIsNumeric(mxArray *ptr)
     return 0;
 }
 
-int mxIsDouble(mxArray *ptr)
+bool mxIsDouble(const mxArray *ptr)
 {
   int *header = Header(ptr);
   if ((header[0] == DOUBLEMATRIX) | (header[0] == SPARSEMATRIX) | ( (header[0] == MLIST) && (header[6+2*(header[4]-1)] == DOUBLEMATRIX)))
@@ -773,16 +785,21 @@ int mxIsDouble(mxArray *ptr)
     return 0;
 }
 
-int mxIsEmpty(mxArray *ptr)
+bool mxIsSingle(const mxArray *ptr)
 {
-  int *header = Header(ptr);
-  if ( (header[0] == DOUBLEMATRIX) | (header[0] == SPARSEMATRIX) ) 
-    return 1-header[1]*header[2];
-  else 
-    return 0;
+  mexPrintf("Routine mxIsSingle not implemented \r\n");
+  exit(1);  /* TO BE DONE */
+  return 0;
 }
 
-int mxIsFull(mxArray *ptr)
+bool mxIsEmpty(const mxArray *ptr)
+{
+  int *header = Header(ptr);
+  if (header[1]*header[2]==0) return 1;
+  return 0;
+}
+
+bool mxIsFull(const mxArray *ptr)
 {
   int *header = Header(ptr);
   if ( header[0] != SPARSEMATRIX)
@@ -791,7 +808,7 @@ int mxIsFull(mxArray *ptr)
     return 0;
 }
 
-int mxIsSparse(mxArray *ptr)
+bool mxIsSparse(const mxArray *ptr)
 {
   int *header = Header(ptr);
   if (header[0] == SPARSEMATRIX) 
@@ -800,7 +817,7 @@ int mxIsSparse(mxArray *ptr)
     return 0;
 }
 
-int mxIsLogical(mxArray *ptr)
+bool mxIsLogical(const mxArray *ptr)
 {
   int *header = Header(ptr);
   /*     TO BE DONE ND Array */
@@ -824,7 +841,7 @@ void mxClearLogical(mxArray *ptr)
   header[0] = DOUBLEMATRIX;
 }
 
-int mxIsComplex(mxArray *ptr)
+bool mxIsComplex(const mxArray *ptr)
 {
   int *header = Header(ptr);
   switch (header[0]) {
@@ -839,7 +856,7 @@ int mxIsComplex(mxArray *ptr)
   }
 }
 
-double mxGetScalar(mxArray *ptr)
+double mxGetScalar(const mxArray *ptr)
 { 
   double *value;
   int *header = Header(ptr);
@@ -856,12 +873,12 @@ double mxGetScalar(mxArray *ptr)
   }
 }
 
-void *mxGetData(mxArray *ptr)
+void *mxGetData(const mxArray *ptr)
 {
   return mxGetPr(ptr);
 }
 
-void *mxGetImagData(mxArray *ptr)
+void *mxGetImagData(const mxArray *ptr)
 {
   return mxGetPi(ptr);
 }
@@ -877,12 +894,12 @@ void mxAssert(int expr, char *error_message)
   if (!expr) mexErrMsgTxt(error_message);
 }
 
-mxArray *mxCreateDoubleMatrix(int m, int n, int it)
+mxArray *mxCreateDoubleMatrix(int m, int n, mxComplexity it)
 {
   static int lw, lr, lc;
   int k;
   lw = Nbvars + 1;
-  if (! C2F(createcvar)(&lw, "d", &it, &m, &n, &lr, &lc, 1L)) {
+  if (! C2F(createcvar)(&lw, "d", (int *) &it, &m, &n, &lr, &lc, 1L)) {
     mexErrMsgTxt("No more memory available: increase stacksize");
   }
   for ( k=0; k<m*n*(it+1); k++ ) {
@@ -899,7 +916,7 @@ mxArray *mxCreateDoubleScalar(double value)
   return (mxArray *) pa;
 }
 
-int mxIsClass(mxArray *ptr, char *name)
+bool mxIsClass(const mxArray *ptr, const char *name)
 {
   int *header = Header(ptr);
   switch (header[0]) {
@@ -928,14 +945,14 @@ int mxIsClass(mxArray *ptr, char *name)
   return 0;
 }
 
-mxArray *mxCreateStructArray(int ndim, int *dims, int nfields, char **field_names)
+mxArray *mxCreateStructArray(int ndim, const int *dims, int nfields, const char **field_names)
 {
   static int lw,lw1;
   int retval;
   Nbvars++;
   lw = Nbvars;
   lw1 = lw + Top - Rhs;
-  C2F(stcreate)(&lw1, &ndim, dims, &nfields, field_names, &retval);
+  C2F(stcreate)(&lw1, &ndim, (int *) dims, &nfields, (char **) field_names, &retval);
   if( !retval) {
     return (mxArray *) 0;
   }
@@ -943,7 +960,7 @@ mxArray *mxCreateStructArray(int ndim, int *dims, int nfields, char **field_name
   return (mxArray *) C2F(vstk).Lstk[lw + Top - Rhs - 1 ];
 }
 
-mxArray *mxCreateStructMatrix(int m, int n, int nfields, char **field_names)
+mxArray *mxCreateStructMatrix(int m, int n, int nfields, const char **field_names)
 {
   static int lw,lw1;
   int ndim; 
@@ -955,7 +972,7 @@ mxArray *mxCreateStructMatrix(int m, int n, int nfields, char **field_names)
   Nbvars++;
   lw = Nbvars;
   lw1 = lw + Top - Rhs;
-  C2F(stcreate)(&lw1, (ndim=2, &ndim), dims, &nfields, field_names, &retval);
+  C2F(stcreate)(&lw1, (ndim=2, &ndim), dims, &nfields, (char **) field_names, &retval);
   if( !retval) {
     return (mxArray *) 0;
   }
@@ -965,10 +982,18 @@ mxArray *mxCreateStructMatrix(int m, int n, int nfields, char **field_names)
 
 void mxSetFieldByNumber(mxArray *array_ptr, int index, int field_number, mxArray *value)
 {
-  int pointed, point_ed;
+  int pointed, point_ed;int proddims,k;int is1x1;
   int *headerobj; int *headervalue;
   int *header = Header(array_ptr);
-  if (Is1x1(array_ptr)) {
+  int *headerdims = listentry(header,2);
+
+  proddims=1;
+  for (k=0; k<headerdims[1]*headerdims[2]; k++) {
+    proddims=proddims*headerdims[4+k];
+  }
+  is1x1= (int) proddims==1;
+
+  if (is1x1) {
     headerobj = listentry( header, field_number+3);}
   else {
     headerobj = listentry( listentry(header, field_number+3)  ,index+1);}
@@ -991,14 +1016,14 @@ void mxSetFieldByNumber(mxArray *array_ptr, int index, int field_number, mxArray
     }
 }
 
-void mxSetField(mxArray *array_ptr, int index, char *field_name, mxArray *value)
+void mxSetField(mxArray *array_ptr, int index, const char *field_name, mxArray *value)
 {
   int field_num;
   field_num = mxGetFieldNumber(array_ptr, field_name);
   mxSetFieldByNumber(array_ptr, index, field_num, value);
 }
 
-char *mxGetFieldNameByNumber(mxArray *array_ptr, int field_number)
+const char *mxGetFieldNameByNumber(const mxArray *array_ptr, int field_number)
 {
   int k, longueur, istart, nf, job;
   int *headerstr;
@@ -1030,29 +1055,69 @@ int IsReference(mxArray *array_ptr)
     return 0;
 }
 
-mxArray *mxCreateNumericArray(int ndim, int *dims, int CLASS, int cmplx)
+mxArray *mxCreateNumericArray(int ndim, const int *dims, mxClassID CLASS, mxComplexity cmplx)
 {
   static int lw,lw1;
   int retval;
+  if (ndim < 3) return mxCreateNumericMatrix(dims[0],dims[1], CLASS, cmplx);
   Nbvars++;
   lw = Nbvars;
   lw1 = lw + Top - Rhs;
-  C2F(hmcreate)(&lw1, &ndim, dims, &CLASS, &cmplx,&retval);
+  C2F(hmcreate)(&lw1, &ndim, (int *) dims, (int *) &CLASS, (int *) &cmplx,&retval);
   if( !retval) {
     return (mxArray *) 0;
   }
   C2F(intersci).ntypes[lw-1]=AsIs;
-  return (mxArray *) C2F(vstk).Lstk[lw + Top - Rhs - 1 ];  /* C2F(intersci).iwhere[lw-1])  */
+  return (mxArray *) C2F(vstk).Lstk[lw + Top - Rhs - 1 ]; 
 }
 
-mxArray *mxCreateCharArray(int ndim, int *dims)
+mxArray *mxCreateNumericMatrix(int m, int n, mxClassID CLASS, int cmplx)
+{
+  static int lw,lw1;
+  int it;int lr;
+  switch (CLASS) {
+  case mxDOUBLE_CLASS:
+    return mxCreateDoubleMatrix(m, n, cmplx);
+  case mxINT8_CLASS:
+    Nbvars++;lw = Nbvars;  lw1 = lw + Top - Rhs;
+    if (! C2F(creimat)("  ", &lw1, (it=1, &it), &m, &n, &lr, 4L)) return (mxArray *) 0;
+    break;
+  case mxINT16_CLASS:
+    Nbvars++;lw = Nbvars;  lw1 = lw + Top - Rhs;
+    if (! C2F(creimat)("  ", &lw1, (it=2, &it), &m, &n, &lr, 4L)) return (mxArray *) 0;
+    break;
+  case mxINT32_CLASS:
+    Nbvars++;lw = Nbvars;  lw1 = lw + Top - Rhs;
+    if (! C2F(creimat)("  ", &lw1, (it=4, &it), &m, &n, &lr, 4L)) return (mxArray *) 0;
+    break;
+  case mxUINT8_CLASS:
+    Nbvars++;lw = Nbvars;  lw1 = lw + Top - Rhs;
+    if (! C2F(creimat)("  ", &lw1, (it=11, &it), &m, &n, &lr, 4L)) return (mxArray *) 0;
+    break;
+  case mxUINT16_CLASS:
+    Nbvars++;lw = Nbvars;  lw1 = lw + Top - Rhs;
+    if (! C2F(creimat)("  ", &lw1, (it=12, &it), &m, &n, &lr, 4L)) return (mxArray *) 0;
+    break;
+  case mxUINT32_CLASS:
+    Nbvars++;lw = Nbvars;  lw1 = lw + Top - Rhs;
+    if (! C2F(creimat)("  ", &lw1, (it=14, &it), &m, &n, &lr, 4L)) return (mxArray *) 0;
+    break;
+  default:
+    return (mxArray *) 0;  
+  }
+  C2F(intersci).ntypes[lw-1]=AsIs;
+  return (mxArray *) C2F(vstk).Lstk[lw + Top - Rhs - 1 ];
+}
+
+
+mxArray *mxCreateCharArray(int ndim, const int *dims)
 {
   static int lw,lw1, CLASS, cmplx;
   int retval;
   Nbvars++;
   lw = Nbvars;
   lw1 = lw + Top - Rhs;
-  C2F(hmcreate)(&lw1, &ndim, dims, (CLASS=11, &CLASS),(cmplx=0, &cmplx),&retval);
+  C2F(hmcreate)(&lw1, &ndim, (int *) dims, (CLASS=11, &CLASS),(cmplx=0, &cmplx),&retval);
   if( !retval) {
     return (mxArray *) 0;
   }
@@ -1060,18 +1125,20 @@ mxArray *mxCreateCharArray(int ndim, int *dims)
   return (mxArray *) C2F(vstk).Lstk[lw+ Top - Rhs - 1];  /* C2F(intersci).iwhere[lw-1])  */
 }
 
-mxArray *mxCreateCellArray(int ndim, int *dims)
+mxArray *mxCreateCellArray(int ndim, const int *dims)
 {
   static int lw,lw1;
-  int retval;
+  int retval;int *header;
   int nfields;char *field_names[] = {"entries"};
   Nbvars++;
   lw = Nbvars;
   lw1 = lw + Top - Rhs;
-  C2F(stcreate)(&lw1, &ndim, dims, (nfields=1,&nfields), field_names , &retval);
+  C2F(stcreate)(&lw1, &ndim, (int *) dims, (nfields=1,&nfields), field_names , &retval);
   if( !retval) {
     return (mxArray *) 0;
   }
+  header =  (int *) stk(C2F(vstk).Lstk[lw + Top - Rhs - 1 ]);
+  header[14]=12;header[15]=14; /*  "st" <-- "ce"  */
   C2F(intersci).ntypes[lw-1]=AsIs;
   return (mxArray *) C2F(vstk).Lstk[lw + Top - Rhs - 1 ];
 }
@@ -1083,30 +1150,38 @@ mxArray *mxCreateCellMatrix(int nrows, int ncols)
   return mxCreateCellArray(two, dims);
 }
 
-mxArray *mxGetCell(mxArray *ptr, int index)
+mxArray *mxGetCell(const mxArray *ptr, int index)
 {
-  int kk,lw,isize;
+  int kk,lw,isize;int proddims,k;int is1x1;
   int *headerlist,*headerobj,*headerobjcopy;
   int *header = Header(ptr);
-  if (Is1x1(ptr)) {
+  int *headerdims = listentry(header,2);
+  
+  proddims=1;
+  for (k=0; k<headerdims[1]*headerdims[2]; k++) {
+    proddims=proddims*headerdims[4+k];
+  }
+  is1x1= (int) proddims==1;
+
+  if (is1x1) {
     headerobj = listentry( header, index+1);
     isize = header[5]- header[4];
   }
   else {
     headerlist = listentry(header,3);
     headerobj = listentry(headerlist,index+1);
-    isize=2*(headerlist[index+3]-headerlist[index+2]);
+    isize=headerlist[index+3]-headerlist[index+2];
   }
   Nbvars++;  lw=Nbvars;
-  CreateData(lw,4*isize);
+  CreateData(lw,isize*sizeof(double));
   headerobjcopy=GetData(lw);
-  for (kk = 0; kk < isize; ++kk) headerobjcopy[kk]=headerobj[kk];
+  for (kk = 0; kk < 2*isize; ++kk) headerobjcopy[kk]=headerobj[kk];
   C2F(intersci).ntypes[lw-1]=AsIs;
   C2F(intersci).iwhere[lw-1]=C2F(vstk).Lstk[lw+ Top - Rhs - 1];
   return (mxArray *) C2F(intersci).iwhere[lw-1];
 }
 
-int mxGetFieldNumber(mxArray *ptr, char *string)
+int mxGetFieldNumber(const mxArray *ptr, const char *string)
 {
   int nf, longueur, istart, k, ilocal, retval;
   int *headerstr;
@@ -1128,65 +1203,81 @@ int mxGetFieldNumber(mxArray *ptr, char *string)
   return retval;
 }
 
-mxArray *mxGetField(mxArray *ptr, int index, char *string)
+mxArray *mxGetField(const mxArray *ptr, int index, const char *string)
 {
-  int kk,lw,isize,fieldnum;
+  int kk,lw,isize,fieldnum;int proddims,k;int is1x1;
   int *headerlist, *headerobj, *headerobjcopy;
   int *header = Header(ptr);
+  int *headerdims = listentry(header,2);
+
   fieldnum=mxGetFieldNumber(ptr, string);
   if (fieldnum==-1) return (mxArray *) 0;
+  
+  proddims=1;
+  for (k=0; k<headerdims[1]*headerdims[2]; k++) {
+    proddims=proddims*headerdims[4+k];
+  }
+  is1x1= (int) proddims==1;
 
-  if (Is1x1(ptr)) {
+  if (is1x1) {
     headerobj = listentry( header, 3+fieldnum);
     isize = header[5+fieldnum]- header[4+fieldnum];
   }
   else {
     headerlist = listentry(header,3+fieldnum);
     headerobj = listentry(headerlist,index+1);
-    isize=2*(headerlist[index+3]-headerlist[index+2]);
+    isize=headerlist[index+3]-headerlist[index+2];
   }
 
   Nbvars++; lw=Nbvars;
-  CreateData(lw,4*isize);
+  CreateData(lw,isize*sizeof(double));
   headerobjcopy=GetData(lw);
-  for (kk = 0; kk < isize; ++kk) headerobjcopy[kk]=headerobj[kk];
+  for (kk = 0; kk < 2*isize; ++kk) headerobjcopy[kk]=headerobj[kk];
   C2F(intersci).ntypes[lw-1]=AsIs;
   C2F(intersci).iwhere[lw-1]=C2F(vstk).Lstk[lw+ Top - Rhs - 1];
   return (mxArray *) C2F(intersci).iwhere[lw-1];
 }
 
-mxArray *mxGetFieldByNumber(mxArray *ptr, int index, int field_number)
+mxArray *mxGetFieldByNumber(const mxArray *ptr, int index, int field_number)
 {
-  int kk,lw,isize,fieldnum;  /* maxfieldnum, maxindex; */
+  int kk,lw,isize,fieldnum;int proddims,k;int is1x1;
+  int maxfieldnum, maxindex;
   int *headerlist, *headerobj, *headerobjcopy;
   int *header = Header(ptr);
+  int *headerdims = listentry(header,2);
+
   fieldnum = field_number;
-  /* maxfieldnum = mxGetNumberOfFields(ptr);
-   * maxindex = mxGetM(ptr)*mxGetN(ptr);
-   * if (maxfieldnum < fieldnum) return (mxArray *) NULL;
-   * if (maxindex < index) return (mxArray *) NULL;  */
+  maxfieldnum = mxGetNumberOfFields(ptr)-1;
+  maxindex = mxGetNumberOfElements(ptr)-1;
+  if (maxfieldnum < fieldnum) return (mxArray *) NULL;
+  if (maxindex < index) return (mxArray *) NULL; 
 
+  proddims=1;
+  for (k=0; k<headerdims[1]*headerdims[2]; k++) {
+    proddims=proddims*headerdims[4+k];
+  }
+  is1x1= (int) proddims==1;
 
-  if (Is1x1(ptr)) {
+  if (is1x1) {
     headerobj = listentry( header, 3+fieldnum);
     isize = header[5+fieldnum]- header[4+fieldnum];
   }
   else {
     headerlist = listentry(header,3+fieldnum);
     headerobj = listentry(headerlist,index+1);
-    isize=2*(headerlist[index+3]-headerlist[index+2]);
+    isize=headerlist[index+3]-headerlist[index+2];
   }
-
+  if (isize==2) return (mxArray *) NULL; /* empty field */
   Nbvars++; lw=Nbvars;
-  CreateData(lw,isize*sizeof(int));
+  CreateData(lw,isize*sizeof(double));
   headerobjcopy=GetData(lw);
-  for (kk = 0; kk < isize; ++kk) headerobjcopy[kk]=headerobj[kk];
+  for (kk = 0; kk < 2*isize; ++kk) headerobjcopy[kk]=headerobj[kk];
   C2F(intersci).ntypes[lw-1]=AsIs;
   C2F(intersci).iwhere[lw-1]=C2F(vstk).Lstk[lw+ Top - Rhs - 1];
   return (mxArray *) C2F(intersci).iwhere[lw-1];
 }
 
-int mxGetNumberOfFields(mxArray *ptr)
+int mxGetNumberOfFields(const mxArray *ptr)
 {
   int *header = Header(ptr);
   if (header[0]==MLIST) return header[1]-2;
@@ -1199,29 +1290,42 @@ int mxGetNumberOfFields(mxArray *ptr)
  * we initialize to zero for double and int data types 
  *----------------------------------------------------*/
 
-void *mxCalloc(unsigned int n, unsigned int size)
+
+void *mxRealloc(void *ptr, size_t nsize)
+{
+  int m;  vraiptrst lrd=(vraiptrst)NULL; 
+  m = (nsize) /sizeof(double) + 1;
+  mxFree((void *) lrd);
+  if (! C2F(createstkptr)( &m, &lrd)) return 0;
+  memcpy((void *) lrd, ptr, nsize);
+  return (void *) lrd;
+}
+
+void *mxCalloc(size_t n, size_t size)
 {
   int m;  vraiptrst lrd; 
   static int one=1; int N;
-  static double zero =0.0;
-  m = (n * size) /sizeof(double) + 1;
+  static double zero = 0.0;
+  int nsize;
+  nsize=n*size;
+  m = nsize /sizeof(double) + 1;
   if (! C2F(createstkptr)( &m, &lrd)) {
     return 0;
   }
   if ( size ==  sizeof(double)) 
     {
-      N=(int) n; C2F(dset)(&N,&zero,(double *) lrd,&one);
+      N=(int) n; C2F(dset)(&N, &zero, (double *) lrd,&one);
     }
   else 
     {
       int i;
-      for (i=0; i < n*size ; i++) ((char *) lrd)[i]=0;
+      for (i=0; i < nsize ; i++) ((char *) lrd)[i]=0;
     }
   return (void *) lrd;
 }
 
-
-void *mxMalloc(unsigned int nsize)
+/*  void *mxMalloc(unsigned int nsize)  */
+void *mxMalloc(size_t nsize)
 {
   int m;  vraiptrst lrd;
   m = (nsize) /sizeof(double) + 1;
@@ -1345,7 +1449,7 @@ static void mxFree_m_all() {
  * we initialize to zero for double and int data types 
  *----------------------------------------------------*/
 
-int mxIsCell(mxArray *ptr)
+bool mxIsCell(const mxArray *ptr)
 {
   int *header1; int l;
   int *header = Header(ptr);
@@ -1361,7 +1465,7 @@ int mxIsCell(mxArray *ptr)
   else return 0;
 }
 
-int mxIsStruct(mxArray *ptr)
+bool mxIsStruct(const mxArray *ptr)
 {
   int *header1; int nfplus2, l;
   int *header = Header(ptr);
@@ -1398,20 +1502,37 @@ int IsstOrce(mxArray *ptr)
  * string Matrix pointed to by ptr ( ptr is assumed to be a String Matrix )
  **************************************************************/
 
-int mxGetString(mxArray *ptr, char *str, int strl)
+int mxGetString(const mxArray *ptr, char *str, int strl)
 {
-  int commonlength, firstchain, nrows; 
+  int commonrowlength, totallength, firstchain, nrows; 
   int *header = Header(ptr);
 
   /*  int ncols = header[2]; This is 1 */
-  /* commonlength=nrows*(header[5]-header[4]); */
+
+  if (header[0] != STRINGMATRIX) return 1;
   nrows = header[1];
-  commonlength=header[5]-header[4];
+  commonrowlength=header[5]-header[4];
+  totallength=nrows*commonrowlength;
   firstchain=5+nrows;
-  C2F(in2str)(&commonlength, &header[firstchain], str,0L);
+  C2F(in2str)(&totallength, &header[firstchain], str,0L);
+  if (strl < totallength) return 1;
   return 0;
 }
 
+char *mxArrayToString(const mxArray *array_ptr)
+{
+  int commonrowlength, nrows, buflen; 
+  char *buf;
+  int *header = Header(array_ptr);
+
+  nrows = header[1];
+  commonrowlength=header[5]-header[4];
+  buflen=nrows*commonrowlength;
+  buf = mxCalloc(buflen, sizeof(char));
+  if (mxGetString(array_ptr, buf, buflen) == 0) return (char *) buf;
+  return (char *) 0;
+}
+
 /*-------------------------------------------------
  * mxFreeMatrix : 
  * mxFreeMatrix will do something only if it is called 
@@ -1449,41 +1570,115 @@ void  numberandsize(const mxArray  *ptr, int *number, int *size)
 {
   int kk,lst_k;
   lst_k=(int) ptr;
-  *number=0;*size=0;
+  if (lst_k < *lstk(C2F(vstk).bot)) {
+    *number=0;*size=0;
   for (kk = 1; kk <= Nbvars; kk++)
     {
       *number=kk;
       if (lst_k == C2F(vstk).Lstk[kk+ Top - Rhs -1]) break;
     }
   *size = C2F(vstk).Lstk[*number+ Top - Rhs] - lst_k;
+  } else
+    {
+    *number=0;
+  for (kk = C2F(vstk).bot; kk <  C2F(vstk).isiz; kk++)
+    {
+      *number=kk;
+      if (lst_k == C2F(vstk).Lstk[kk-1]) break;
+    }
+  *size = C2F(vstk).Lstk[*number] - lst_k;
+    }
 }
 
+
 int arr2num( mxArray  *ptr )
 {
   int kk,lst_k,number;
   lst_k=(int) ptr;
-  number=0;
+  if (lst_k < *lstk(C2F(vstk).bot)) {
+    number=0;
   for (kk = 1; kk <= Nbvars; kk++)
     {
       number=kk;
       if (lst_k == C2F(vstk).Lstk[kk+ Top - Rhs -1]) break;
     }
   return number;
+  } else
+    {
+    number=0;
+  for (kk = C2F(vstk).bot; kk <  C2F(vstk).isiz; kk++)
+    {
+      number=kk;
+      if (lst_k == C2F(vstk).Lstk[kk-1]) break;
+    }
+  return number;
+    }
+}
+
+int arr2numcst(const mxArray  *ptr )
+{
+  int kk,lst_k,number;
+  lst_k=(int) ptr;
+  if (lst_k < *lstk(C2F(vstk).bot)) {
+    number=0;
+  for (kk = 1; kk <= Nbvars; kk++)
+    {
+      number=kk;
+      if (lst_k == C2F(vstk).Lstk[kk+ Top - Rhs -1]) break;
+    }
+  return number;
+  } else
+    {
+    number=0;
+  for (kk = C2F(vstk).bot; kk <  C2F(vstk).isiz; kk++)
+    {
+      number=kk;
+      if (lst_k == C2F(vstk).Lstk[kk-1]) break;
+    }
+  return number;
+    }
 }
  
+bool mexIsGlobal(const mxArray *ptr)
+{
+  int pointed;
+  int ret_val;
+  int *header;int *rheader;
+  header=(int *) Header(ptr);
+  rheader=(int *) RawHeader(ptr);
+  pointed = arr2numcst(ptr);
+  /*  A FINIR si interface par reference OK  
+      printf("POINTED %i infstk(pointed) %i\n", pointed, *infstk(pointed));
+      printf("header[2] %i infstk(pointed) %i\n", header[2], *infstk(header[2])); */
+  pointed=header[2];
+  if (*infstk(pointed) == 2) 
+   ret_val = 1;
+  else
+   ret_val = 0;
+  return ret_val;
+}
+
+
 mxArray *mxDuplicateArray(const mxArray *ptr)
 {
   int start_in;
   int lw, number, size, k;
   double *old , *data;
   start_in = (int) ptr;
-  old = stk(start_in);
+  if ( istk( iadr(start_in) )[0] < 0 ) {
+    /*   variable is a reference : the reference is copied */
+    size = istk( iadr(start_in) )[2]; 
+    old = stk( istk(iadr(start_in))[1] );
+  }
+  else {
+    numberandsize(ptr, &number, &size);  
+    old = stk(start_in);
+  }
   Nbvars++; lw = Nbvars;
-  numberandsize( ptr, &number, &size);
   CreateData(lw, size*sizeof(double));
-  data = (double *) GetData(lw);
+  data = (double *) GetRawData(lw); 
   for (k = 0; k <size; ++k)
-  data[k]=old[k];
+    data[k]=old[k];
   return (mxArray *) C2F(vstk).Lstk[lw+ Top - Rhs - 1];
 }
 
@@ -1502,9 +1697,9 @@ mxArray *UnrefStruct(mxArray *ptr)
   int *headerdims; int proddims;int obj;
 
   mxArray *mxNew;
-  header = RawHeader(ptr);
+  header = Header(ptr);   /* RawHeader ?  */
   mxNew = mxDuplicateArray(ptr);
-  headernew = RawHeader(mxNew);
+  headernew = Header(mxNew);   /* RawHeader ?  */
   
   offset = Top - Rhs;
   newsize=header[4];   /* Initialize */
@@ -1535,7 +1730,7 @@ mxArray *UnrefStruct(mxArray *ptr)
     }
     numberandsize( mxNew, &number, &oldsize);
     newsize += 3;   /* taking account begining of list */
-    newbot=*lstk(number+offset)+newsize;
+    newbot=*lstk(number+offset)+newsize+1;
     if( (newbot - *lstk(Bot)) > 0) 
       {Error(17); return 0;}
     *lstk(number+offset+1)=newbot;
@@ -1593,7 +1788,7 @@ mxArray *UnrefStruct(mxArray *ptr)
     }
     numberandsize( mxNew, &number, &oldsize);
     newsize +=3;
-    newbot = *lstk(number+offset)+newsize;
+    newbot = *lstk(number+offset)+newsize+1;
     if ( (newbot - *lstk(Bot)) > 0)
       {Error(17); return 0;}
     *lstk(number+offset+1)=newbot;
@@ -1645,13 +1840,13 @@ int mexAtExit(mxArray *ptr)
   return 0;
 }
 
-mxArray *mxCreateSparse(int m, int n, int nzmax, int cmplx)
+mxArray *mxCreateSparse(int m, int n, int nzmax, mxComplexity cmplx)
 {
   static int lw, iprov;
   Nbvars++;
   lw=Nbvars;
   iprov = lw + Top - Rhs;
-  if( ! C2F(mspcreate)(&iprov, &m, &n, &nzmax, &cmplx)) {
+  if( ! C2F(mspcreate)(&iprov, &m, &n, &nzmax, (int *) &cmplx)) {
     return (mxArray *) 0;
   }
   C2F(intersci).ntypes[lw-1]=AsIs;
@@ -1751,6 +1946,67 @@ void  C2F(mexprintf)(va_alist) va_dcl
   va_end(ap);
 }
 */
+/*
+void  mexPrintf(char *fmt,...) 
+{
+  int i, lstr;
+  va_list args;
+  char buf[2048];
+  va_start(args,fmt);
+  (void ) vsprintf(buf, fmt, args );
+  lstr=strlen(buf);
+  C2F(xscion)(&i);
+  if (i == 0) 
+    {
+      printf("%s",buf); 
+    }
+  else 
+    {
+      C2F(xscisrn)(buf,&lstr,0L);
+    }
+  if (getdiary()) diary_nnl(buf,&lstr);
+  va_end(args);
+}
+*/
+
+/* Modification pour Compilation sous Windows */
+/* Allan CORNET 27 avril 2004 */
+#ifdef __STDC__ 
+void  mexPrintf (char *fmt,...) 
+#else 
+void  mexPrintf (va_alist) va_dcl
+#endif
+{
+  int i, lstr;
+  va_list args;
+  char buf[2048];
+
+  #ifdef __STDC__ 
+  va_start(args,fmt);
+  #else
+	char *fmt;
+	va_start(args);
+	fmt = va_arg(args, char *);
+  #endif 
+  (void ) vsprintf(buf, fmt, args );
+  lstr=strlen(buf);
+  C2F(xscion)(&i);
+  if (i == 0) 
+    {
+      printf("%s",buf); 
+    }
+  else 
+    {
+	#if WIN32
+		sciprint("%s",buf);
+		
+	#else
+      C2F(xscisrn)(buf,&lstr,0L);
+	#endif
+    }
+  if (getdiary()) diary_nnl(buf,&lstr);
+  va_end(args);
+}
 
 
 void mexWarnMsgTxt(char *error_msg)
@@ -1802,11 +2058,15 @@ static int mexCallSCI(int nlhs, mxArray **plhs, int nrhs, mxArray **prhs, char *
 }
 
 
-int mexCallSCILAB(int nlhs, mxArray **plhs, int nrhs, mxArray **prhs, char *name) {
-  return mexCallSCI(nlhs,plhs,nrhs,prhs,name,1); 
+int mexCallSCILAB(int nlhs, mxArray **plhs, int nrhs, mxArray **prhs, const char *name) {
+  return mexCallSCI(nlhs,plhs,nrhs,prhs,(char *) name,1); 
 }
 
-int mxCalcSingleSubscript(mxArray *ptr, int nsubs, int *subs)
+int mexCallMATLAB(int nlhs, mxArray **plhs, int nrhs, mxArray **prhs, const char *name) {
+  return mexCallSCI(nlhs,plhs,nrhs,prhs,(char *) name,1); 
+}
+
+int mxCalcSingleSubscript(const mxArray *ptr, int nsubs, const int *subs)
 {
   int k, retval, coeff;
   int *dims = mxGetDimensions(ptr);
@@ -1857,7 +2117,7 @@ int sci_gateway(char *fname, GatefuncS F)
   return 0;
 }
 
-int mxGetElementSize(mxArray *ptr)
+int mxGetElementSize(const mxArray *ptr)
 { int k, it; 
  int *header = Header(ptr);
  switch (header[0]) {
@@ -1875,7 +2135,7 @@ int mxGetElementSize(mxArray *ptr)
    break;
  case INTMATRIX:
    /*[8,m,n,it] it=01    02   04    11     12    14
-     int8 int16 int32 uint8 uint16 uint32    */
+                  int8 int16 int32 uint8 uint16 uint32    */
    it=header[3];
    return( it%10 );
  default:
@@ -1885,7 +2145,7 @@ int mxGetElementSize(mxArray *ptr)
  return 0;
 }
 
-mxArray *mxCreateCharMatrixFromStrings(int m, char **str)
+mxArray *mxCreateCharMatrixFromStrings(int m, const char **str)
 {
   static int i, lr1, lw, ilocal, n, k,kk, nmax;
   nmax = strlen(str[0]);
@@ -1904,7 +2164,7 @@ mxArray *mxCreateCharMatrixFromStrings(int m, char **str)
   for (k=0; k<m; ++k) {
     n=strlen(str[k]);
     /* fill with blanks (40) if n<nmax !!*/
-    C2F(cvstr)(&n, istk(lr1), str[k], (ilocal=0, &ilocal),i);
+    C2F(cvstr)(&n, istk(lr1), (char *) str[k], (ilocal=0, &ilocal),i);
     if (nmax>n) {
       for (kk=0; kk<nmax-n; ++kk) *istk(lr1+n+kk)=40;
     };
@@ -1939,6 +2199,45 @@ int mexEvalString(char *name)
 }
 
 mxArray *mexGetArray(char *name, char *workspace)
+{
+  int lw, fin, new ; int *header;
+  /* mxArray *mxPointed; */
+  if (C2F(objptr)(name,&lw,&fin,strlen(name))) {
+    /*    mxPointed = (mxArray *) lw;   */
+    Nbvars++; new=Nbvars; 
+    CreateData(new, 4*sizeof(int));
+    header =  (int *) GetRawData(new);
+    header[0]=- *istk( iadr(*lstk(fin))); 
+    header[1]= lw; 
+    header[2]= fin; 
+    header[3]= *lstk(fin+1) -*lstk(fin) ;
+    /*    C2F(intersci).ntypes[new-1]=45;  */
+    return (mxArray *) C2F(intersci).iwhere[new-1]; } 
+  else
+    return (mxArray *) 0;
+}
+
+const mxArray *mexGetVariablePtr(const char *workspace, const char *var_name)
+{
+  int lw, fin, new ; int *header;
+  /* mxArray *mxPointed; */
+  if (C2F(objptr)(var_name,&lw,&fin,strlen(var_name))) 
+    {
+    /*    mxPointed = (mxArray *) lw;   */
+    Nbvars++; new=Nbvars; 
+    CreateData(new, 4*sizeof(int));
+    header =  (int *) GetRawData(new);
+    header[0]=- *istk( iadr(*lstk(fin))); 
+    header[1]= lw; 
+    header[2]= fin; 
+    header[3]= *lstk(fin+1) -*lstk(fin) ;
+    return (mxArray *) C2F(intersci).iwhere[new-1]; 
+    } 
+  else
+    return (mxArray *) 0;
+}
+
+mxArray *mexGetVariable(const char *workspace, const char *name)
 {
   int lw, fin, new ; int *header;
   /* mxArray *mxPointed; */
@@ -1973,7 +2272,13 @@ int mexPutVariable(const char *workspace, char *var_name, mxArray *array_ptr)
 
 void mxSetName(mxArray *array_ptr, const char *name)
 {
-  mexPrintf("Routine mxSetName  not implemented \r\n");
+  mexErrMsgTxt("Routine mxSetName not implemented ! \r\n");
+  exit(1);  /* TO BE DONE */
+}
+
+void mxSetData(mxArray *array_ptr, void *data_ptr)
+{
+  mexErrMsgTxt("Routine mxSetData  not implemented \r\n");
   exit(1);  /* TO BE DONE */
 }
 
@@ -1990,6 +2295,8 @@ void mxSetPi(mxArray *array_ptr, double *pi)
 {
   /* TO BE DONE */
   int size;
+  double *value;
+  value = mxGetPi(array_ptr);
   size=mxGetM(array_ptr)*mxGetN(array_ptr);
   memcpy(mxGetPi(array_ptr), pi, size*sizeof(double));
 }
@@ -1998,12 +2305,14 @@ const char *mxGetName(const mxArray *array_ptr)
 {
     mexPrintf("Routine mxGetName  not implemented \r\n");
     exit(1); 
+	return 0;
 }
 
 int mxSetDimensions(mxArray *array_ptr, const int *dims, int ndim)
 {
   mexPrintf("Routine mxSetDimensions  not implemented \r\n");
   exit(1);  /* TO BE DONE */
+  return 0;
 }
 
 const char *mxGetClassName(const mxArray *ptr)
@@ -2018,7 +2327,7 @@ const char *mxGetClassName(const mxArray *ptr)
     return "sparse";
   case INTMATRIX:
     /*[8,m,n,it] it=01    02   04    11     12    14
-      int8 int16 int32 uint8 uint16 uint32    */
+                   int8 int16 int32 uint8 uint16 uint32    */
     switch (header[3]){
     case 1:
       return "int8";
@@ -2081,13 +2390,6 @@ void mxSetCell(mxArray *array_ptr, int index, mxArray *value)
   return;
 }
 
-/*
-const char *mxGetFieldNameByNumber(const mxArray *array_ptr, int field_number)
-{
-  return "not implemented";
-}
-*/
-
 int mxGetNzmax(mxArray *ptr)
 {
   int *header = Header(ptr);
@@ -2394,6 +2696,11 @@ mxArray *C2F(mxcreatefull)(int *m, int *n, int *it)
   return (mxArray *) lrd ;
 } 
 
+mxArray *C2F(mxcreatedoublematrix)(int *m, int *n, int *it)
+{
+  return (mxArray *) mxCreateDoubleMatrix(*m, *n, *it);
+} 
+
 
 unsigned long int C2F(mxcalloc)(unsigned int *n, unsigned int *size)
 {
@@ -2480,5 +2787,12 @@ int C2F(mxcopyptrtocomplex16)(mxArray *ptr, mxArray *pti, double *y, integer *n)
 
 
 /* mxCreateLogicalArray
- * mxIsLogicalScalar
- * mxIsLogicalScalarTrue  */
+ * mxIsLogicalScalarTrue */
+
+/* *mxRealloc(void *ptr, size_t size);
+    mxArray *mxCreateStringFromNChars(const char *str, int n);
+    int mxSetClassName(mxArray *pa, const char *classname);
+    int mxAddField(mxArray *pa, const char *fieldname);
+    void mxRemoveField(mxArray *pa, int field);
+    void mxSetCopyInCell(mxArray *pa, int i, mxArray *value);  */
+
