@@ -1,4 +1,11 @@
-/**@name Header for newGraph Library  */
+/*------------------------------------------------------------------------
+ *    Graphic library 
+ *    Copyright INRIA
+ *    newGraph Library header
+ *    Matthieu PHILIPPE, INRIA 2001-2002
+ *    Djalel ABDEMOUCHE, INRIA 2002-2004
+ --------------------------------------------------------------------------*/
+
 
 
 #ifdef WIN32
@@ -44,7 +51,7 @@
 #define SB_VERT 0
 #define SB_HORZ 0
 #endif 
-
+#define NUMCOLORS_SCI 32
 /* Renvoi le pointeur sur la structure */
 
 #define pFIGURE_FEATURE(pointobj)      ((sciFigure        *)pointobj->pfeatures)/** */
@@ -53,13 +60,13 @@
 #define pTEXT_FEATURE(pointobj)        ((sciText          *)pointobj->pfeatures)/** */
 #define pTITLE_FEATURE(pointobj)       ((sciTitle         *)pointobj->pfeatures)/** */
 #define pLEGEND_FEATURE(pointobj)      ((sciLegend        *)pointobj->pfeatures)/** */
-#define pPOLYLINE_FEATURE(pointobj)    ((sciPolyline     *)pointobj->pfeatures)/** */
-#define pPATCH_FEATURE(pointobj)       ((sciPatch         *)pointobj->pfeatures)/** */
+#define pPOLYLINE_FEATURE(pointobj)    ((sciPolyline      *)pointobj->pfeatures)/** */
 #define pARC_FEATURE(pointobj)         ((sciArc           *)pointobj->pfeatures)/** */
 #define pRECTANGLE_FEATURE(pointobj)   ((sciRectangle     *)pointobj->pfeatures)/** */
+#define pMERGE_FEATURE(pointobj)       ((sciMerge         *)pointobj->pfeatures)/* DJ.A 30/12 */
 #define pSURFACE_FEATURE(pointobj)     ((sciSurface       *)pointobj->pfeatures)/** */
-#define pLIGHT_FEATURE(pointobj)       ((sciLightSource   *)pointobj->pfeatures)/** */
-#define pAXIS_FEATURE(pointobj)        ((sciAxis          *)pointobj->pfeatures)/** */
+#define pLIGHT_FEATURE(pointobj)       ((sciLightSource   *)pointobj->pfeatures)/** */ 
+/*#define pAXIS_FEATURE(pointobj)        ((sciAxis          *)pointobj->pfeatures)*/ /** */
 #define pAXES_FEATURE(pointobj)        ((sciAxes          *)pointobj->pfeatures)/** */
 #define pGRAYPLOT_FEATURE(pointobj)    ((sciGrayplot      *)pointobj->pfeatures)/** */
 #define pFEC_FEATURE(pointobj)         ((sciFec           *)pointobj->pfeatures)/** */
@@ -72,6 +79,8 @@
 #define pAGREG_FEATURE(pointobj)       ((sciAgreg         *)pointobj->pfeatures)/** */
 #define pSEGS_FEATURE(pointobj)        ((sciSegs          *)pointobj->pfeatures)/** */
 
+#define pLABEL_FEATURE(pointobj)       ((sciLabel         *)pointobj->pfeatures)/** */
+
 #ifndef WIN32
 typedef unsigned short HMENU;
 typedef void *HFONT;                                         
@@ -81,8 +90,8 @@ typedef unsigned long DWORD;
 
 typedef struct tagPOINT2D
 {
-  long x;
-  long y;
+  double x;
+  double y;
 }
 POINT2D;
 
@@ -106,7 +115,6 @@ POINT3D;
  * @memo SCI_ARC,
  * @memo SCI_POLYLINE,
  * @memo SCI_RECTANGLE,
- * @memo SCI_PATCH,
  * @memo SCI_SURFACE,
  * @memo SCI_LIGHT,
  * @memo SCI_AXIS, 
@@ -138,10 +146,10 @@ typedef enum
   SCI_POLYLINE,	    
   /**Entity type RECTANGLE*/
   SCI_RECTANGLE,    
-  /**Entity type PATCH*/
-  SCI_PATCH,		
   /**Entity type SURFACE*/
-  SCI_SURFACE,	    
+  SCI_SURFACE,
+  /**Entity type MERGE*/  /* DJ.A 30/12 */
+  SCI_MERGE,
   /**Entity type LIGHT*/
   SCI_LIGHT,		
   /**Entity type AXIS*/
@@ -167,7 +175,9 @@ typedef enum
   /**Entity type STATUS BAR*/
   SCI_STATUSB,	    
   /**Entity type AGREGATION */
-  SCI_AGREG			
+  SCI_AGREG,			
+  /**Entity type LABEL created by F.Leray 26.05.04 */
+  SCI_LABEL
 }
 /**Struct of Entity type*/
 sciEntityType;	
@@ -299,7 +309,7 @@ sciGraphicContext;
 
 
 /*----------------------
-   SCIFONT.H header file
+  SCIFONT.H header file no more used
   ----------------------*/
 
 /* Changing those lines, be carreful that
@@ -333,13 +343,7 @@ typedef struct
   /** renvoi la longueur de fontname */
   unsigned int fontnamelen;	
   /** */
-  BOOL fontbold;
-  /** */
-  BOOL fontitalic;
-  /** */
-  BOOL fontunderline;
-  /** */
-  BOOL fontstrikeout;
+  int fonttype; /* scilab font index 0 to 9 */
   /** Gets the width of the character in tenth of point */
   int fontdeciwidth;		
   /** this is coded in tenth of a degree */
@@ -400,10 +404,10 @@ typedef struct
   struct BCG *pScilabXgc;	
   sciRelationShip relationship;
   scigMode gmode;
-  sciGraphicContext graphiccontext;
+  sciGraphicContext graphiccontext; /* the only property used here is background */
   sciPointObj * originalsubwin0011;
   /** specifies the title for this window  */
-  char name[sizeof ("ScilabGraphic") + 4];	 
+  char name[80];	 
   /** specifies le length of the string name */
   int namelen;
   /** specifies the number of this window            */
@@ -420,7 +424,8 @@ typedef struct
   int inrootposy;
   /** specifies the colr map                         */
   double *pcolormap;
-  /** specifies if this window is iconified            */
+  /** specifies if this window is iconified*/
+  int numcolors;
   BOOL isiconified;		     
   /** specifies if this window is selected             */
   BOOL isselected; 
@@ -429,7 +434,12 @@ typedef struct
   BOOL visible;
   /** specifies the number of the selected son         */
   int numsubwinselected;
-    
+  /** specifies the current pixmap status         */
+  int pixmap; /* DJ.A 30/12 */
+  int wshow ;
+  
+  sciFont fontcontext; /* F.Leray 08.04.04 */
+  
 }/** */
 sciFigure;  
 
@@ -450,8 +460,10 @@ typedef struct
   /** position in scilab window (not pixel) */
   double y;
   /***/
-  double wy;			    
+  double wh[2];
+  BOOL fill;
   /** */
+  double z; /**DJ.Abdemouche 2003**/
   unsigned int textlen;
   /** specifies the text scilab code for the callback associated with this entity */
   char *callback; 
@@ -559,18 +571,47 @@ typedef struct
 }/** */
 sciTitle;  
 
+/**@name Titre
+ * Structure used to specify Labels like Title or classic labels
+ */
+typedef struct
+{
+  /* sciRelationShip relationship; */
+  /** */
+  sciText text;
+  /** absolut position in subindow*/
+  POINT2D pos;	
+  int ptype;
+  /** up, down */
+  /*sciTitlePlace titleplace; */
+  /** */
+  BOOL isselected;
+  /** specifies if this object is visble             */
+  BOOL visible; 
+  int isclip;
+}/** */
+sciLabel;  
+
+
 typedef struct 
 {  
-  int  fontsize;
-  int  textcolor;
   int  ticscolor;
-  int  subint[2]; /* SS 01/01/03 */
+  /*  int  fontsize;
+      int  textcolor;*/
+  sciFont fontcontext;
+  
+  int  subint[3]; /* Dj.A 17/12/03 */
   int  rect;
   char xdir;   /**  xdir  = 'u' | 'd'  : gives the xy-axes positions **/ 
   char ydir;   /**  ydir  = 'r' | 'l' : gives the xy-axes positions **/ 
   double  xlim[4];  /* [xmin,xmax,ar,nint]           */
   double  ylim[4];  /* [ymin,ymax,ar,nint]           */ 
-  double    limits[5]; /* = 1 set tight limits = 0 set axes auto shape */
+  double  zlim[4];  /* [zmin,zmax,ar,nint]         */  /**DJ.Abdemouche 2003**/
+  double    limits[7]; /* = 1 set tight limits = 0 set axes auto shape */
+  integer flag[3]; /* 3d options */
+  
+  /* F.Leray To keep the logic on aaint:*/
+  integer aaint[4];
 }
 AXES; 
 
@@ -586,7 +627,6 @@ typedef struct
   /** */
   sciGraphicContext graphiccontext; 
   /** */
-  sciTitle title;
   /** specifies the title for this window  */
   char name[sizeof ("ScilabGraphic") + 4];	    
     /** */
@@ -609,16 +649,22 @@ typedef struct
   int zoomx;				 
   /** specifies the factor of the y zoom                     */
   int zoomy;
-  double FRect[4];
-  double WRect[4];
+  double SRect[6]; /* [xmin xmax ymin ymax zmin zmax] : Strict rect. coming from update_specification_bounds function or from a set(a,"data_bounds",[...]) */
+  double FRect[6];
+  double WRect[4]; /* subwin */
+  double ARect[4]; /* margins*/
   int zoomy_kp;
   double FRect_kp[4];
-  double WRect_kp[4];
-  char logflags[2]; /* SS 01/01/03 */
-  char strflag[4];
-  int grid;
+  char logflags[2]; 
+  int grid[3];
   BOOL isaxes;
-  AXES axes;	
+  AXES axes;
+  BOOL is3d;
+  BOOL tight_limits;
+  double theta_kp;
+  double alpha_kp;	
+  double theta;
+  double alpha;	
   /** specifie the associated entity popup menu */
   sciPointObj *pPopMenu;    
   /** specifies the text scilab code for the callback associated with this entity */
@@ -629,6 +675,23 @@ typedef struct
   /** specifies if this object is visble             */
   BOOL visible;  
   int isclip;
+  /**DJ.Abdemouche 2003**/
+  integer project[3];
+  BOOL isoview; 
+  int hiddencolor;
+  int hiddenstate;
+  BOOL facetmerge; 
+  int with_leg; /* Adding F.Leray 07.05.04 */ /* for strflag[0] support : not needed today */
+  BOOL cube_scaling; /* Matlab like view in 3D when one or two range is/are preferential */
+  BOOL FirstPlot; /* An internal state used to indicated that high level functions must not use SRect*/
+
+  /* F.Leray 25.04.05 Labels in sciSubWin*/
+  sciPointObj * mon_title;
+  sciPointObj * mon_x_label;
+  sciPointObj * mon_y_label;
+  sciPointObj * mon_z_label;
+
+
 }/** */
 sciSubWindow;  
 
@@ -669,7 +732,8 @@ typedef struct
   int callbackevent;
   /** specifies if this object is visble             */
   BOOL visible;  
-  int isclip;
+  int isclip; 
+  double z; /**DJ.Abdemouche 2003**/
 }  /** */
 sciArc;
 
@@ -705,12 +769,17 @@ typedef struct
   POINT2D *pvector;		/* vecteur de points redondant, for future developpement*/
   double *pvx;			/* vecteur des points x doublon avec pvector je les garde pour compatiblite*/
   double *pvy;			/* vecteur des points y doublon avec pvector*/
+  double *pvz; /**DJ.Abdemouche 2003**/
   int n1;                               /** number of point */
-  int n2;				/** numbre of curve if Plot **/
+  int n2;                             /** numbre of curve if Plot **/ 
   int closed;                      /** is it a closed polyline */
   int plot;                        /** is it simple poly or a plot (Plot2d /Plot2d1/.../Plot2d4) */
   double xmin;				/** xmin */
   double ymin;				/** ymin */
+  double zmin;				/** ymin */
+  double xmax;				/** xmax Adding  F.Leray  02.04.04 */
+  double ymax;	                        /** ymax Adding  F.Leray  02.04.04 */
+  double zmax;	                        /** ymax Adding  F.Leray  02.04.04 */
   double width;			/** width */
   double height;		/** height */
   BOOL isselected;
@@ -724,34 +793,6 @@ typedef struct
 sciPolyline;  /** */
 
 
-/**@name Patch
- * Structure used to specify 
- */
-typedef struct
-{
-  sciRelationShip relationship;
-  sciGraphicContext graphiccontext;
-  /* listPoints     points; */
-  POINT2D *pvector;		/* vecteur de points redondant, for future developpement*/
-  double *pvx;			/* vecteur des points x doublon avec pvector je les garde pour compatiblite*/
-  double *pvy;			/* vecteur des points y doublon avec pvector*/
-  int n;				/** number of point */
-  int closed;			/** is it a closed polyline */
-  double xmin;				/** xmin */
-  double ymin;				/** ymin */
-  double width;			/** width */
-  double height;		/** height */
-  BOOL isselected;
-  char *callback;		/** specifies the text scilab code for the callback associated with this entity */
-  int callbacklen;		/** the length of the callback code */ 
-  int callbackevent;
-  /** specifies if this object is visble             */
-  BOOL visible; 
-  int isclip;
-}
-sciPatch;  /** */
-
-
 /**@name Rectangle
  * Structure used to specify 
  */
@@ -768,8 +809,8 @@ typedef struct
   int str; 
   integer strwidth;
   integer strheight;
-  double horzcurvature;		  /** to do rectangle with round corner */
-  double vertcurvature;		  /** to do rectangle with round corner */
+  double horzcurvature;		  /** to do rectangle with round corner */ /*F.Leray not implemented till now... 19.03.04 to see...*/
+  double vertcurvature;		  /** to do rectangle with round corner */ /*F.Leray not implemented till now... 19.03.04 to see...*/
   BOOL isselected;
   char *callback; /** specifies the text scilab code for the callback associated with this entity */
   int callbacklen; /** the length of the callback code */  
@@ -777,6 +818,7 @@ typedef struct
   /** specifies if this object is visble             */
   BOOL visible; 
   int isclip;
+  double z;  /** rectangle */
 }
 sciRectangle;  /** */
 
@@ -803,30 +845,58 @@ typedef struct
   double * pvecy;
   double * pvecz;
   integer *zcol;
+  integer *inputCMoV; /* Adding here in order to always have the input data*/
+  /* We will determinate if it is a vector or matrix data with m3n and n3n values*/
+
   integer izcol;  
   integer dimzx;
   integer dimzy;
+
+  /*F.Leray 12.03.04 Adding here to know the length of arrays pvecx, pvecy and pvecz*/
+
+  int nc;
+  int nx;
+  int ny;
+  int nz;
+  int isfac;
+  int m1,n1;
+  int m2,n2;
+  int m3,n3;
+  int m3n,n3n;
+
   POINT2D *pproj;			/* projections on 2d */
-  double theta;
-  double alpha;
-  char *legend;
   integer flag[3];
   double ebox[6];
   int flagcolor; /* this flag indicates the type of the color of how the facet have to be colored 
                         0: uniformed color
-                       1: facet's color are computed with z*/ 
+			1: facet's color are computed with z*/ /* in case of a simple plot...!!! F.Leray 19.03.04 */
   sciTypeOf3D typeof3d;
-
+  int hiddencolor;
   BOOL isselected;
   char *callback; /** specifies the text scilab code for the callback associated with this entity */
   int callbacklen; /** the length of the callback code */  
   int callbackevent;
   /** specifies if this object is visble             */
   BOOL visible; 
+
 }
 sciSurface;  /** */
 
 
+/**@name merge DJ.A 30/12
+ * Structure used to specify 
+ */
+
+typedef struct
+{
+  sciRelationShip relationship;
+  long *from_entity; /* vector of handles on the facet or segment entity*/
+  int *index_in_entity;/*index of facet or segment in its entity*/
+  int N; /* number of facets or segments */
+}
+sciMerge;  /** */
+
+
 /**@name LightSource
  * Structure used to specify 
  */
@@ -875,6 +945,7 @@ typedef struct
   int callbackevent;
   /** specifies if this object is visble             */
   BOOL visible; 
+  int isclip; /* Adding F.Leray 10.03.04*/
 }
 sciAxis;  /** */
 
@@ -897,9 +968,13 @@ typedef struct
   char tics;  /** tics = 'v' (for vector) or 'r' (for range) or i **/
   POINT2D *vector;		/* vecteur de points redondant, for future developpement*/
   double *vx;  /** vx vector of size nx **/
-  double *vy;  /** vy vector of size ny **/  
+  double *vy;  /** vy vector of size ny **/ 
+  /**DJ.Abdemouche 2003**/
+  double *vz; 
   int nx;
   int ny;
+  /***/
+  int nz;
   char **str ;  /** string vector **/
   int subint;  /** subints : number of sub intervals **/ 
   char *format; /** format for tick marks **/
@@ -914,6 +989,8 @@ typedef struct
   /** specifies if this object is visble             */
   BOOL visible; 
   int isclip;
+
+
 }
 sciAxes;  
 
@@ -930,15 +1007,15 @@ typedef struct
 {
   sciRelationShip relationship;
   sciGraphicContext graphiccontext; 
-  double *vx;  /** vx vector of size Nbr **/
-  double *vy;  /** vy vector of size Nbr **/
+  double *vx;  /** vx vector of size Nbr **/ /*F.Leray 18.02.04 ...of size Nbr1 ? No depending on the type ptype*/
+  double *vy;  /** vy vector of size Nbr **/ /*F.Leray 18.02.04 ...of size Nbr2 ? No depending on the type ptype*/
   double *vfx;
   double *vfy;
   integer Nbr1;   
   integer Nbr2;
   integer *pstyle;
   integer iflag;      /**0 or 1, flag which control the drawing of the segment  **/
-  double arrowsize;
+  double arrowsize;  /*F.Leray units : hundreds (i.e. 100, 150,...)*/
   integer pcolored;
   double parfact;
   integer ptype;
@@ -949,6 +1026,8 @@ typedef struct
   /** specifies if this object is visble             */
   BOOL visible; 
   int isclip;
+  double *vz; /**DJ.Abdemouche 2003**/
+  double *vfz;
 
 }
 sciSegs; 
@@ -1157,6 +1236,16 @@ extern int sciSetNumColors (sciPointObj * pobj, int numcolors);
 extern int sciGetNumColors (sciPointObj * pobj);
 extern double *sciCloneColormap (sciPointObj * pobj);
 extern int sciGetColormap (sciPointObj * pobj, double *rgbmat);
+/*Adding F.Leray 31.03.04*/
+extern int sciSetGoodIndex(sciPointObj * pobj, int colorindex);
+extern int sciGetGoodIndex(sciPointObj * pobj, int colorindex);
+extern void sciRecursiveUpdateBaW(sciPointObj *pobj, int old_m, int m);
+extern int sciUpdateBaW (sciPointObj * pobj, int flag, int value);
+extern int sciGetForegroundToDisplay (sciPointObj * pobj);
+extern int sciGetBackgroundToDisplay (sciPointObj * pobj);
+/*End Adding 31.03.04*/
+
+
 extern int sciSetBackground (sciPointObj * pobj, int colorindex);
 extern int sciGetBackground (sciPointObj * pobj);
 extern int sciSetForeground (sciPointObj * pobj, int colorindex);
@@ -1188,6 +1277,10 @@ extern unsigned int sciGetTextLength (sciPointObj * pobj);
 extern int sciGetFontBackground (sciPointObj * pobj);
 extern int sciSetFontBackground (sciPointObj * pobj, int color);
 extern int sciGetFontForeground (sciPointObj * pobj);
+/* F.Leray 09.04.04*/
+extern int sciGetFontForegroundToDisplay (sciPointObj * pobj);
+extern int sciGetFontBackgroundToDisplay (sciPointObj * pobj);
+
 extern int sciSetFontForeground (sciPointObj * pobj, int color);
 extern int sciGetFontStyle (sciPointObj * pobj);
 extern int sciSetFontStyle (sciPointObj * pobj, int fontdeciwidth);
@@ -1292,7 +1385,7 @@ extern sciPointObj *ConstructScrollH (sciPointObj * pparentfigure);
 extern int DestroyScrollV (sciPointObj * pthis);
 extern int DestroyScrollH (sciPointObj * pthis);
 extern sciPointObj *ConstructText (sciPointObj * pparentfigure, char text[],
-				   int n, double x, double y,double wy);
+				   int n, double x, double y,double *wh);
 extern sciPointObj *CloneText (sciPointObj * pthis);
 extern int DestroyText (sciPointObj * pthis);
 extern sciPointObj *ConstructTitle (sciPointObj * pparentfigure, char text[],
@@ -1302,14 +1395,12 @@ extern sciPointObj *ConstructLegend (sciPointObj * pparentfigure, char text[],
 				     int n, int nblegends, int *pstyle, sciPointObj **pptabofpointobj);
 extern int DestroyLegend (sciPointObj * pthis);
 extern sciPointObj *ConstructPolyline (sciPointObj * pparentfigure,
-				       double *pvecx, double *pvecy, int closed, int n1, int n2, int plot);
+				       double *pvecx, double *pvecy, double *pvecz,int closed, int n1, int n2, int plot);/*3D constructor*/
 extern int DestroyPolyline (sciPointObj * pthis);
-extern sciPointObj *ConstructPatch (sciPointObj * pparentfigure,
-				    double *pvectx, double *pvecty, int n);
-extern int DestroyPatch (sciPointObj * pthis);
 extern sciPointObj *ConstructArc (sciPointObj * pparentfigure, double x,
 				  double y, double height, double width,
 				  double alphabegin, double alphaend, int color, int fill);
+
 extern int DestroyArc (sciPointObj * pthis);
 extern sciPointObj *ConstructRectangle (sciPointObj * pparentfigure, double x,
 					double y, double height, double width,
@@ -1317,16 +1408,22 @@ extern sciPointObj *ConstructRectangle (sciPointObj * pparentfigure, double x,
 					double vertcurvature, int fillflag, int fillcolor, int str);
 extern int DestroyRectangle (sciPointObj * pthis);
 extern sciPointObj *ConstructSurface (sciPointObj * pparentsubwin, sciTypeOf3D typeof3d, 
-				  double * pvecx, double * pvecy, double * pvecz,
-				  integer *zcol, integer izcol, integer dimzx, integer dimzy, 
-                                  double theta, double alpha, 
-                                  char *legend, integer *flag, double *ebox, integer flagcolor);
+				      double * pvecx, double * pvecy, double * pvecz,
+				      integer *zcol, integer izcol, integer dimzx, integer dimzy, 
+				      integer *flag, double *ebox, integer flagcolor, integer *isfac,
+				      integer *m1, integer *n1, integer *m2, integer *n2, 
+				      integer *m3, integer *n3, integer *m3n, integer *n3n);
 extern int DestroySurface (sciPointObj * pthis);
-extern sciPointObj *ConstructAxis (sciPointObj * pparentfigure,char *strflag,int style,
+
+extern sciPointObj *ConstructMerge (sciPointObj * pparentsubwin,int N,int *index_in_entity,long *from_entity);
+
+
+extern int DestroyMerge (sciPointObj * pthis);
+/*extern sciPointObj *ConstructAxis (sciPointObj * pparentfigure,char *strflag,int style,
 				   double minx, double miny, double minz,
 				   double maxx, double maxy, double maxz); 
 extern int DestroyAxis (sciPointObj * pthis);
-
+*/
 extern sciPointObj *ConstructGrayplot (sciPointObj * pparentfigure,double *vx,double *vy, 
                                    double *vz,int nx,int ny, int type);
 extern int DestroyGrayplot (sciPointObj * pthis);
@@ -1364,6 +1461,7 @@ extern int sciGet (sciPointObj * pobj, char *marker);
 extern long sciGetCurrentHandle ();
 extern sciPointObj *sciGetCurrentObj ();
 extern sciPointObj *sciGetCurrentFigure ();
+extern void sciSetCurrentFigure (sciPointObj * mafigure);
 
 struct BCG *sciGetCurrentScilabXgc ();
 extern int sciSetCurrentObj (sciPointObj * pobj);
@@ -1375,6 +1473,7 @@ extern int sciSetPosX (sciPointObj * pthis, double x);
 extern int sciSetPosY (sciPointObj * pthis, double y);
 extern double sciGetPosX (sciPointObj * pthis);
 extern double sciGetPosY (sciPointObj * pthis);
+extern double sciGetPosZ (sciPointObj * pthis);/**DJ.Abdemouche 2003**/
 extern double sciGetPosWidth (sciPointObj * pthis);
 extern double sciGetPosHeight (sciPointObj * pthis);
 extern double *sciGetPoint (sciPointObj * pthis, int *num, int *numco);
@@ -1405,10 +1504,11 @@ extern void Zoom_Subwin(double bbox[]);
 extern void Unzoom_Subwin();
 extern sciPointObj *sciGetAxes (sciPointObj *pparentfigure,sciPointObj *psubwin);
 extern void sciSwitchWindow(int *winnum);
-extern int sciType (char *marker);
+extern int sciType (char *marker, sciPointObj *pobj);  /* F.Leray MODIFICATION ICI*/
 extern int sciUnAgregation (sciPointObj * pobj);
-extern void sciGetIdFigure (int *vect, int *id);
+extern void sciGetIdFigure (int *vect, int *id, int *flag);
 extern int version_flag(); 
+void set_version_flag(int flag) ;
 extern int sciDelGraphicObj (sciPointObj * pthis);
 extern unsigned int sciGetFontNameLength (sciPointObj * pobj);
 extern struct BCG *sciGetCurrentScilabXgc ();
@@ -1420,5 +1520,41 @@ extern HDC sciGetHDC (sciPointObj * pobj);
 #endif
 extern sciPointObj *sciGetSurface(sciPointObj *psubwin);
 extern void Obj_RedrawNewAngle(sciPointObj *psubwin,double theta,double alpha);
-extern BOOL Check3DObjs();
+extern BOOL Check3DObjs(sciPointObj *pobj);
 extern sciPointObj *CheckClickedSubwin(integer x, integer y);
+/**DJ.Abdemouche 2003**/
+extern void SetEch3d1(double *xbox, double *ybox, double *zbox, double *bbox, double *teta, double *alpha, integer flag);
+extern void Convex_Box(double *xbox, double *ybox, integer *InsideU, integer *InsideD, char *legend, integer *flag, double *bbox);
+extern void DrawAxis(double *xbox, double *ybox, integer *Indices, integer style);
+extern void axis_3ddraw(sciPointObj *pobj, double *xbox, double *ybox, double *zbox, integer *InsideU, integer *InsideD);
+extern void triedre(sciPointObj *pobj, double *xbox, double *ybox, double *zbox, integer *InsideU, integer *InsideD);
+extern void Nextind(integer ind1, integer *ind2, integer *ind3);
+/* extern int Axes3dStrings(integer *ixbox, integer *iybox, integer *xind, char *legend); */
+extern int Axes3dStrings(integer *ixbox, integer *iybox, integer *xind);
+extern int trans3d(sciPointObj *pobj,integer n,integer *xm,integer *ym,double *x, double *y,double *z);
+extern BOOL Ishidden(sciPointObj *pobj);
+extern BOOL IsDownAxes(sciPointObj *pobj);
+extern void Plo2dTo3d(integer type, integer *n1, integer *n2, double *x, double *y, double *z, double *x1, double *y1, double *z1);
+extern void update_3dbounds(sciPointObj *pobj);
+double Fill_XYdec01_TLO_and_ISO_case(int Xdec3, double val);
+extern void  sci_update_frame_bounds(int cflag);
+extern double graphic_search(double *id, double *tab1, double *tab2, integer *n);
+extern void update_graduation(sciPointObj *pobj);
+/***/
+extern void initsubwin();
+extern int Gen3DPoints (integer type,integer *polyx,integer *polyy,integer *fill,integer whiteid,double zmin,double zmax,double *,double *,double *,integer i,integer j,integer jj1,integer *p,integer dc,integer fg); 
+extern void Merge3d(sciPointObj *psubwin);/*DJ.A merge*/ 
+extern void DrawMerge3d(sciPointObj *psubwin, sciPointObj *pmerge);
+extern sciPointObj *sciGetMerge(sciPointObj *psubwin);
+/* DJ.A 08/01/04 */
+extern int C2F(CreateModels) ();
+extern int InitFigureModel();
+extern int InitAxesModel();
+
+extern sciHandleTab * sciGetpendofhandletab();
+extern void rebuild_strflag( sciPointObj * psubwin, char * STRFLAG);
+
+/* F.Leray 25.05.04 */
+extern int labels2D_draw(sciPointObj * psubwin);
+extern sciPointObj * ConstructLabel (sciPointObj * pparentsubwin, char *text, int type);
+extern int DestroyLabel (sciPointObj * pthis);
