@@ -30,6 +30,13 @@ static void FindIntersection __PARAMS((double sx[], double sy[], double fxy[],
 void newfec __PARAMS((integer *xm,integer *ym,double *triangles,double *func,integer *Nnode,
 		      integer *Ntr,double *zminmax,integer *colminmax));
 extern void initsubwin();
+/*extern void compute_data_bounds(int cflag,char dataflag,double *x,double *y,int n1,int n2,double *drect);*/
+extern void compute_data_bounds2(int cflag,char dataflag,char *logflags,double *x,double *y,int n1,int n2,double *drect);
+extern void update_specification_bounds(sciPointObj *psubwin, double *rect,int flag);
+extern int re_index_brect(double * brect, double * drect);
+extern void strflag2axes_properties(sciPointObj * psubwin, char * strflag);
+
+void get_frame_in_pixel(integer WIRect[]);
 
 /*------------------------------------------------------------
  *  Iso contour with grey level or colors 
@@ -56,7 +63,7 @@ extern void initsubwin();
 
 int C2F(fec)(double *x, double *y, double *triangles, double *func, integer *Nnode, integer *Ntr, char *strflag, char *legend, double *brect, integer *aaint, double *zminmax, integer *colminmax, integer lstr1, integer lstr2)
 {
-  integer *xm,*ym,n1=1;
+  integer *xm,*ym,n1=1,i;
 
   /* Fec code */
 
@@ -66,23 +73,65 @@ int C2F(fec)(double *x, double *y, double *triangles, double *func, integer *Nno
      int cmpt=0,styl[2];
      sciPointObj *pptabofpointobj;
      sciPointObj  *psubwin;
+     double drect[6];
 
      if (!(sciGetGraphicMode (sciGetSelectedSubWin (sciGetCurrentFigure ())))->addplot) { 
        sciXbasc(); 
        initsubwin();
        sciRedrawFigure();
+       psubwin = sciGetSelectedSubWin (sciGetCurrentFigure ());  /* F.Leray 25.02.04*/
      } 
-  
-    /*---- Boundaries of the frame ----*/
-     if ((sciGetGraphicMode (sciGetSelectedSubWin (sciGetCurrentFigure ())))->autoscaling)
-       update_frame_bounds(0,"gnn",x,y,&n1,Nnode,aaint,strflag,brect);
-     psubwin = sciGetSelectedSubWin (sciGetCurrentFigure ()); 
+     psubwin = sciGetSelectedSubWin (sciGetCurrentFigure ());
+     
+     /* Force psubwin->is3d to FALSE: we are in 2D mode */
+     if (sciGetSurface(psubwin) == (sciPointObj *) NULL)
+       {
+	 pSUBWIN_FEATURE (psubwin)->is3d = FALSE;
+	 pSUBWIN_FEATURE (psubwin)->project[2]= 0;
+       }
+     pSUBWIN_FEATURE (psubwin)->theta_kp=pSUBWIN_FEATURE (psubwin)->theta;
+     pSUBWIN_FEATURE (psubwin)->alpha_kp=pSUBWIN_FEATURE (psubwin)->alpha;  
+     pSUBWIN_FEATURE (psubwin)->alpha  = 0.0;
+     pSUBWIN_FEATURE (psubwin)->theta  = 270.0;
+          
+     /* Force psubwin->axes.aaint to those given by argument aaint*/
+     for (i=0;i<4;i++) pSUBWIN_FEATURE(psubwin)->axes.aaint[i] = aaint[i];
+ 
+     /* Force "cligrf" clipping */
      sciSetIsClipping (psubwin,0); 
  
-     strncpy(pSUBWIN_FEATURE (psubwin)->strflag, strflag, strlen(strflag));
-     pSUBWIN_FEATURE (psubwin)->isaxes  = TRUE;
+     /* Force  axes_visible property */
+     /* pSUBWIN_FEATURE (psubwin)->isaxes  = TRUE;*/
 
-     sciDrawObj(sciGetSelectedSubWin (sciGetCurrentFigure ()));
+     if (sciGetGraphicMode (psubwin)->autoscaling) {
+       /* compute and merge new specified bounds with psubwin->Srect */
+       switch (strflag[1])  {
+       case '0': 
+	 /* do not change psubwin->Srect */
+	 break;
+       case '1' : case '3' : case '5' : case '7':
+	 /* Force psubwin->Srect=brect */
+	 re_index_brect(brect, drect);
+	 break;
+       case '2' : case '4' : case '6' : case '8':case '9':
+	 /* Force psubwin->Srect to the x and y bounds */
+	 /* compute_data_bounds(0,'g',x,y,n1,*Nnode,drect); */
+	 compute_data_bounds2(0,'g',pSUBWIN_FEATURE(psubwin)->logflags,x,y,n1,*Nnode,drect);
+	 break;
+       }
+       if (!pSUBWIN_FEATURE(psubwin)->FirstPlot &&
+	   (strflag[1] == '7' || strflag[1] == '8' || strflag[1] == '9')) { /* merge psubwin->Srect and drect */
+	 drect[0] = Min(pSUBWIN_FEATURE(psubwin)->SRect[0],drect[0]); /*xmin*/
+	 drect[2] = Min(pSUBWIN_FEATURE(psubwin)->SRect[2],drect[2]); /*ymin*/
+	 drect[1] = Max(pSUBWIN_FEATURE(psubwin)->SRect[1],drect[1]); /*xmax*/
+	 drect[3] = Max(pSUBWIN_FEATURE(psubwin)->SRect[3],drect[3]); /*ymax*/
+       }
+       if (strflag[1] != '0') update_specification_bounds(psubwin, drect,2);
+
+     } 
+     strflag2axes_properties(psubwin, strflag);
+ 
+     sciDrawObj(sciGetSelectedSubWin (sciGetCurrentFigure ()));/* ???? */
      
      sciSetCurrentObj (ConstructFec 
 		       ((sciPointObj *)
@@ -129,9 +178,9 @@ int C2F(fec)(double *x, double *y, double *triangles, double *func, integer *Nno
      /** Drawing the Legends **/
      if ((int)strlen(strflag) >=1  && strflag[0] == '1')
        {
-	 integer style = -1;
+	 integer styl[2] = {-1,0}; 
 	 n1=1;
-	 Legends(&style,&n1,legend);
+	 Legends(styl,&n1,legend);
        }        
    } /** version_flag ***/
    
@@ -152,6 +201,10 @@ void newfec(integer *xm,integer *ym,double *triangles,double *func,integer *Nnod
   int *zone, *fill, kp, perm[3], zxy[3], color_min;
   integer ii[3];
 
+  /* pour le pre-cliping */
+  integer WIRect[4];
+  double Fxmin, Fxmax, Fymin, Fymax;
+
   /* choice between zmin and zmax given by the user or computed
    *   with the min and max z values. In matdes.c I have put 
    * zminmax[0]= zminmax[1]=0 if the user don't give this argument 
@@ -232,14 +285,19 @@ void newfec(integer *xm,integer *ym,double *triangles,double *func,integer *Nnod
     else if ( func[i] < zmin )
       zone[i] = 0;
     else
-      zone[i] = floor( (func[i] - zmin)/dz ) + 1;
+      zone[i] = (int) (floor( (func[i] - zmin)/dz ) + 1);
   };
   /* 
      2/ loop of the triangles : each triangle is finally decomposed 
      into its differents zones (polygons) by the function PaintTriangle   
   */
-  for ( j = 0 ; j < *Ntr ; j++) {
 
+  get_frame_in_pixel(WIRect);
+  Fxmin = (double) WIRect[0];  Fymin = (double) WIRect[1];
+  Fxmax = (double) WIRect[2];  Fymax = (double) WIRect[3];
+
+  for ( j = 0 ; j < *Ntr ; j++) {
+    double xmin, xmax, ymin, ymax;
     /* retrieve node numbers and functions values */
     for ( k = 0 ; k < 3 ; k++ ) {
       ii[k] = (integer) triangles[j+(*Ntr)*(k+1)] - 1;      
@@ -257,8 +315,29 @@ void newfec(integer *xm,integer *ym,double *triangles,double *func,integer *Nnod
       fxy[k] = func[ii[kp]]; zxy[k] = zone[ii[kp]];
     };
 
-    /* call the "painting" function */
-    PaintTriangle(sx, sy, fxy, zxy, zlevel, fill);
+  /* essai de pre-clipping tous les triangles en dehors de la zone
+     d'affichage ne seront pas traits */
+    xmin = xmax = sx[0]; ymin = ymax = sy[0];
+    if ( sx[1] < sx[2] ) 
+      { 
+	xmin = Min(xmin,sx[1]); xmax = Max(xmax,sx[2]);
+      } 
+    else 
+      {
+	xmin = Min(xmin,sx[2]); xmax = Max(xmax,sx[1]);
+      }
+    if ( sy[1] < sy[2] )
+      { 
+	ymin = Min(ymin,sy[1]); ymax = Max(ymax,sy[2]);
+      }
+    else
+      {
+	ymin = Min(ymin,sy[2]); ymax = Max(ymax,sy[1]);
+      }
+
+    if ( xmax > Fxmin  &&  ymax > Fymin  &&  xmin < Fxmax  &&  ymin < Fymax )  
+      /* call the "painting" function */
+      PaintTriangle(sx, sy, fxy, zxy, zlevel, fill);
   }
   frame_clip_off();
 }
@@ -402,7 +481,8 @@ static void PaintTriangle (double *sx, double *sy, double *fxy, int *zxy, double
 	  PI0,PD0,PD0,PD0,PD0,0L,0L);
 }
 
-static void FindIntersection(double *sx, double *sy, double *fxy, double z, int inda, int indb, integer *xint, integer *yint)
+static void FindIntersection(double *sx, double *sy, double *fxy, double z, 
+			     int inda, int indb, integer *xint, integer *yint)
 {
   double alpha;
   alpha = (z - fxy[inda])/(fxy[indb] - fxy[inda]);
@@ -418,3 +498,4 @@ static void FindIntersection(double *sx, double *sy, double *fxy, double z, int
 
 
 
+
