@@ -120,7 +120,8 @@ int C2F(xgrid)(style)
     {
       sciPointObj *psubwin;
       psubwin = sciGetSelectedSubWin (sciGetCurrentFigure ());
-      pSUBWIN_FEATURE (psubwin)->grid = *style;
+      for (i=0 ; i<3 ; i++) /**DJ.Abdmouche 2003**/
+	pSUBWIN_FEATURE (psubwin)->grid[i] = *style;
       sciDrawObj(psubwin);
       return(0);
     }
@@ -216,18 +217,46 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
       if ( (int)strlen(xf) < 1) c='g' ; else c=xf[0];
       switch ( c )
 	{
-	case 'e' : xmin= 1.0 ; xmax = (*n2);break;
-	case 'o' : xmax= Maxi(x,(*n2)); xmin= Mini(x,(*n2)); break;
-	case 'g' :
-	default: xmax= Maxi(x, size_x); xmin= Mini(x, size_x); break;
+	case 'e' : xmin= 1.0 ; xmax = (*n2);break; /* F.Leray obsolete ??*/
+	case 'o' : xmax= Maxi(x,(*n2)); xmin= Mini(x,(*n2)); break; /* F.Leray obsolete ??*/
+	case 'g' : /* F.Leray obsolete ??*/
+	  /* F.Leray : look for the min/max inside the x/y vector of size size_x/size-y*/
+	default: xmax= Maxi(x, size_x); xmin= Mini(x, size_x); break; /* for x*/
 	}
-      ymin=  Mini(y, size_y); ymax=  Maxi(y,size_y);
+      ymin=  Mini(y, size_y); ymax=  Maxi(y,size_y); /* for y*/
       /* back to default values for  x=[] and y = [] */
       if ( ymin == LARGEST_REAL ) { ymin = 0; ymax = 10.0 ;} 
       if ( xmin == LARGEST_REAL ) { xmin = 0; xmax = 10.0 ;} 
       break;
     }
 
+  
+  /* BLOCK that moved is HERE F.Leray 20.04.04 */
+  /* FRect gives the plotting boundaries xmin,ymin,xmax,ymax */
+  if (version_flag() == 0) 
+    {/*update A.Djalel for new graphics auto scaling*/
+      subwindowtmp = sciGetSelectedSubWin(sciGetCurrentFigure()); /**DJ.Abdmouche 2003**/
+
+      
+      if ((pSUBWIN_FEATURE (subwindowtmp)->axes.limits[1] !=0 )  || (pSUBWIN_FEATURE (subwindowtmp)->axes.limits[3] !=0 ))
+	{  
+	  xmin=(double) Min(pSUBWIN_FEATURE (subwindowtmp)->axes.limits[1],xmin);
+	  xmax=(double) Max(pSUBWIN_FEATURE (subwindowtmp)->axes.limits[3],xmax);
+	}
+      pSUBWIN_FEATURE (subwindowtmp)->axes.limits[1]=xmin;
+      pSUBWIN_FEATURE (subwindowtmp)->axes.limits[3]=xmax;
+      
+      if ((pSUBWIN_FEATURE (subwindowtmp)->axes.limits[2] !=0 )  || (pSUBWIN_FEATURE (subwindowtmp)->axes.limits[4] !=0 ))
+	{  
+	  ymin=(double) Min(pSUBWIN_FEATURE (subwindowtmp)->axes.limits[2],ymin);
+	  ymax=(double) Max(pSUBWIN_FEATURE (subwindowtmp)->axes.limits[4],ymax);
+	}
+      pSUBWIN_FEATURE (subwindowtmp)->axes.limits[2]=ymin;
+      pSUBWIN_FEATURE (subwindowtmp)->axes.limits[4]=ymax;
+
+    }
+
+
   /*
    * modify computed min,max if isoview requested 
    */
@@ -235,22 +264,25 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
   if ( strflag[1] == '3' || strflag[1] == '4')
     {
       /* code added by S. Mottelet 11/7/2000 */
-      double FRect[4],WRect[4],ARect[4];
-      char logscale[4];      
+      double FFRect[4],WRect[4],ARect[4];
+      /*char logscale[4]; */ /*   F.Leray 24.03.04      */
+      char logscale[2]; 
       /* end of added code by S. Mottelet 11/7/2000 */
       
-      int verbose=0,wdim[2],narg;
+      int verbose=0,wdim[2],narg; /* verbose set to 1 F.Leray 05.04.04 AND reset to 0 07.04.04*/
       C2F(dr)("xget","wdim",&verbose,wdim,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       hx=xmax-xmin;
       hy=ymax-ymin;
 
       /* code added by S. Mottelet 11/7/2000 */
-      getscale2d(WRect,FRect,logscale,ARect);
+      getscale2d(WRect,FFRect,logscale,ARect);
 
       wdim[0]=linint((double)wdim[0] * WRect[2]);
       wdim[1]=linint((double)wdim[1] * WRect[3]);
       /* end of added code by S. Mottelet 11/7/2000 */
 
+    
+
       if ( hx/(double)wdim[0]  <hy/(double) wdim[1] ) 
 	{
 	  hx1=wdim[0]*hy/wdim[1];
@@ -273,7 +305,7 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
 	{
 	  xmax=ceil(log10(xmax));  xmin=floor(log10(xmin));
 	}
-      else 
+      else
 	{
 	  Scistring("Warning: Can't use Log on X-axis xmin is negative \n");
 	  xmax= 1; xmin= 0;
@@ -285,11 +317,11 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
   if ((int)strlen(xf) >=3  && xf[2]=='l' && (int)strlen(strflag) >= 2 && strflag[1] != '0')
     {
       /* y axis */
-      if ( ymin > 0 ) 
+      if ( ymin > 0 )
 	{
 	  ymax= ceil(log10(ymax)); ymin= floor(log10(ymin));
 	}
-      else 
+      else
 	{
 	  Scistring(" Can't use Log on y-axis ymin is negative \n");
 	  ymax= 1; ymin= 0;
@@ -297,7 +329,7 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
       aaint[2]=1;aaint[3]=inint(ymax-ymin);
     }
   
-  /* FRect gives the plotting boundaries xmin,ymin,xmax,ymax */
+  /* MOVE OF THE BLOCK on axes.limits affectation */
 
   FRect[0]=xmin;FRect[1]=ymin;FRect[2]=xmax;FRect[3]=ymax;
 
@@ -317,16 +349,30 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
 	      Scistring("Warning: you cannot use automatic rescale if you switch from log to normal or normal to log \n");
 	    }
 	  else 
-	    {
-	      FRect[0] = Min(FRect[0],Cscale.frect[0]);
-	      FRect[1] = Min(FRect[1],Cscale.frect[1]);
-	      FRect[2] = Max(FRect[2],Cscale.frect[2]);
-	      FRect[3] = Max(FRect[3],Cscale.frect[3]);
+	    { 
+	      if (version_flag() != 0){
+		FRect[0] = Min(FRect[0],Cscale.frect[0]);
+		FRect[1] = Min(FRect[1],Cscale.frect[1]);
+		FRect[2] = Max(FRect[2],Cscale.frect[2]);
+		FRect[3] = Max(FRect[3],Cscale.frect[3]);
+	      }
+	      else{ /*dj2003*/
+		subwindowtmp = sciGetSelectedSubWin(sciGetCurrentFigure()); /* rajout F.Leray*/
+		FRect[0] = Min(FRect[0],pSUBWIN_FEATURE (subwindowtmp)->FRect[0]);
+		FRect[1] = Min(FRect[1],pSUBWIN_FEATURE (subwindowtmp)->FRect[1]);
+		FRect[2] = Max(FRect[2],pSUBWIN_FEATURE (subwindowtmp)->FRect[2]);
+		FRect[3] = Max(FRect[3],pSUBWIN_FEATURE (subwindowtmp)->FRect[3]);
+	      }
 	      if ( FRect[0] < Cscale.frect[0] 
 		   || FRect[1] < Cscale.frect[1] 
 		   || FRect[2] > Cscale.frect[2] 
 		   || FRect[3] > Cscale.frect[3] )
-		redraw = 1;
+		redraw = 1; 
+	      /* F.Leray 15.04.04 */
+	      /* Here the redraw and the computed FRect will be used below */
+	      /* in Tape_ReplayNewScale1(" ",&ww,flag,PI0,aaint,PI0,PI0,FRect,PD0,PD0,PD0);*/
+	      /* in this case (if (strflag[1] == '7' || strflag[1] == '8' )), */
+	      /* we also recomput FRect */
 	    }
 	}
       /* and we force flag back to 5  */
@@ -342,11 +388,14 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
 	case '6' : strflag[1]='5';break;
 	}
     }
-
-  if ( (int)strlen(strflag) >=2 && ( strflag[1]=='5' || strflag[1]=='6' ))
+    if ( (int)strlen(strflag) >=2 && ( strflag[1]=='5' || strflag[1]=='6' ))
     {
       /* recherche automatique des bornes et graduations */
-      Gr_Rescale(&xf[1],FRect,Xdec,Ydec,&(aaint[0]),&(aaint[2]));
+      Gr_Rescale(&xf[1],FRect,Xdec,Ydec,&(aaint[0]),&(aaint[2])); /* F.Leray 15.04.04 Here we change the value of FRect */
+    }
+    else {
+      Xdec[0]=inint(FRect[0]);Xdec[1]=inint(FRect[2]);Xdec[2]=0;
+      Ydec[0]=inint(FRect[1]);Ydec[1]=inint(FRect[3]);Ydec[2]=0;
     }
   
   /* Update the current scale */
@@ -384,7 +433,7 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
       } 
     }
   /* NG end */ 
-  /* Changing back min,max and aaint if using log scaling X axis */
+  /* Changing back min,max and aaint if using log scaling X axis */  /* F.Leray 15.04.04 WHY NOT MAKE set_scale after this change ??? */
   if ((int)strlen(xf) >= 2 && xf[1]=='l' && (int)strlen(strflag) >= 2 && strflag[1] != '0')
     {
       FRect[0]=exp10(xmin);FRect[2]=exp10(xmax);
@@ -394,6 +443,8 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
     {
       FRect[1]= exp10(ymin);FRect[3]= exp10(ymax);
     }
+
+
   /* Redraw other graphics */
   if ( redraw )
     {
@@ -402,20 +453,24 @@ void update_frame_bounds(cflag, xf, x, y, n1, n2, aaint, strflag, FRect)
       /* Redraw previous graphics with new Scale */
       integer ww,verbose=0,narg;
       GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-      if (strcmp("Rec",driver) != 0) 
-	{
-	  Scistring("Auto rescale only works with the rec driver\n" );
-	  return;
-	}
-      C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-      C2F(SetDriver)("X11",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-      C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-      Tape_ReplayNewScale1(" ",&ww,flag,PI0,aaint,PI0,PI0,FRect,PD0,PD0,PD0);
-      /*** MAJ A.Djalel */ 
-      if (version_flag() == 0)
-	{
+
+      if (version_flag() != 0) /* F.Leray*/
+	  {
+		if (strcmp("Rec",driver) != 0) 
+		{	
+		  Scistring("Auto rescale only works with the rec driver\n" );
+		  return;
+		}
+		C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+		C2F(SetDriver)("X11",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
+		C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+		Tape_ReplayNewScale1(" ",&ww,flag,PI0,aaint,PI0,PI0,FRect,PD0,PD0,PD0);
+	  }
+	  else
+	  {
 	    sciDrawObj(subwindowtmp);
-        } 
+      } 
+
       C2F(SetDriver)(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
     }
 }
