@@ -16,6 +16,8 @@
  * A List for storing Window scaling information 
  *----------------------------------------------*/
 
+extern int versionflag; /* Test for NG F.Leray 03.03.04*/
+
 static void scale_copy __PARAMS((WCScaleList *s1, WCScaleList *s2));
 static integer curwin __PARAMS((void));
 static void zoom_rect __PARAMS((double,double,double,double));
@@ -108,7 +110,7 @@ int get_window_scale(i,subwin)
 static int get_scale_win(listptr, wi,subwin)
      ScaleList *listptr;
      integer wi;
-     double *subwin;
+     double *subwin;                                                          
 {
   if (listptr != (ScaleList  *) NULL)
     { 
@@ -464,11 +466,13 @@ int C2F(Nsetscale2d)(WRect,ARect,FRect,logscale,l1)
 	    sciSetSelectedSubWin(masousfen);
 	  else if ((masousfen = ConstructSubWin (sciGetCurrentFigure(), 0)) != NULL)
 	    {
-	    sciSetSelectedSubWin(masousfen);
-            pSUBWIN_FEATURE (masousfen)->WRect[0]   = WRect[0];
-	    pSUBWIN_FEATURE (masousfen)->WRect[1]   = WRect[1];
-	    pSUBWIN_FEATURE (masousfen)->WRect[2]   = WRect[2];
-            pSUBWIN_FEATURE (masousfen)->WRect[3]   = WRect[3];
+	      /* F.Leray Adding here 26.03.04*/
+	      sciSetCurrentObj(masousfen);
+	      sciSetSelectedSubWin(masousfen);
+	      pSUBWIN_FEATURE (masousfen)->WRect[0]   = WRect[0];
+	      pSUBWIN_FEATURE (masousfen)->WRect[1]   = WRect[1];
+	      pSUBWIN_FEATURE (masousfen)->WRect[2]   = WRect[2];
+	      pSUBWIN_FEATURE (masousfen)->WRect[3]   = WRect[3];
             }
 	} 
       /** */
@@ -497,12 +501,22 @@ int C2F(Nsetscale2d)(WRect,ARect,FRect,logscale,l1)
   if (version_flag() == 0)
     if (FRect != NULL)
 	    { masousfen=sciGetSelectedSubWin(sciGetCurrentFigure());
-	      pSUBWIN_FEATURE (masousfen)->FRect[0]   = FRect[0];
-	      pSUBWIN_FEATURE (masousfen)->FRect[1]   = FRect[1];
-	      pSUBWIN_FEATURE (masousfen)->FRect[2]   = FRect[2];
-	      pSUBWIN_FEATURE (masousfen)->FRect[3]   = FRect[3];
+	      pSUBWIN_FEATURE (masousfen)->SRect[0]   = FRect[0];
+	      pSUBWIN_FEATURE (masousfen)->SRect[2]   = FRect[1];
+	      pSUBWIN_FEATURE (masousfen)->SRect[1]   = FRect[2];
+	      pSUBWIN_FEATURE (masousfen)->SRect[3]   = FRect[3];
 	    }
   if ( FRect != NULL) flag[2]='t'; else FRect = Cscale.frect;
+
+  if (version_flag() == 0)
+    if (ARect != NULL)
+      { masousfen=sciGetSelectedSubWin(sciGetCurrentFigure());
+      pSUBWIN_FEATURE (masousfen)->ARect[0]   = ARect[0];
+      pSUBWIN_FEATURE (masousfen)->ARect[1]   = ARect[1];
+      pSUBWIN_FEATURE (masousfen)->ARect[2]   = ARect[2];
+      pSUBWIN_FEATURE (masousfen)->ARect[3]   = ARect[3];
+      }
+
   if ( ARect != NULL) flag[5]='t'; else ARect = Cscale.axis;
   if ( logscale != NULL) flag[4] ='t'; else logscale = Cscale.logflag;
   if ( flag[4] == 't' && flag[2] == 't' ) 
@@ -552,7 +566,7 @@ int getscale2d(WRect,FRect,logscale,ARect)
   if (logscale[0]=='l') 
     { 
       FRect[0]=pow(ten,FRect[0]);
-	FRect[2]=pow(ten,FRect[2]);
+      FRect[2]=pow(ten,FRect[2]);
     }
   if (logscale[1]=='l') 
     {
@@ -561,6 +575,15 @@ int getscale2d(WRect,FRect,logscale,ARect)
     }
   return(0);
 }
+/* reporte de CVS par serge 07/11/03*/
+void get_frame_in_pixel(integer WIRect[])
+{
+  /* ajout bruno */
+  WIRect[0] = Cscale.WIRect1[0];
+  WIRect[1] = Cscale.WIRect1[1];
+  WIRect[2] = Cscale.WIRect1[0] +  Cscale.WIRect1[2];
+  WIRect[3] = Cscale.WIRect1[1] +  Cscale.WIRect1[3];
+}
 
 /*-------------------------------------------
  * changes selected items in the current scale 
@@ -575,7 +598,7 @@ int getscale2d(WRect,FRect,logscale,ARect)
 
 void set_scale(flag,subwin,frame_values,aaint,logflag,axis_values)
      char flag[6];            /* flag[i] = 't' or 'f' */
-     double  subwin[4];       /* subwindow specification */
+     double  subwin[4];       /* subwindow specification */ /* <=> WRect*/
      double  frame_values[4]; /* [xmin,ymin,xmax,ymax] */
      integer aaint[4];        /* [xint,x_subint,y_int,y_subint]*/
      char logflag[2];         /* [xlogflag,ylogflag] */
@@ -980,9 +1003,9 @@ void C2F(axis2d)(alpha, initpoint, size, initpoint1, size1)
 
 extern int EchCheckSCPlots();
 
-/** get a rectangle interactively **/ 
+/** get a rectangle interactively **/
 
-void zoom_get_rectangle(bbox)
+int zoom_get_rectangle(bbox)
      double bbox[4];
 {
   /* Using the mouse to get the new rectangle to fix boundaries */
@@ -992,7 +1015,7 @@ void zoom_get_rectangle(bbox)
   integer modes[2];
   double x0,yy0,x,y,xl,yl;
 
-  modes[0]=1;modes[1]=0; /* for xgemouse only get mouse mouvement*/ 
+  modes[0]=1;modes[1]=0; /* for xgemouse only get mouse mouvement*/
 
   C2F(dr)("xget","pixmap",&verbose,&pixmode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xget","alufunction",&verbose,&alumode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -1022,6 +1045,7 @@ void zoom_get_rectangle(bbox)
       zoom_rect(x0,yy0,x,y);
       if ( pixmode == 1) C2F(dr1)("xset","wshow",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr1)("xgetmouse","one",&ibutton,&iwait,PI0,PI0,modes,PI0,&xl, &yl,PD0,PD0,0L,0L);
+      if (ibutton==-100) return 1; /* the window has been closed */
       /* effacement du rectangle */
       zoom_rect(x0,yy0,x,y);
       if ( pixmode == 1) C2F(dr1)("xset","wshow",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -1032,8 +1056,10 @@ void zoom_get_rectangle(bbox)
   C2F(dr1)("xset","alufunction",(in=3,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 #endif
   /* Back to the default driver which must be Rec and redraw the recorded
-   * graphics with the new scales 
+   * graphics with the new scales
    */
+  /* F.Leray With the nez graphic standard, driver has not to be Rec*/
+
   bbox[0]=Min(x0,x);
   bbox[1]=Min(yy0,y);
   bbox[2]=Max(x0,x);
@@ -1046,136 +1072,147 @@ void zoom_get_rectangle(bbox)
 #ifdef WIN32
   ReleaseWinHdc();
   SciMouseRelease();
-#endif 
-
+#endif
+  return 0;
 }
 
 
 
-void zoom()
+int zoom()
 {
-  char driver[4];
-  integer aaint[4],flag[2]; /* ansi : ={1,0};*/
-  integer verbose=0,narg,ww; 
-  /** 01/07/2002 ***/
-  sciPointObj *psousfen,*tmpsousfen;
-  sciSons *psonstmp;  
+  integer min,max,puiss,deux=2,dix=10,box[4],box1[4],section[4];
+  double bbox[4];
 
-  double fmin,fmax,lmin,lmax;  
-  integer min,max,puiss,deux=2,dix=10,box1[4],section[4];
+  if (version_flag() == 0){
+    double fmin,fmax,lmin,lmax;
+    sciPointObj *psousfen,*tmpsousfen;
+    sciSons *psonstmp;
+
+    if (zoom_get_rectangle(bbox)==1) return 1;
  
- 
-  flag[0] =1 ; flag[1]=0;
-  C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-  if (strcmp("Rec",driver) != 0) 
-    {
-      Scistring("\n Use the Rec driver to zoom " );
-      return;
-    }
-  else 
-    {
-      double bbox[4];
- 
-      zoom_get_rectangle(bbox);   
-      C2F(SetDriver)(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-      C2F(dr)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);  
-      if (version_flag() == 0){  
-	/***** 02/10/2002 ****/
-        integer box[4];
-       
-        box[0]= Min(XDouble2Pixel(bbox[0]),XDouble2Pixel(bbox[2])); 
-        box[2]= Max(XDouble2Pixel(bbox[0]),XDouble2Pixel(bbox[2]));
-        box[1]= Min(YDouble2Pixel(bbox[1]),YDouble2Pixel(bbox[3])); 
-        box[3]= Max(YDouble2Pixel(bbox[1]),YDouble2Pixel(bbox[3]));
-       
-        
-        tmpsousfen= (sciPointObj *) sciGetSelectedSubWin (sciGetCurrentFigure());
-        psonstmp = sciGetSons (sciGetCurrentFigure());
-        while (psonstmp != (sciSons *) NULL)	
-          {  
-           if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN)
-             {
-                psousfen= (sciPointObj *)psonstmp->pointobj;
-                 sciSetSelectedSubWin(psousfen);
-                 box1[0]= Cscale.WIRect1[0]; 
-		 box1[2]= Cscale.WIRect1[2]+Cscale.WIRect1[0];
-		 box1[1]= Cscale.WIRect1[1]; 
-		 box1[3]= Cscale.WIRect1[3]+Cscale.WIRect1[1];
-                 
-                 if (sciIsAreaZoom(box,box1,section))
-                   { 
-                 bbox[0]= Min(XPixel2Double(section[0]),XPixel2Double(section[2])); 
-                 bbox[2]= Max(XPixel2Double(section[0]),XPixel2Double(section[2]));
-                 bbox[1]= Min(YPixel2Double(section[1]),YPixel2Double(section[3])); 
-                 bbox[3]= Max(YPixel2Double(section[1]),YPixel2Double(section[3])); 
-                 
-                     if (!(sciGetZooming(psousfen)))
-	               {
-		       sciSetZooming(psousfen, 1);
-		       pSUBWIN_FEATURE (psousfen)->FRect_kp[0]   = pSUBWIN_FEATURE (psousfen)->FRect[0];
-		       pSUBWIN_FEATURE (psousfen)->FRect_kp[1]   = pSUBWIN_FEATURE (psousfen)->FRect[1];
-		       pSUBWIN_FEATURE (psousfen)->FRect_kp[2]   = pSUBWIN_FEATURE (psousfen)->FRect[2];
-		       pSUBWIN_FEATURE (psousfen)->FRect_kp[3]   = pSUBWIN_FEATURE (psousfen)->FRect[3];
-                       }
-		      
- 
-		     /** regraduation de l'axe des axes ***/
-		     fmin=  bbox[0]; 
-		     fmax=  bbox[2];
-		     C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
-                     pSUBWIN_FEATURE(psousfen)->axes.xlim[2]=puiss; 
-                     pSUBWIN_FEATURE (psousfen)->FRect[0]=lmin;  
-                     pSUBWIN_FEATURE (psousfen)->FRect[2]=lmax; 
-		     
-          
-		     fmin= bbox[1]; fmax= bbox[3];   
-		     C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
-		     pSUBWIN_FEATURE(psousfen)->axes.ylim[2]=puiss;
-                     pSUBWIN_FEATURE (psousfen)->FRect[1]=lmin;  
-                     pSUBWIN_FEATURE (psousfen)->FRect[3]=lmax; 
-		 }
-	     }     
-           psonstmp = psonstmp->pnext;
-          }
-          sciSetSelectedSubWin(tmpsousfen);
-          sciSetReplay(1);
-	  sciDrawObj(sciGetCurrentFigure());
-	  sciSetReplay(0);
-         }
-        else 
-           Tape_ReplayNewScale(" ",&ww,flag,PI0,aaint,PI0,PI0,bbox,PD0,PD0,PD0);
-	  
-    }
+    box[0]= Min(XDouble2Pixel(bbox[0]),XDouble2Pixel(bbox[2]));
+    box[2]= Max(XDouble2Pixel(bbox[0]),XDouble2Pixel(bbox[2]));
+    box[1]= Min(YDouble2Pixel(bbox[1]),YDouble2Pixel(bbox[3]));
+    box[3]= Max(YDouble2Pixel(bbox[1]),YDouble2Pixel(bbox[3]));
+
+
+    tmpsousfen= (sciPointObj *) sciGetSelectedSubWin (sciGetCurrentFigure());
+    psonstmp = sciGetSons (sciGetCurrentFigure());
+    while (psonstmp != (sciSons *) NULL)
+      {
+	if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN)
+	  {
+	    psousfen= (sciPointObj *)psonstmp->pointobj;
+	    if ( pSUBWIN_FEATURE (psousfen)->is3d == TRUE) {
+	      sciprint("3D zoom is not yet implemented for new graphic style\n");
+	      return 0;
+	    }
+	    sciSetSelectedSubWin(psousfen);
+	    box1[0]= Cscale.WIRect1[0];
+	    box1[2]= Cscale.WIRect1[2]+Cscale.WIRect1[0];
+	    box1[1]= Cscale.WIRect1[1];
+	    box1[3]= Cscale.WIRect1[3]+Cscale.WIRect1[1];
+
+	    if (sciIsAreaZoom(box,box1,section))
+	      {
+		bbox[0]= Min(XPixel2Double(section[0]),XPixel2Double(section[2]));
+		bbox[2]= Max(XPixel2Double(section[0]),XPixel2Double(section[2]));
+		bbox[1]= Min(YPixel2Double(section[1]),YPixel2Double(section[3]));
+		bbox[3]= Max(YPixel2Double(section[1]),YPixel2Double(section[3]));
+
+		if (!(sciGetZooming(psousfen)))
+		  {
+		    sciSetZooming(psousfen, 1);
+		    pSUBWIN_FEATURE (psousfen)->FRect_kp[0]   = pSUBWIN_FEATURE (psousfen)->FRect[0];
+		    pSUBWIN_FEATURE (psousfen)->FRect_kp[1]   = pSUBWIN_FEATURE (psousfen)->FRect[1];
+		    pSUBWIN_FEATURE (psousfen)->FRect_kp[2]   = pSUBWIN_FEATURE (psousfen)->FRect[2];
+		    pSUBWIN_FEATURE (psousfen)->FRect_kp[3]   = pSUBWIN_FEATURE (psousfen)->FRect[3];
+		  }
+
+
+		/** regraduation de l'axe des axes ***/
+		fmin=  bbox[0];
+		fmax=  bbox[2];
+		if(pSUBWIN_FEATURE (psousfen)->logflags[0] == 'n') {
+		  C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
+		  pSUBWIN_FEATURE(psousfen)->axes.xlim[2]=puiss;
+		  pSUBWIN_FEATURE (psousfen)->FRect[0]=lmin;
+		  pSUBWIN_FEATURE (psousfen)->FRect[2]=lmax;}
+		else {
+		  pSUBWIN_FEATURE(psousfen)->axes.xlim[2]=0;
+		  pSUBWIN_FEATURE (psousfen)->FRect[0]=fmin;
+		  pSUBWIN_FEATURE (psousfen)->FRect[2]=fmax;
+		}
+
+
+		fmin= bbox[1]; fmax= bbox[3];
+		if(pSUBWIN_FEATURE (psousfen)->logflags[1] == 'n') {
+		  C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
+		  pSUBWIN_FEATURE(psousfen)->axes.ylim[2]=puiss;
+		  pSUBWIN_FEATURE (psousfen)->FRect[1]=lmin;
+		  pSUBWIN_FEATURE (psousfen)->FRect[3]=lmax;}
+		else {
+		  pSUBWIN_FEATURE(psousfen)->axes.ylim[2]=0;
+		  pSUBWIN_FEATURE (psousfen)->FRect[1]=fmin;
+		  pSUBWIN_FEATURE (psousfen)->FRect[3]=fmax;}
+	      }
+	  }
+	psonstmp = psonstmp->pnext;
+      }
+    sciSetSelectedSubWin(tmpsousfen);
+    sciSetReplay(1);
+    sciDrawObj(sciGetCurrentFigure());
+    sciSetReplay(0);
+  }
+  else {
+    integer aaint[4],flag[2];
+    char driver[4];
+    integer verbose=0,narg,ww;
+
+    C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
+    if (strcmp("Rec",driver) != 0)
+      {
+	Scistring("\n Use the Rec driver to zoom " );
+	return 0;
+      }
+    zoom_get_rectangle(bbox);
+    C2F(SetDriver)(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
+
+    C2F(dr)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    flag[0] =1 ; flag[1]=0;
+    Tape_ReplayNewScale(" ",&ww,flag,PI0,aaint,PI0,PI0,bbox,PD0,PD0,PD0);
+  }
+  return 0;
 }
 
 
 extern void unzoom()
 {
   char driver[4];
-  integer ww,verbose=0,narg; 
-  /** 17/09/2002 ***/  
-  double fmin,fmax,lmin,lmax;  
+  integer ww,verbose=0,narg;
+  /** 17/09/2002 ***/
+  double fmin,fmax,lmin,lmax;
   integer min,max,puiss,deux=2,dix=10;
   sciPointObj *psousfen;
-  sciSons *psonstmp;  
+  sciSons *psonstmp;
+
 
-  
   GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
-  if (strcmp("Rec",driver) != 0) 
+  if (strcmp("Rec",driver) != 0 && versionflag !=0)  /* F.Leray 03.03.04*/
     {
       Scistring("\n Use the Rec driver to unzoom " );
       return;
     }
-  else 
+  else
     {
       C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-      if (version_flag() == 0){ 
+      if (version_flag() == 0){
          /***** 02/10/2002 ****/
         psonstmp = sciGetSons (sciGetCurrentFigure());
-        while (psonstmp != (sciSons *) NULL)	
-          {  
+        while (psonstmp != (sciSons *) NULL)
+          {
            if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN)
              {
                 psousfen= (sciPointObj *)psonstmp->pointobj;
@@ -1187,22 +1224,22 @@ extern void unzoom()
 		      pSUBWIN_FEATURE (psousfen)->FRect[2]   = pSUBWIN_FEATURE (psousfen)->FRect_kp[2];
 		      pSUBWIN_FEATURE (psousfen)->FRect[3]   = pSUBWIN_FEATURE (psousfen)->FRect_kp[3];
 		    }
-	  
+
 		/** regraduation de l'axe des axes ***/
 		fmin= pSUBWIN_FEATURE (psousfen)->FRect[0];
-		fmax= pSUBWIN_FEATURE (psousfen)->FRect[2]; 
+		fmax= pSUBWIN_FEATURE (psousfen)->FRect[2];
 		C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
-		pSUBWIN_FEATURE(psousfen)->axes.xlim[2]=puiss; 
-          
+		pSUBWIN_FEATURE(psousfen)->axes.xlim[2]=puiss;
+
 		fmin= pSUBWIN_FEATURE (psousfen)->FRect[1];
-		fmax= pSUBWIN_FEATURE (psousfen)->FRect[3]; 
+		fmax= pSUBWIN_FEATURE (psousfen)->FRect[3];
 		C2F(graduate)(&fmin, &fmax,&lmin,&lmax,&deux,&dix,&min,&max,&puiss) ;
 		pSUBWIN_FEATURE(psousfen)->axes.ylim[2]=puiss;
-		/*****/  
-               }     
+		/*****/
+               }
               psonstmp = psonstmp->pnext;
-            } 
-        
+            }
+
           sciSetReplay(1);
 	  sciDrawObj(sciGetCurrentFigure());
 	  sciSetReplay(0);
@@ -1270,10 +1307,10 @@ void Gr_Rescale(logf, FRectI, Xdec, Ydec, xnax, ynax)
     
   if (logf[0] == 'n') 
     { 
-      if ((version_flag() != 0) || ( pSUBWIN_FEATURE (psubwin)->axes.limits[0] !=1))
+      if ((version_flag() != 0) || ( pSUBWIN_FEATURE (psubwin)->tight_limits == FALSE))
          {
           C2F(graduate)(FRectI,FRectI+2,FRectO,FRectO+2,xnax,xnax+1,Xdec,Xdec+1,Xdec+2);
-          FRectI[0]=FRectO[0];FRectI[2]=FRectO[2];
+	  FRectI[0]=FRectO[0];FRectI[2]=FRectO[2];
          }
         
       else
@@ -1289,7 +1326,7 @@ void Gr_Rescale(logf, FRectI, Xdec, Ydec, xnax, ynax)
     }
   if (logf[1] == 'n') 
     {
-     if ((version_flag() != 0) || ( pSUBWIN_FEATURE (psubwin)->axes.limits[0] !=1))
+     if ((version_flag() != 0) || ( pSUBWIN_FEATURE (psubwin)->tight_limits == FALSE))
          {
             C2F(graduate)(FRectI+1,FRectI+3,FRectO+1,FRectO+3,ynax,ynax+1,Ydec,Ydec+1,Ydec+2);
             FRectI[1]=FRectO[1];FRectI[3]=FRectO[3];
@@ -1306,4 +1343,3 @@ void Gr_Rescale(logf, FRectI, Xdec, Ydec, xnax, ynax)
 
 
 }
-
