@@ -10,7 +10,6 @@
 #include "Math.h"
 #include "PloEch.h"
 #include "Entities.h"
-
 #ifdef __STDC__
 void wininfo(char *format,...);
 #else
@@ -115,6 +114,7 @@ static void C2F(plot3dg)(char *name, int (*func) (/* ??? */), double *x, double
   static integer cache;
   static double zmin,zmax;
   integer i,j;
+ 
   /** If Record is on **/
   if (GetDriver()=='R' && version_flag() != 0) 
     StorePlot3D(name,x,y,z,p,q,teta,alpha,legend,flag,bbox);
@@ -133,8 +133,7 @@ static void C2F(plot3dg)(char *name, int (*func) (/* ??? */), double *x, double
       zmin=bbox[4];
       zmax=bbox[5];
     }
-
-
+ 
   if ( flag[1] ==0)
     SetEch3d1(xbox,ybox,zbox,bbox,teta,alpha,0L);
   else
@@ -155,6 +154,7 @@ static void C2F(plot3dg)(char *name, int (*func) (/* ??? */), double *x, double
       cache=InsideU[0]-4;
       if (flag[2] >=2 )DrawAxis(xbox,ybox,InsideU,fg1);
     }
+ 
   polyx = graphic_alloc(0,5*(*q),sizeof(int));
   polyy = graphic_alloc(1,5*(*q),sizeof(int));
   fill  = graphic_alloc(2,(*q),sizeof(int));
@@ -163,7 +163,7 @@ static void C2F(plot3dg)(char *name, int (*func) (/* ??? */), double *x, double
       Scistring("plot3dg_ : malloc No more Place\n");
       return;
     }
-
+ 
   /** The 3d plot **/
 
   C2F(dr)("xget","lastpattern",&verbose,&whiteid,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -465,10 +465,11 @@ int DPoints1(integer *polyx, integer *polyy, integer *fill, integer whiteid, dou
     fill[jj1]= (dc < 0 ) ? -fg : fg ;
   else
     {
-    fill[jj1]=inint((whiteid-1)*((1/4.0*( z[i+(*p)*j]+ z[i+1+(*p)*j]+
-				     z[i+(*p)*(j+1)]+ z[i+1+(*p)*(j+1)])-zmin)
-			     /(zmax-zmin)))+1;
-      if ( dc < 0 ) fill[jj1]= -fill[jj1];
+      fill[jj1]=inint((whiteid-1)*((1/4.0*( z[i+(*p)*j]+ z[i+1+(*p)*j]+
+					    z[i+(*p)*(j+1)]+ z[i+1+(*p)*(j+1)])-zmin)
+				   /(zmax-zmin)))+1;
+      if ( dc < 0 ) fill[jj1]= -fill[jj1];  
+     
     }
   return(1);
   
@@ -607,6 +608,7 @@ int C2F(param3d1)(double *x, double *y, double *z, integer *m, integer *n, integ
   static integer init;
   static integer *xm,*ym;
   integer verbose=0,xz[10],narg,fg1,cur;
+
   /** If Record is on **/
   if (GetDriver()=='R' && version_flag() != 0) 
     StoreParam3D1("param3d1",x,y,z,m,n,iflag,colors,teta,alpha,legend,flag,bbox);
@@ -694,24 +696,86 @@ int C2F(param3d1)(double *x, double *y, double *z, integer *m, integer *n, integ
  *-------------------------------------------------------------------*/
 
 int C2F(box3d)(double *xbox, double *ybox, double *zbox)
-{
+{  
+ 
   static integer InsideU[4],InsideD[4],flag[]={1,1,3},verbose=0,fg,narg,fg1;
+  static integer ixbox[4],iybox[4], n=2, m=1;
+  char * legends = NULL;
+  sciPointObj * psubwin = NULL;
+  sciSubWindow * ppsubwin =  NULL;
+
+  char * legx = NULL;
+  char * legy = NULL;
+  char * legz = NULL;
   /** Calcule l' Enveloppe Convexe de la boite **/
   /** ainsi que les triedres caches ou non **/
-  Convex_Box(xbox,ybox,InsideU,InsideD,"X@Y@Z",flag,Cscale.bbox1);
-  /** le triedre vu **/
-  C2F(dr)("xget","foreground",&verbose,&fg,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  if (zbox[InsideU[0]] > zbox[InsideD[0]])
-    DrawAxis(xbox,ybox,InsideU,fg);
-  else 
-    DrawAxis(xbox,ybox,InsideD,fg);
-  C2F(dr)("xget","hidden3d",&verbose,&fg1,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  if (fg1==-1) fg1=0;
-  /** Le triedre cache **/
-  if (zbox[InsideU[0]] > zbox[InsideD[0]])
-      DrawAxis(xbox,ybox,InsideD,fg1);
-  else 
-      DrawAxis(xbox,ybox,InsideU,fg1);
+
+
+  if (version_flag() != 0)
+    Convex_Box(xbox,ybox,InsideU,InsideD,"X@Y@Z",flag,Cscale.bbox1);
+  else
+    {
+      psubwin = (sciPointObj *)sciGetSelectedSubWin (sciGetCurrentFigure ());
+      ppsubwin = pSUBWIN_FEATURE (psubwin);
+
+      legx = sciGetText(ppsubwin->mon_x_label);
+      legy = sciGetText(ppsubwin->mon_y_label);
+      legz = sciGetText(ppsubwin->mon_z_label);
+                  
+      if ((legends = MALLOC ((strlen(legx)+
+			      strlen(legy)+
+			      strlen(legz)+
+			      7)*sizeof (char))) == NULL)
+	Scistring("box3d : No more Place to store legends (3D labels)\n");
+
+      strcpy(legends,legx);
+      strcat(legends,"@"); 
+      strcat(legends,legy);
+      strcat(legends,"@"); 
+      strcat(legends,legz);
+      
+      Convex_Box(xbox,ybox,InsideU,InsideD,legends,flag,Cscale.bbox1);
+      FREE(legends); legends = NULL;
+    }
+
+
+  /**DJ.Abdemouche 2003**/
+   if (version_flag() != 0) {
+     /** le triedre vu **/
+     C2F(dr)("xget","foreground",&verbose,&fg,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+      if (zbox[InsideU[0]] > zbox[InsideD[0]])
+       DrawAxis(xbox,ybox,InsideU,fg);
+     else 
+       DrawAxis(xbox,ybox,InsideD,fg);
+     C2F(dr)("xget","hidden3d",&verbose,&fg1,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+     if (fg1==-1) fg1=0;
+     /** Le triedre cache **/
+     if (zbox[InsideU[0]] > zbox[InsideD[0]])
+       DrawAxis(xbox,ybox,InsideD,fg1);
+     else 
+       DrawAxis(xbox,ybox,InsideU,fg1);
+   }
+   else
+     {
+       C2F (dr) ("xset","thickness",&m,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);    
+       if (zbox[InsideU[0]] > zbox[InsideD[0]])
+	 DrawAxis(xbox,ybox,InsideU,2);
+       else 
+	 DrawAxis(xbox,ybox,InsideD,2);    
+       if (zbox[InsideU[0]] > zbox[InsideD[0]])
+	 DrawAxis(xbox,ybox,InsideD,2);
+       else 
+	 DrawAxis(xbox,ybox,InsideU,2);
+    
+       ixbox[0]=XScale(xbox[0]);ixbox[1]=XScale(xbox[2]);
+       ixbox[2]=XScale(xbox[1]);ixbox[3]=XScale(xbox[3]);
+       iybox[0]=YScale(ybox[0]); iybox[1]=YScale(ybox[2]);
+       iybox[2]=YScale(ybox[1]); iybox[3]=YScale(ybox[3]);
+       C2F(dr)("xpolys","v",ixbox,iybox,&n,&m,&n,PI0,PD0,PD0,PD0,PD0,0L,0L);  
+       C2F(dr)("xpolys","v",ixbox+2,iybox+2,&n,&m,&n,PI0,PD0,PD0,PD0,PD0,0L,0L); 
+
+     }
+
   return(0);
 }
 
@@ -826,7 +890,7 @@ void SetEch3d1(double *xbox, double *ybox, double *zbox, double *bbox, double *t
   if ( flag == 2 || flag == 3 )
     {
 /* get current window size */
-      C2F(dr)("xget","wdim",&verbose,wdim,&narg, PI0,PI0,PI0,\
+      C2F(dr)("xget","wdim",&verbose,wdim,&narg, PI0,PI0,PI0,
               PD0,PD0,PD0,PD0,0L,0L);
       getscale2d(WRect,FRect,logf,ARect);
       wmax=linint((double)wdim[0] * WRect[2]);
@@ -880,8 +944,9 @@ void SetEch3d1(double *xbox, double *ybox, double *zbox, double *bbox, double *t
 
 void DrawAxis(double *xbox, double *ybox, integer *Indices, integer style)
 {
-  integer ixbox[6],iybox[6],npoly=6,lstyle[6],verbose=0,narg;
-  integer i,iflag=0;
+  integer ixbox[6],iybox[6],npoly=6,lstyle[6],verbose=0,narg,hiddencolor;
+  integer i, iflag=0, j=1;
+  sciPointObj *psubwin;
   for ( i = 0 ; i <= 4 ; i=i+2)
     {
       ixbox[i]=XScale(xbox[Indices[0]]);iybox[i]=YScale(ybox[Indices[0]]);
@@ -890,7 +955,17 @@ void DrawAxis(double *xbox, double *ybox, integer *Indices, integer style)
   ixbox[3]=XScale(xbox[Indices[2]]);iybox[3]=YScale(ybox[Indices[2]]);
   ixbox[5]=XScale(xbox[Indices[3]]);iybox[5]=YScale(ybox[Indices[3]]);
   C2F(dr)("xget","line style",&verbose,lstyle,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L); 
-  C2F(dr)("xset","line style",(i=1,&i),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+  /**DJ.Abdemouche 2003**/
+  if (version_flag() == 0) { 
+    psubwin = sciGetSelectedSubWin (sciGetCurrentFigure ()); 
+    hiddencolor = pSUBWIN_FEATURE (psubwin)->hiddencolor;    
+    if (hiddencolor == style ) 
+      j= 2;
+    else
+      j=sciGetLineStyle (psubwin);
+  }	
+    /***/  
+  C2F(dr)("xset","line style",&j,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xsegs","v",ixbox,iybox,&npoly,&style,&iflag,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xset","line style",lstyle,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 
@@ -976,19 +1051,23 @@ void Convex_Box(double *xbox, double *ybox, integer *InsideU, integer *InsideD,
    }
   ixbox[6]=ixbox[0];iybox[6]=iybox[0];
   p=7,n=1;
-  C2F(dr)("xget","foreground",&verbose,dvect,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  /** On trace l'enveloppe cvxe **/
+  /**DJ.Abdemouche 2003**/
+  if (version_flag() != 0) 
+    C2F(dr)("xget","foreground",&verbose,dvect,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+  else
+   dvect[0]=2;       
+     /** On trace l'enveloppe cvxe **/
   C2F(dr)("xget","line style",&verbose,dash,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xset","line style",(j=1,&j),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-    
+  C2F (dr) ("xset","thickness",(j=1,&j),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);     /**DJ.Abdemouche 2003**/	   
   if (flag[2]>=3){
     C2F(dr)("xpolys","v",ixbox,iybox,dvect,&n,&p
-	    ,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  }
+        ,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    }
   C2F(dr)("xget","pattern",&verbose,&pat,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  C2F(dr)("xset","pattern",dvect,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-
-  if (flag[2]>=3)AxesStrings(flag[2],ixbox,iybox,xind,legend,bbox);
+  C2F(dr)("xset","pattern",dvect,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L); 
+  if (flag[2]>=3)
+    AxesStrings(flag[2],ixbox,iybox,xind,legend,bbox);
   C2F(dr)("xset","pattern",&pat,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xset","line style",dash,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 
@@ -1006,7 +1085,7 @@ void AxesStrings(integer axflag, integer *ixbox, integer *iybox, integer *xind,
   char *loc,*legx,*legy,*legz; 
   integer rect[4],flag=0,x,y;
   double ang=0.0;
-  loc=(char *) MALLOC( (strlen(legend)+1)*sizeof(char));
+   loc=(char *) MALLOC( (strlen(legend)+1)*sizeof(char));
   if ( loc == 0)    
     {
       Scistring("AxesString : No more Place to store Legends\n");
@@ -1017,7 +1096,11 @@ void AxesStrings(integer axflag, integer *ixbox, integer *iybox, integer *xind,
   /** le cot\'e gauche ( c'est tjrs un axe des Z **/
   C2F(dr)("xget","wdim",&verbose,xz,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   iof = (xz[0]+xz[1])/50;
-  x=ixbox[2]-iof ;y=iybox[2]-iof;
+  if (version_flag() != 0) 
+    {x=ixbox[2]-iof ;y=iybox[2]-iof;}
+  else
+    {x = (integer) (ixbox[2]-(xz[0]+xz[1])/20) ; y = (integer) (0.5*iybox[3]+0.5*iybox[2]);}
+ /*** le z scaling ***/
   if ( axflag>=4)
     {
       double fx,fy,fz,lx,ly,lz;
@@ -1035,11 +1118,15 @@ void AxesStrings(integer axflag, integer *ixbox, integer *iybox, integer *xind,
     {
       C2F(dr)("xstringl",legz,&x,&y,rect,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(dr)("xstring",legz,(x=x - rect[2],&x),&y,PI0,&flag
-	  ,PI0,PI0,&ang,PD0,PD0,PD0,0L,0L);
+          ,PI0,PI0,&ang,PD0,PD0,PD0,0L,0L);
     }
   /** le cot\^e en bas \`a gauche **/
-  x=inint((ixbox[3]+ixbox[4])/2.0 -iof);
-  y=inint((1/3.0)*iybox[3]+(2/3.0)*iybox[4]+iof);
+  if (version_flag() != 0) {
+    x=inint((ixbox[3]+ixbox[4])/2.0 -iof);
+    y=inint((1/3.0)*iybox[3]+(2/3.0)*iybox[4]+iof);}
+  else{
+    x=inint((ixbox[3]+ixbox[4])/2.0 -iof);
+    y=inint((1/3.0)*iybox[3]+(2/3.0)*iybox[4]+(xz[0]+xz[1])/30);}
   if ( xind[3]+xind[4] == 3)
     {
       if ( axflag>=4)
@@ -1087,8 +1174,12 @@ void AxesStrings(integer axflag, integer *ixbox, integer *iybox, integer *xind,
 	}
     }
   /** le cot\'e en bas a droite **/
-  x=inint((ixbox[4]+ixbox[5])/2+iof);
-  y=inint(((2/3.0)*iybox[4]+(1/3.0)*iybox[5])+iof);
+  if (version_flag() != 0) {
+    x=inint((ixbox[4]+ixbox[5])/2+iof);
+    y=inint(((2/3.0)*iybox[4]+(1/3.0)*iybox[5])+iof); }
+  else{
+    x=inint((ixbox[4]+ixbox[5])/2+(xz[0]+xz[1])/30);
+    y=inint(((2/3.0)*iybox[4]+(1/3.0)*iybox[5])+iof); }
   if ( xind[4]+xind[5] == 3)
     {
       if ( axflag>=4)
@@ -1128,10 +1219,11 @@ void AxesStrings(integer axflag, integer *ixbox, integer *iybox, integer *xind,
 	{
 	  C2F(dr)("xstring",legy,&x,&y,PI0,&flag,PI0,PI0,&ang,PD0,PD0,PD0,0L,0L);
 	}
-    }
+    }  
   FREE(loc);
 }
 
+
 void MaxiInd(double *vect, integer n, integer *ind, double maxi)
 {
   integer i ;
@@ -1160,7 +1252,6 @@ void DownNext(integer ind1, integer *ind2, integer *ind3)
   if (*ind3 == -1) *ind3 = 3;
 }
 
-
 void TDAxis(integer flag, double FPval, double LPval, integer *nax, integer *FPoint, integer *LPoint, integer *Ticsdir)
 {
   char fornum[100];
@@ -1168,7 +1259,7 @@ void TDAxis(integer flag, double FPval, double LPval, integer *nax, integer *FPo
   double xp, dx,dy,ticsx,ticsy,size;
   integer verbose=0,narg,xz[2];
   C2F(dr)("xget","wdim",&verbose,xz,&narg, PI0, PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-  size = xz[0]>=xz[1] ? xz[1]/50.0 : xz[0]/50.0;
+  size = xz[0]>=xz[1] ? xz[1]/50.0 : xz[0]/50.0; 
   C2F(TDdrawaxis)(size,FPval,LPval,nax,FPoint,LPoint,Ticsdir) ;
   ChoixFormatE(fornum,Min(FPval,LPval),Max(LPval,FPval),
 	       Abs((LPval-FPval))/nax[1]);
@@ -1176,7 +1267,7 @@ void TDAxis(integer flag, double FPval, double LPval, integer *nax, integer *FPo
   barlength=inint(1.2*size);
   dx= ((double) LPoint[0]-FPoint[0])/((double)nax[1]);
   dy= ((double) LPoint[1]-FPoint[1])/((double)nax[1]);
-  if ( Ticsdir[0] == 0 && Ticsdir[1] == 0) 
+   if ( Ticsdir[0] == 0 && Ticsdir[1] == 0) 
     {
       ticsx= ticsy = 0;
     }
@@ -1194,7 +1285,7 @@ void TDAxis(integer flag, double FPval, double LPval, integer *nax, integer *FPo
       char foo[100];/*** JPC : must be cleared properly **/
       double lp;
       lp = xp + i*(LPval-FPval)/((double)nax[1]);
-      sprintf(foo,fornum,lp);
+      sprintf(foo,fornum,lp);   
       C2F(dr)("xstringl",foo,&xx,&yy,rect,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       posi[0]=inint(FPoint[0]+ i*dx + 2*ticsx );
       posi[1]=inint(FPoint[1]+ i*dy + 2*ticsy +rect[3]/2 );
@@ -1207,7 +1298,7 @@ void TDAxis(integer flag, double FPval, double LPval, integer *nax, integer *FPo
 	case 2: posi[0] -= rect[2];break;
 	}
       C2F(dr)("xstring",foo,&(posi[0]),&(posi[1]),PI0,&flag1,PI0,PI0,&angle,PD0,PD0,PD0,0L,0L);
-    }
+    } 
 }
 
 
@@ -1263,45 +1354,44 @@ void BBoxToval(double *x, double *y, double *z, integer ind, double *bbox)
 
 /** Changement interactif de 3d **/
 static double theta,alpha;
-
-void I3dRotation(void)
+/* return 1 if figure has been close during rotation */
+int I3dRotation(void)
 {
   char driver[4];
   integer flag[3],pixmode,alumode,verbose=0,narg,ww;
   static integer iflag[]={0,0,0,0};
   double xx,yy;
   double theta0,alpha0;
+  static int one=1;
+
   static integer modes[]={1,0};/* for xgemouse only get mouse mouvement*/ 
   sciSons *psonstmp;
-  sciPointObj *psubwin, *tmpsubwin, *psurface; 
+  sciPointObj *psubwin, *tmpsubwin;
+  sciPointObj *pold = NULL;
+  /*  sciPointObj *psurface; */
   integer xr, yr;
 
+  BOOL cube_scaling; /* TEST F.Leray 22.04.04 */
+
 
   C2F(dr1)("xget","window",&verbose,&ww,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   if (version_flag() != 0) {
     if ( Check3DPlots("v",&ww) == 0) 
       {
 	wininfo("No 3d recorded plots in your graphic window");
-	return;
+	return 0;
       }
   }
-  else {
-    if ( !Check3DObjs()) 
-      {
-	wininfo("No 3d entities in your graphic window");
-	return;
-      }
-  }
-  xx=1.0/Abs(Cscale.frect[0]-Cscale.frect[2]);
-  yy=1.0/Abs(Cscale.frect[1]-Cscale.frect[3]);
+
+  /**DJ.Abdemouche 2003**/
   C2F(dr)("xget","pixmap",&verbose,&pixmode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xget","alufunction",&verbose,&alumode,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 
   GetDriver1(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
   if (strcmp("Rec",driver) != 0 && version_flag() !=0) 
     {
-      Scistring("\n Use the Rec driver for 3f Rotation " );
-      return;
+      wininfo("Use the Rec driver for 3d Rotation" );
+      return 0;
     }
   else 
     {
@@ -1317,47 +1407,61 @@ void I3dRotation(void)
       if (version_flag() != 0)
 	C2F(SetDriver)("X11",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
 #endif
-      if ( pixmode == 0 ) C2F(dr1)("xset","alufunction",(in=6,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-      C2F(dr1)("xclick","one",&ibutton,&iwait,&istr,PI0,PI0,PI0,&x0,&yy0,PD0,PD0,0L,0L);
+      C2F(dr)("xclick","one",&ibutton,&xr,&yr,&iwait,&istr,PI0,PD0,PD0,PD0,PD0,0L,0L);
+      /*C2F(dr1)("xclick","one",&ibutton,&iwait,&istr,PI0,PI0,PI0,&x0,&yy0,PD0,PD0,0L,0L);*/
       if (version_flag() != 0)
 	C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+#ifdef WIN32
+      ReleaseWinHdc();
+      SciMouseRelease();
+#endif
       theta=Cscale.theta ;
       alpha=Cscale.alpha ;
-
-      x0=(x0-Cscale.frect[0])*xx;
-      yy0=(yy0-Cscale.frect[1])*yy;
-      x=x0;y=yy0;
       theta0=theta;
       alpha0=alpha;
+
       ibutton=-1;
       if (version_flag() == 0)
 	{
-	  tmpsubwin = (sciPointObj *) sciGetSelectedSubWin (sciGetCurrentFigure ());          
-	  xr=inint( ((double) Cscale.wdim[0]*pSUBWIN_FEATURE(tmpsubwin)->WRect[2]*
-		     (1-(Cscale.axis[0]+Cscale.axis[1])))*(x0) + 
-		    (((double) Cscale.wdim[0]*pSUBWIN_FEATURE(tmpsubwin)->WRect[2])*(Cscale.axis[0])
-		     +pSUBWIN_FEATURE(tmpsubwin)->WRect[0]*((double)Cscale.wdim[0])));
-	  yr=inint(((double) Cscale.wdim[1]*pSUBWIN_FEATURE(tmpsubwin)->WRect[3]*
-		    (1-(Cscale.axis[2]+Cscale.axis[3])))*(-(yy0)+1) + 
-		   (((double) Cscale.wdim[1]*pSUBWIN_FEATURE(tmpsubwin)->WRect[3])*(Cscale.axis[2])
-		    + pSUBWIN_FEATURE(tmpsubwin)->WRect[1]*((double)Cscale.wdim[1])));
+	  tmpsubwin = (sciPointObj *) sciGetSelectedSubWin (sciGetCurrentFigure ());   
           if (pFIGURE_FEATURE((sciPointObj *)sciGetCurrentFigure())->rotstyle == 0)    
 	    {
 	      psubwin = (sciPointObj *)CheckClickedSubwin(xr,yr);
-	      psurface = (sciPointObj *) sciGetSurface(psubwin); 
-	      if (psurface != (sciPointObj *)NULL)
+	      /**DJ.Abdemouche 2003**/
+	      if((sciPointObj *) psubwin != NULL)
 		{
 		  sciSetSelectedSubWin (psubwin);
-		  theta0 =  pSURFACE_FEATURE (psurface)-> theta; 
-		  alpha0 =  pSURFACE_FEATURE (psurface)-> alpha;
-		}
-	      else 
-		{
-		  wininfo("Is not a 3d Entity");
-		  if ( pixmode == 0) 
-		    C2F(dr1)("xset","alufunction",(in=3,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-		  return;
+
+		  theta0 =  pSUBWIN_FEATURE (psubwin)-> theta; 
+		  alpha0 =  pSUBWIN_FEATURE (psubwin)-> alpha;
+		  pSUBWIN_FEATURE (psubwin)-> is3d = TRUE;
+		  Cscale.metric3d = (long)(pSUBWIN_FEATURE (psubwin)->axes.flag[1]+1)/2; 
+
+		  /* Modif. HERE F.Leray 24.05.04 : we take advantage of update_specification_bounds and update_3dbounds previous call */
+		  /* brect variable should not exist any more.*/
+		  Cscale.bbox1[0] = pSUBWIN_FEATURE (psubwin)->FRect[0]; 
+		  Cscale.bbox1[1] = pSUBWIN_FEATURE (psubwin)->FRect[2];
+		  Cscale.bbox1[2] = pSUBWIN_FEATURE (psubwin)->FRect[1];
+		  Cscale.bbox1[3] = pSUBWIN_FEATURE (psubwin)->FRect[3];
+		  Cscale.bbox1[4] = pSUBWIN_FEATURE (psubwin)->FRect[4];
+		  Cscale.bbox1[5] = pSUBWIN_FEATURE (psubwin)->FRect[5];
+		  
+		  cube_scaling =  pSUBWIN_FEATURE (psubwin)->cube_scaling;
+		  if(cube_scaling == TRUE)
+		    {
+		      Cscale.bbox1[0] =  0.; 
+		      Cscale.bbox1[1] =  1.;
+		      Cscale.bbox1[2] =  0.;
+		      Cscale.bbox1[3] =  1.;
+		      Cscale.bbox1[4] =  0.;
+		      Cscale.bbox1[5] =  1.;
+		    }
 		}
+	      else
+              {
+		wininfo("No 3d object selected");
+		return 0;
+	      }
 	    }
           else
 	    {                  
@@ -1371,6 +1475,22 @@ void I3dRotation(void)
 	      sciSetSelectedSubWin (psonstmp->pointobj);
 	    } 
 	}
+      xx=1.0/Abs(Cscale.frect[0]-Cscale.frect[2]);
+      yy=1.0/Abs(Cscale.frect[1]-Cscale.frect[3]);
+
+      C2F(echelle2d)(&x0,&yy0,&xr,&yr,&one,&one,"i2f",3L);
+      x0=(x0-Cscale.frect[0])*xx;
+      yy0=(yy0-Cscale.frect[1])*yy;
+      x=x0;y=yy0;
+
+#ifdef WIN32
+      SetWinhdc();
+      SciMouseCapture();
+#endif
+      if (version_flag() != 0)
+	C2F(dr1)("xclear","v",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+      if ( pixmode == 0 ) C2F(dr1)("xset","alufunction",(in=6,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+    
       while ( ibutton == -1 ) 
 	{
 	  /* dessin d'un rectangle */
@@ -1380,13 +1500,14 @@ void I3dRotation(void)
 	  if ( pixmode == 1) C2F(dr1)("xset","wwpc",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
 	  dbox();
 	  if ( pixmode == 1) C2F(dr1)("xset","wshow",PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-	    C2F(dr1)("xgetmouse","one",&ibutton,&iwait,PI0,PI0,modes,PI0,&xl, &yl,PD0,PD0,0L,0L);
-	    /* effacement du rectangle */
-	    dbox();
-	    xx=1.0/Abs(Cscale.frect[0]-Cscale.frect[2]);
-	    yy=1.0/Abs(Cscale.frect[1]-Cscale.frect[3]);
-	    x=(xl-Cscale.frect[0])*xx;
-	    y=(yl-Cscale.frect[1])*yy;
+	  C2F(dr1)("xgetmouse","one",&ibutton,&iwait,PI0,PI0,modes,PI0,&xl, &yl,PD0,PD0,0L,0L);
+	  if (ibutton==-100) return 1;/* window has been closed */
+	  /* effacement du rectangle */
+	  dbox();
+	  xx=1.0/Abs(Cscale.frect[0]-Cscale.frect[2]);
+	  yy=1.0/Abs(Cscale.frect[1]-Cscale.frect[3]);
+	  x=(xl-Cscale.frect[0])*xx;
+	  y=(yl-Cscale.frect[1])*yy;
 	}
       if ( pixmode == 0) C2F(dr1)("xset","alufunction",(in=3,&in),PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
       C2F(SetDriver)(driver,PI0,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
@@ -1402,15 +1523,23 @@ void I3dRotation(void)
 	Tape_ReplayNewAngle("v",&ww,PI0,PI0,iflag,flag,PI0,&theta,&alpha,bbox,PD0);
       else
 	{  
-          if (pFIGURE_FEATURE((sciPointObj *)sciGetCurrentFigure())->rotstyle == 0)         
+          if (pFIGURE_FEATURE((sciPointObj *)sciGetCurrentFigure())->rotstyle == 0){
+	    pold = (sciPointObj *)sciGetSelectedSubWin (sciGetCurrentFigure ());
+	    sciSetSelectedSubWin(psubwin);
 	    Obj_RedrawNewAngle(psubwin,theta,alpha);
+	    sciSetSelectedSubWin(pold);
+	  }
 	  else
             { 
 	      psonstmp = sciGetSons (sciGetCurrentFigure());  
 	      while (psonstmp != (sciSons *) NULL)	
 		{  
-		  if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN) 
+		  if(sciGetEntityType (psonstmp->pointobj) == SCI_SUBWIN){
+		    pold = (sciPointObj *)sciGetSelectedSubWin (sciGetCurrentFigure ());
+		    sciSetSelectedSubWin(psonstmp->pointobj);
 		    Obj_RedrawNewAngle(psonstmp->pointobj,theta,alpha);
+		    sciSetSelectedSubWin(pold);
+		  }
 		  psonstmp = psonstmp->pnext;
 		} 
             }
@@ -1418,6 +1547,7 @@ void I3dRotation(void)
 	  sciSetSelectedSubWin (tmpsubwin);
 	}
     }
+  return 0;
 }
 
 /*
@@ -1431,11 +1561,12 @@ static void dbox(void)
 {
   double xbox[8],ybox[8],zbox[8];
 #ifdef WIN32
-  integer verbose=0,pat,pat1=3,narg;
+  integer verbose=0,pat,pat1=3,narg,un=1;
   C2F(dr)("xget","pattern",&verbose,&pat,&narg,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
   C2F(dr)("xset","pattern",&pat1,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
-#endif
-  SetEch3d1(xbox,ybox,zbox,Cscale.bbox1,&theta,&alpha,Cscale.metric3d);
+  C2F (dr) ("xset", "line style",&un,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+#endif/**DJ.Abdemouche 2003**/
+SetEch3d1(xbox,ybox,zbox,Cscale.bbox1,&theta,&alpha,Cscale.metric3d);
   C2F(box3d)(xbox,ybox,zbox);
 #ifdef WIN32
   C2F(dr)("xset","pattern",&pat,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
@@ -1600,9 +1731,3 @@ int shade(integer *polyx, integer *polyy, integer *fill, integer polysize, integ
 
 
 
-
-
-
-
-
-
