@@ -218,7 +218,7 @@ void StorePlot(char *name, char *xf, double *x, double *y, integer *n1, integer
  * axis  
  *---------------------------------------------------------------------------*/
 
-void StoreSciAxis(char *name, char pos, char xy_type, double *x, int *nx, double *y, int *ny, char **str, int subtics, char *format, int fontsize, int textcolor, int ticscolor, char logflag, int seg_flag)
+void StoreSciAxis(char *name, char pos, char xy_type, double *x, int *nx, double *y, int *ny, char **str, int subtics, char *format, int fontsize, int textcolor, int fontstyle, int ticscolor, char logflag, int seg_flag)
 {
   struct sciaxis_rec *lplot = ((struct sciaxis_rec *) MALLOC(sizeof(struct sciaxis_rec)));
   if (lplot == NULL)
@@ -2043,7 +2043,7 @@ static void UnSCNEch(char *plot)
 /*** code added by ES 21/5/2002 ****/
 static void UnSCContour(char *plot)
 {
-  int i;
+  /*  int i;*/
   struct contour_rec *theplot;
   theplot =   (struct contour_rec *) plot;
   {
@@ -2057,7 +2057,7 @@ static void UnSCContour(char *plot)
 
 static void UnSCFac3D(char *plot)
 {
-  int i;
+  /*  int i;*/
   struct fac3d_rec *theplot;
   theplot =   (struct fac3d_rec *) plot;
   {
@@ -2073,7 +2073,7 @@ static void UnSCFac3D(char *plot)
 
 static void UnSCParam3D(char *plot)
 {
-  int i;
+  /*  int i;*/
   struct param3d_rec *theplot;
   theplot =   (struct param3d_rec *) plot;
   {
@@ -2086,7 +2086,7 @@ static void UnSCParam3D(char *plot)
 
 static void UnSCParam3D1(char *plot)
 {
-  int i;
+  /*  int i;*/
   struct param3d1_rec *theplot;
   theplot =   (struct param3d1_rec *) plot;
   {
@@ -2102,7 +2102,7 @@ static void UnSCParam3D1(char *plot)
 
 static void UnSCPlot3D(char *plot)
 {
-  int i;
+  /*  int i;*/
   struct plot3d_rec *theplot;
   theplot =   (struct plot3d_rec *) plot;
   {
@@ -2322,12 +2322,25 @@ void Tape_Replay(char *unused, integer *winnumber, integer *v3, integer *v4, int
     }
 }
 
+/* old version : we can reach the recursion stack limit 
+
 static void Tape_Replay1(struct listplot *list, integer winnumber)
 {
   if (list->window == winnumber) GReplay(list->type,list->theplot);
   if (list->ptrplot != NULL) Tape_Replay1(list->ptrplot,winnumber);
 }
 
+*/
+
+static void Tape_Replay1(struct listplot *list, integer winnumber)
+{
+  while (list)
+    {
+      if (list->window == winnumber )  GReplay(list->type,list->theplot);
+      list =list->ptrplot;
+    }
+}
+
 static void Replay3D(char *theplot)
 {
   struct plot3d_rec *pl3d;
@@ -2508,8 +2521,9 @@ static void Replay2D(char *theplot)
 static void ReplaySciAxis(char *theplot)
 {
   struct sciaxis_rec *p = (struct sciaxis_rec *) theplot;
+  int fontstyle = 0;
   sci_axis(p->pos,p->xy_type,p->x,&p->nx,p->y,&p->ny,p->str,p->subtics,p->format,p->fontsize,p->textcolor,
-	   p->ticscolor,p->logflag,p->seg_flag);
+	   fontstyle,p->ticscolor,p->logflag,p->seg_flag);
 
 }
 
@@ -2639,7 +2653,7 @@ static void GReplay(char *type, char *plot)
 
 
 /*---------------------------------------------------------------------
- * Add a new graphics record in the graphic recorder lisy 
+ * Add a new graphics record in the graphic recorder list 
  *---------------------------------------------------------------------------*/
 
 int Store(char *type, char *plot)
