@@ -12,6 +12,8 @@
 #include "Math.h"
 #include "Rec.h"
 
+extern void  xdrstdio_create();
+
 static int SaveTPlot __PARAMS((char *type, char *plot));
 static int SaveD  __PARAMS((double x));
 static int SaveLI __PARAMS((integer ix));
@@ -473,11 +475,24 @@ static SaveTable SaveCTable[] ={
 #define __STDC__
 #endif 
 
+extern int version_flag(void); /* NG */
+
 int C2F(xsaveplots)(integer *winnumber, char *fname1, integer lxv)
 {
   static char endplots[]={"endplots"};
   static char scig[]={"SciG1.1"};
   struct listplot *list;
+  int verb=0,cur,na;
+
+
+  C2F(dr)("xget","window",&verb,&cur,&na,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+  C2F(dr)("xset","window",winnumber,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+  if (version_flag() == 0) {
+    sciprint("New style plot save is not yet implemented\n");
+    C2F(dr)("xset","window",&cur,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0,0L,0L);
+  }
+  else {
+
 #ifdef lint 
   *unused;
 #endif
@@ -510,6 +525,7 @@ int C2F(xsaveplots)(integer *winnumber, char *fname1, integer lxv)
   SaveVectC(endplots,((int)strlen(endplots))+1) ;
   assert(fflush((FILE *)xdrs->x_private) != EOF) ; 
   assert(fclose(F) != EOF) ;
+  }
   return(0);
 }
 
