@@ -20,8 +20,8 @@
 #endif
 
 #if defined(THINK_C)|| defined(WIN32)
-#define CoordModePrevious 0
-#define CoordModeOrigin 1
+#define CoordModePrevious 1
+#define CoordModeOrigin 0
 #define GXclear 0
 #define GXand 1
 #define GXandReverse 2
@@ -48,7 +48,7 @@
 
 #define WHITE 7
 #define BLACK 0
-
+extern int versionflag;
 
 void C2F(Write2VectXfig)(integer *vx, integer *vy, integer n, integer flag); 
 void C2F(WriteGenericXfig)(char *string, integer nobj, integer sizeobj, integer *vx, integer *vy, integer sizev, integer flag, integer *fvect);
@@ -80,18 +80,18 @@ static void set_dash_or_color (int dash,int *l_style,int *style_val,int *color);
 static double *vdouble = 0; /* used when a double argument is needed */
 /** Global variables to deal with fonts **/
 
-#define FONTNUMBER 7
+#define FONTNUMBER 11
 #define FONTMAXSIZE 6
 #define SYMBOLNUMBER 10
 integer FontsListXfig_[FONTNUMBER][FONTMAXSIZE];
 struct SciFontInfo { integer ok;
-		  char fname[20];} FontInfoTabXfig_[FONTNUMBER];
+		  char fname[21];} FontInfoTabXfig_[FONTNUMBER];
 /** xfig code for our fonts **/
-static integer  xfig_font[]= { 12,32,0,1,2,3,0};
+static integer  xfig_font[]= { 12,32,0,1,2,3,16,17,18,19,0};
 static char *sizeXfig_[] = { "08" ,"10","12","14","18","24"};
 static integer  isizeXfig_[] = { 8,10,12,14,18,24};
 
-#if defined(__CYGWIN32__) || defined(__MINGW32__) || defined(__GNUC__) || defined(__MSC__)
+#if defined(__CYGWIN32__) || defined(__MINGW32__) || defined(__GNUC__) || defined(__MSC__)|| defined(__EDG__)
 static FILE *file= (FILE *) 0;
 #define FPRINTF(x) ( file != (FILE*) 0) ?  fprintf x  : 0 
 #else 
@@ -776,20 +776,38 @@ void C2F(gethidden3dXfig)(integer *verbose, integer *num, integer *narg, double
 
 /** To set the current font id of font and size **/
 
+/* void C2F(xsetfontXfig)(integer *fontid, integer *fontsize, integer *v3, integer *v4) */
+/* { integer i,fsiz; */
+/*   i = Min(FONTNUMBER-1,Max(*fontid,0)); */
+/*   fsiz = Min(FONTMAXSIZE-1,Max(*fontsize,0)); */
+/*   if ( FontInfoTabXfig_[i].ok !=1 ) */
+/*     Scistring("\n Sorry This Font is Not available\n"); */
+/*   else  */
+/*    { */
+/*      ScilabGCXfig.FontId = i; */
+/*      ScilabGCXfig.FontSize = fsiz; */
+/*      FPRINTF((file,"#/%s findfont %d scalefont setfont\n", */
+/*      	     FontInfoTabXfig_[i].fname, */
+/* 	     (int)isizeXfig_[fsiz]*prec_fact)); */
+/*    } */
+/* } */
+
 void C2F(xsetfontXfig)(integer *fontid, integer *fontsize, integer *v3, integer *v4)
-{ integer i,fsiz;
+{ 
+  integer i,fsiz;
   i = Min(FONTNUMBER-1,Max(*fontid,0));
   fsiz = Min(FONTMAXSIZE-1,Max(*fontsize,0));
   if ( FontInfoTabXfig_[i].ok !=1 )
-    Scistring("\n Sorry This Font is Not available\n");
-  else 
-   {
-     ScilabGCXfig.FontId = i;
-     ScilabGCXfig.FontSize = fsiz;
-     FPRINTF((file,"#/%s findfont %d scalefont setfont\n",
-     	     FontInfoTabXfig_[i].fname,
-	     (int)isizeXfig_[fsiz]*prec_fact));
-   }
+    {
+      /* currently this case occurs only when i=FONTNUMBER-1 */
+      Scistring("\n Sorry This Font is Not available: use default font (Times)\n");
+      i = 2;
+    }
+  ScilabGCXfig.FontId = i;
+  ScilabGCXfig.FontSize = fsiz;
+  FPRINTF((file,"#/%s findfont %d scalefont setfont\n",
+	   FontInfoTabXfig_[i].fname,
+	   (int)isizeXfig_[fsiz]*prec_fact));
 }
 
 /** To get the values id and size of the current font **/
@@ -955,11 +973,13 @@ void C2F(ScilabGCGetorSetXfig)(char *str, integer flag, integer *verbose, intege
 	 { if ( j <= 0)
 	     {
 	       sciprint("\nUnknow Postscript operator <%s>\r\n",str);
+	       *x1=1;*x2=0;
 	       return;
 	     }
 	 }
      }
   sciprint("\n Unknow Postscript operator <%s>\r\n",str);
+  *x1=1;*x2=0;
 }
 
 /*-----------------------------------------------------------
@@ -1013,12 +1033,12 @@ void C2F(displaystringXfig)(char *string, integer *x, integer *y, integer *v1, i
     }
 }
 
-integer bsizeXfig_[6][4]= {{ 0,-7,463,9  },
-		{ 0,-9,574,12 },
-		{ 0,-11,674,14},
-		{ 0,-12,779,15},
-		{0, -15,972,19 },
-		{0,-20,1341,26}};
+integer bsizeXfig_[6][4]= {{ 0, -7,  463, 9  },
+			   { 0, -9,  574, 12 },
+			   { 0, -11, 674, 14 },
+			   { 0, -12, 779, 15 },
+			   { 0, -15, 972, 19 },
+			   { 0, -20,1341, 26 }};
 
 /** To get the bounding rectangle of a string **/
 
@@ -1098,6 +1118,9 @@ void C2F(drawsegmentsXfig)(char *str, integer *vx, integer *vy, integer *n, inte
   integer verbose=0,Dnarg,Dvalue[10],Dvalue1[10];
   /* store the current values */
 
+  /* F.Leray 08.03.04 Init. here for Dvalue[0]: Pb here what is the correct value for Dvalue[0] ?? */
+  Dvalue[0] = 1;
+
   for ( i =0 ; i < *n/2 ; i++)
     {
       if ( (int) *iflag == 0) 
@@ -1295,16 +1318,16 @@ void C2F(drawarcXfig_old)(char *str, integer *x, integer *y, integer *width, int
 void C2F(drawarcXfig)(char *str, integer *x, integer *y, integer *width, integer *height, integer *angle1, integer *angle2, double *dv1, double *dv2, double *dv3, double *dv4)
 { 
   integer vx[365],vy[365],k,n;
-  float alpha,fact=0.01745329251994330,w,h;
+  float alpha,fact= (float) 0.01745329251994330,w,h;
   integer close = 0;
 
-  w = (*width)/2.0;
-  h = (*height)/2.0;
+  w = (float) ((*width)/2.0);
+  h = (float) ((*height)/2.0);
   n=Min((*angle2/64),360);
   for (k = 0; k < n; ++k) {
     alpha=((*angle1/64)+k)*fact;
-    vx[k] = *x + w*(cos(alpha)+1.0);
-    vy[k] = *y + h*(-sin(alpha)+1.0);}
+    vx[k] = (integer) (*x + w*(cos(alpha)+1.0));
+    vy[k] = (integer) (*y + h*(-sin(alpha)+1.0));}
     
   C2F(drawpolylineXfig)(str, &n, vx, vy, &close, PI0, PI0, dv1, dv2, dv3, dv4);
 }
@@ -1328,30 +1351,30 @@ void C2F(fillarcXfig_old)(char *str, integer *x, integer *y, integer *width, int
 void C2F(fillarcXfig)(char *str, integer *x, integer *y, integer *width, integer *height, integer *angle1, integer *angle2, double *dv1, double *dv2, double *dv3, double *dv4)
 { 
   integer vx[365],vy[365],k,k0,kmax,n;
-  float alpha,fact=0.01745329251994330,w,h;
+  float alpha,fact= (float) 0.01745329251994330,w,h;
   integer close = 1;
 
   n=Min((*angle2/64),360);
 
-  w = (*width)/2.0;
-  h = (*height)/2.0;
+  w = (float) ((*width)/2.0);
+  h = (float) ((*height)/2.0);
   k0 = 0;
   kmax = n-1;
 
   if (n != 360) {
-  vx[0] = *x + w;
-  vy[0] = *y + h;
+  vx[0] = (integer) (*x + w);
+  vy[0] = (integer) (*y + h);
   k0 = 1;
   kmax = n;}
 
   for (k = k0; k <= kmax; ++k) {
     alpha=((*angle1/64)+k)*fact;
-    vx[k] = *x + w*(cos(alpha)+1.0);
-    vy[k] = *y + h*(-sin(alpha)+1.0);}
+    vx[k] = (integer) (*x + w*(cos(alpha)+1.0));
+    vy[k] = (integer) (*y + h*(-sin(alpha)+1.0));}
   if (n != 360) {
   n++;
-  vx[n] = *x + ((*width)/2.0);
-  vy[n] = *y + ((*height)/2.0); 
+  vx[n] = (integer) (*x + ((*width)/2.0));
+  vy[n] = (integer) (*y + ((*height)/2.0)); 
   n++;
   }
   C2F(fillpolylineXfig)(str, &n, vx, vy, &close, PI0, PI0, dv1, dv2, dv3, dv4);
@@ -1408,7 +1431,8 @@ void C2F(drawpolylinesXfig)(char *str, integer *vectsx, integer *vectsy, integer
 	{ /** on utilise la marque de numero associ\'ee **/
 	  NDvalue = - drawvect[i] ;
 	  C2F(setcursymbolXfig)(&NDvalue,symb+1,PI0,PI0);
-          C2F(setdashXfig)(Dvalue,PI0,PI0,PI0);
+	  C2F(setdashXfig)(Dvalue,PI0,PI0,PI0);
+	 
 	  C2F(drawpolymarkXfig)(str,p,vectsx+(*p)*i,vectsy+(*p)*i,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
 	}
       else 
@@ -1503,7 +1527,10 @@ void C2F(initgraphicXfig)(char *string, integer *v2, integer *v3, integer *v4, i
       fnum=3;      C2F(loadfamilyXfig)("Times-Italic",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
       fnum=4;      C2F(loadfamilyXfig)("Times-Bold",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
       fnum=5;      C2F(loadfamilyXfig)("Times-BoldItalic",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
-
+      fnum=6;      C2F(loadfamilyXfig)("Helvetica",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
+      fnum=7;      C2F(loadfamilyXfig)("Helvetica-Oblique",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
+      fnum=8;      C2F(loadfamilyXfig)("Helvetica-Bold",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
+      fnum=9;      C2F(loadfamilyXfig)("Helvetica-BoldOblique",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
     }
   C2F(FileInitXfig)();
   ScilabGCXfig.CurWindow =EntryCounter;
@@ -1600,7 +1627,7 @@ void C2F(InitScilabGCXfig)(integer *v1, integer *v2, integer *v3, integer *v4)
   /** we force CurColorStatus to th eopposite value of col 
     to force usecolorPos to perform initialisations 
     **/
-  ScilabGCXfig.graphicsversion = 0;/* NG */ /* old mode */
+  ScilabGCXfig.graphicsversion = (versionflag==1) ? 0:1;/* NG */
   ScilabGCXfig.CurColorStatus = (col == 1) ? 0: 1;
   C2F(usecolorXfig)(&col,PI0,PI0,PI0);
   if (col == 1) ScilabGCXfig.IDLastPattern = ScilabGCXfig.Numcolors - 1;
