@@ -42,8 +42,8 @@
 extern  char  *getenv();
 #endif
 #if defined(THINK_C) || defined (__MWERKS__)|| defined(WIN32)
-#define CoordModePrevious 0
-#define CoordModeOrigin 1
+#define CoordModePrevious 1
+#define CoordModeOrigin 0
 #define GXclear 0
 #define GXand 1
 #define GXandReverse 2
@@ -65,7 +65,7 @@ extern  char  *getenv();
 
 
 #define Char2Int(x)   ( x & 0x000000ff )
-#if defined(__CYGWIN32__) || defined(__MINGW32__) || defined(__GNUC__) || defined(__MSC__)
+#if defined(__CYGWIN32__) || defined(__MINGW32__) || defined(__GNUC__) || defined(__MSC__)|| defined(__EDG__)
 static FILE *file= (FILE *) 0;
 #define FPRINTF(x) ( file != (FILE*) 0) ?  fprintf x  : 0 
 #else 
@@ -125,6 +125,7 @@ static int GifLineColor __PARAMS((void));
 static int GifPatternColor __PARAMS((int pat));
 static void LoadFontsGif(void);
 extern int gdImageSymb(gdImagePtr im, gdFontPtr f, int x, int y, int c, int color);
+extern int versionflag;
 /** Structure to keep the graphic state  **/
 
 struct BCG  ScilabGCGif ;
@@ -153,16 +154,16 @@ void C2F(xselgraphicGif)(char *v1, integer *v2, integer *v3, integer *v4, intege
 /** End of graphic (close the file) **/
 
 void GetDriverName(char *DriverName)
-{    integer *v2;
-     integer *v3;
-     integer *v4;
-     integer *v5;
-     integer *v6;
-     integer *v7;
-     double *dv1;
-     double *dv2;
-     double *dv3;
-     double *dv4;
+{    integer *v2 = NULL;
+     integer *v3 = NULL;
+     integer *v4 = NULL;
+     integer *v5 = NULL;
+     integer *v6 = NULL;
+     integer *v7 = NULL;
+     double *dv1 = NULL;
+     double *dv2 = NULL;
+     double *dv3 = NULL;
+     double *dv4 = NULL;
      GetDriver1(DriverName, v2, v3, v4, v5, v6, v7, dv1, dv2, dv3, dv4);
 }
 
@@ -371,7 +372,7 @@ void C2F(getclipGif)(integer *verbose, integer *x, integer *narg, double *dummy)
 
 void C2F(setabsourelGif)(integer *num, integer *v2, integer *v3, integer *v4)
 {
-  if (*num == 0 )
+  if (*num == CoordModeOrigin )
     ScilabGCGif.CurVectorStyle =  CoordModeOrigin;
   else 
     ScilabGCGif.CurVectorStyle =  CoordModePrevious ;
@@ -1169,11 +1170,13 @@ void C2F(ScilabGCGetorSetGif)(char *str, integer flag, integer *verbose, integer
 	 { if ( j <= 0)
 	     {
 	       sciprint("\nUnknow GIF operator <%s>\r\n",str);
+	       *x1=1;*x2=0;
 	       return;
 	     }
 	 }
      }
   sciprint("\n Unknow GIF operator <%s>\r\n",str);
+  *x1=1;*x2=0;
 }
 
 /*-----------------------------------------------------------
@@ -1259,6 +1262,17 @@ void C2F(displaystringGif)(char *string, integer *x, integer *y, integer *v1, in
 		  GifLineColor());
     C2F(setdashGif)(Dvalue,PI0,PI0,PI0);
   }
+  else if ( Abs(*angle + 90) <= 0.1 )   /* added by Bruno */
+    {
+    C2F(boundingboxGif)(string,&x1,&y1,rect,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
+    C2F(getdashGif)(&verbose,Dvalue,&Dnarg,vdouble);
+    C2F(setdashGif)((j=1,&j),PI0,PI0,PI0);
+    /* a voir (peut etre enlever le -rect[2] qui doit centrer en vertical alors
+       que ce n'est pas attendu) */
+    gdImageStringUp(GifIm, GifFont, *x - rect[3], *y - rect[2], (unsigned char*) string,
+		  GifLineColor());
+    C2F(setdashGif)(Dvalue,PI0,PI0,PI0);
+    }
   else 
     C2F(DispStringAngleGif)(x,y,string,angle);
 }
@@ -1272,7 +1286,7 @@ void C2F(boundingboxGif)(char *string, integer *x, integer *y, integer *rect, in
     return;
   }
   width = 0;
-  for (k=0;k<strlen(string);k++) 
+  for (k=0;k< (int) strlen(string);k++) 
     width += gdCharWidth(GifFont, string[k]);
   rect[0]= (int)(*x);
   rect[1]= (int)(*y);
@@ -1365,10 +1379,7 @@ void C2F(drawarrowsGif)(char *str, integer *vx, integer *vy, integer *n, integer
 	NDvalue=(*style < 1) ?  Dvalue[0] : *style;
       C2F(set_line_style_Gif)(&NDvalue,PI0,PI0,PI0);
 
-      gdImageThickLine(GifIm, vx[2*i], vy[2*i],
-		       vx[2*i + 1], vy[2*i + 1],
-		       GifLineColor(),Max(1,ScilabGCGif.CurLineWidth));
-      dx=( vx[2*i+1]-vx[2*i]);
+     dx=( vx[2*i+1]-vx[2*i]);
       dy=( vy[2*i+1]-vy[2*i]);
       norm = sqrt(dx*dx+dy*dy);
       if ( Abs(norm) >  SMDOUBLE ) 
@@ -1382,6 +1393,11 @@ void C2F(drawarrowsGif)(char *str, integer *vx, integer *vy, integer *n, integer
 	  polyy[2]= inint(polyy[0] - sin20*dx - cos20*dy) ;
 	  C2F(fillpolylinesGif)("v",polyx,polyy,&NDvalue, &nn,&p,PI0,PD0,PD0,PD0,PD0);
 	  }
+
+      gdImageThickLine(GifIm, vx[2*i], vy[2*i],(int)
+		       (vx[2*i + 1]-dx*cos20), (int)(vy[2*i + 1]-dy*cos20),
+		       GifLineColor(),Max(1,ScilabGCGif.CurLineWidth));
+ 
     }
   C2F(set_dash_and_color_Gif)( Dvalue,PI0,PI0,PI0);
 }
@@ -1515,7 +1531,7 @@ void C2F(drawarcsGif)(char *str, integer *vects, integer *style, integer *n, int
 void C2F(drawarcGif)(char *str, integer *x, integer *y, integer *width, integer *height, integer *angle1, integer *angle2, double *dv1, double *dv2, double *dv3, double *dv4)
 { 
   integer vx[365],vy[365],k,n;
-  float alpha,fact=0.01745329251994330,w,h;
+  float alpha,fact= (float) 0.01745329251994330,w,h;
   integer close = 0;
 
   if (GifIm == (gdImagePtr)0 ) {
@@ -1523,13 +1539,13 @@ void C2F(drawarcGif)(char *str, integer *x, integer *y, integer *width, integer
     return;
   }
 
-  w = (*width)/2.0;
-  h = (*height)/2.0;
+  w = (float) ((*width)/2.0);
+  h = (float) ((*height)/2.0);
   n=Min((*angle2/64),360);
   for (k = 0; k < n; ++k) {
     alpha=((*angle1/64)+k)*fact;
-    vx[k] = *x + w*(cos(alpha)+1.0);
-    vy[k] = *y + h*(-sin(alpha)+1.0);}
+    vx[k] = (integer) (*x + w*(cos(alpha)+1.0));
+    vy[k] = (integer) (*y + h*(-sin(alpha)+1.0));}
     
   C2F(drawpolylineGif)(str, &n, vx, vy, &close, PI0, PI0, dv1, dv2, dv3, dv4);
 }
@@ -1540,7 +1556,7 @@ void C2F(drawarcGif)(char *str, integer *x, integer *y, integer *width, integer
 void C2F(fillarcGif)(char *str, integer *x, integer *y, integer *width, integer *height, integer *angle1, integer *angle2, double *dv1, double *dv2, double *dv3, double *dv4)
 { 
   integer vx[365],vy[365],k,k0,kmax,n;
-  float alpha,fact=0.01745329251994330,w,h;
+  float alpha,fact= (float) 0.01745329251994330,w,h;
   integer close = 1;
   if (GifIm == (gdImagePtr)0 ) {
     sciprint(" xinit must be called before any action \r\n");
@@ -1548,25 +1564,25 @@ void C2F(fillarcGif)(char *str, integer *x, integer *y, integer *width, integer
   }
   n=Min((*angle2/64),360);
 
-  w = (*width)/2.0;
-  h = (*height)/2.0;
+  w = (float) ((*width)/2.0);
+  h = (float) ((*height)/2.0);
   k0 = 0;
   kmax = n-1;
 
   if (n != 360) {
-  vx[0] = *x + w;
-  vy[0] = *y + h;
+  vx[0] =  (integer) (*x + w);
+  vy[0] =  (integer) (*y + h);
   k0 = 1;
   kmax = n;}
 
   for (k = k0; k <= kmax; ++k) {
     alpha=((*angle1/64)+k)*fact;
-    vx[k] = *x + w*(cos(alpha)+1.0);
-    vy[k] = *y + h*(-sin(alpha)+1.0);}
+    vx[k] =  (integer) (*x + w*(cos(alpha)+1.0));
+    vy[k] =  (integer) (*y + h*(-sin(alpha)+1.0));}
   if (n != 360) {
   n++;
-  vx[n] = *x + ((*width)/2.0);
-  vy[n] = *y + ((*height)/2.0); 
+  vx[n] = (integer) (*x + ((*width)/2.0));
+  vy[n] = (integer) (*y + ((*height)/2.0)); 
   n++;
   }
   C2F(fillpolylineGif)(str, &n, vx, vy, &close, PI0, PI0, dv1, dv2, dv3, dv4);
@@ -1597,6 +1613,7 @@ void C2F(drawpolylinesGif)(char *str, integer *vectsx, integer *vectsy, integer
 	{ /** on utilise la marque de numero associ\'ee **/
 	  NDvalue = - drawvect[i];
 	  C2F(setdashGif)((j=1,&j),PI0,PI0,PI0);
+
 	  C2F(xsetmarkGif)(&NDvalue,symb+1,PI0,PI0);
 	  
 	  C2F(drawpolymarkGif)(str,p,vectsx+(*p)*i,vectsy+(*p)*i,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
@@ -1894,7 +1911,7 @@ void InitScilabGCGif(integer *v1, integer *v2, integer *v3, integer *v4)
   /** we force CurColorStatus to the opposite value of col 
     to force usecolorGif to perform initialisations 
     **/
-  ScilabGCGif.graphicsversion = 0;/* NG */ /* old mode */
+  ScilabGCGif.graphicsversion = (versionflag==1) ? 0:1;/* NG */
   ScilabGCGif.CurColorStatus = (col == 1) ? 0: 1;
   C2F(usecolorGif)(&col,PI0,PI0,PI0);
   if (col == 1) ScilabGCGif.IDLastPattern = ScilabGCGif.Numcolors - 1;
@@ -1980,13 +1997,13 @@ void C2F(displaynumbersGif)(char *str, integer *x, integer *y, integer *v1, inte
 
 /** Global variables to deal with fonts **/
 
-#define FONTNUMBER 6
+#define FONTNUMBER 11
 #define FONTMAXSIZE 6
 #define SYMBOLNUMBER 10
 
 
 static char *sizeGif[] = { "08" ,"10","12","14","18","24"};
-static int  isizeGif[FONTNUMBER] = { 8 ,10,12,14,18,24 };
+static int  isizeGif[FONTMAXSIZE] = { 8 ,10,12,14,18,24 };
 
 /* FontsList : stockage des structures des fonts 
    la font i a la taille fsiz se trouve ds 
@@ -2020,6 +2037,10 @@ static FontAlias fonttab[] ={
   {"timI", "-adobe-times-medium-i-normal--*-%s0-*-*-p-*-iso8859-1"},
   {"timB", "-adobe-times-bold-r-normal--*-%s0-*-*-p-*-iso8859-1"},
   {"timBI", "-adobe-times-bold-i-normal--*-%s0-*-*-p-*-iso8859-1"},
+  {"helvR", "-adobe-helvetica-medium-r-normal--*-%s0-*-*-p-*-iso8859-1"},
+  {"helvO", "-adobe-helvetica-medium-o-normal--*-%s0-*-*-p-*-iso8859-1"},
+  {"helvB", "-adobe-helvetica-bold-r-normal--*-%s0-*-*-p-*-iso8859-1"},
+  {"helvBO","-adobe-helvetica-bold-o-normal--*-%s0-*-*-p-*-iso8859-1"},
   {(char *) NULL,( char *) NULL}
 };
 
@@ -2031,15 +2052,14 @@ void C2F(xsetfontGif)(integer *fontid, integer *fontsize, integer *v3, integer *
   fsiz = Min(FONTMAXSIZE-1,Max(*fontsize,0));
   if ( FontInfoTabGif[i].ok !=1 )
     { 
-      if (i != 6 )
+      if (i != FONTNUMBER-1 )  /* a voir ... */
 	{
 	  C2F(loadfamilyGif)(fonttab[i].alias,&i,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
 	}
       else 
 	{
-	  sciprint(" The Font Id %d is not affected \r\n",(int)i);
-	  Scistring(" use xlfont to set it \n");
-	  return;
+	  sciprint(" The Font Id %d is not affected: use default font (Times)\r\n",(int)i);
+	  i = 2; /* celle-ci est prcharge lors de l'init */
 	}
     }
   ScilabGCGif.FontId = i;
@@ -2115,10 +2135,10 @@ void C2F(loadfamilyGif)(char *name, integer *j, integer *v3, integer *v4, intege
   char *SciPath;
   gdFontPtr Font;
 
-/** generic name with % **/
-  if ( strchr(name,'%') != (char *) NULL)
+  /** test if it is an alias font name **/
+  if ( strchr(name,'%') != (char *) NULL)  /* no apriori it is an X11 font name */
     {
-      sciprint("Generic font names are not supported by gif driver\n");
+      sciprint("only alias font name are supported by gif driver\n");
       return;
     }
   SciPath=getenv("SCI");
