@@ -21,8 +21,8 @@
 
 
 #if defined(THINK_C) || defined (__MWERKS__)|| defined(WIN32)
-#define CoordModePrevious 0
-#define CoordModeOrigin 1
+#define CoordModePrevious 1
+#define CoordModeOrigin 0
 #define GXclear 0
 #define GXand 1
 #define GXandReverse 2
@@ -45,7 +45,7 @@
 #include "periPos.h"
 #include "color.h"
 #include "bcg.h" /* NG */
-
+extern int versionflag;
 void C2F(WriteGeneric1Pos)(char *string, integer nobjpos, integer objbeg, integer sizeobj, integer *vx, integer *vy, integer flag, integer *fvect);
 void C2F(xgetmarkPos)(integer *verbose, integer *symb, integer *narg, double *dummy);
 void C2F(xsetmarkPos)(integer *number, integer *size, integer *v3, integer *v4);
@@ -68,6 +68,7 @@ void C2F(setscilabVersionPos)(integer *vers, integer *v2, integer *v3, integer *
 void C2F(getscilabVersionPos)(integer *verbose, integer *vers, integer *narg, double *dummy);
 void C2F(setscilabxgcPos)(integer *v1, integer *v2, integer *v3, integer *v4); 
 void C2F(getscilabxgcPos)(integer *verbose, integer *x,integer *narg, double *dummy);
+void setposfig(integer *i,integer *j);
 /* NG end */
 
 static double ascentPos(void);
@@ -80,7 +81,7 @@ static void WriteColorRGBDef(char *str, short unsigned int *tab, int ind);
 
 static double *vdouble = 0; /* used when a double argument is needed */
 
-#if defined(__CYGWIN32__) || defined(__MINGW32__) || defined(__GNUC__) || defined(__MSC__)
+#if defined(__CYGWIN32__) || defined(__MINGW32__) || defined(__GNUC__) || defined(__MSC__) || defined(__EDG__)
 static FILE *file= (FILE *) 0;
 #define FPRINTF(x) ( file != (FILE*) 0) ?  fprintf x  : 0 
 #else 
@@ -183,7 +184,19 @@ void C2F(setwindowposPos)(integer *x, integer *y, integer *v3, integer *v4)
 
 static integer prec_fact =10;
 static integer def_width =600;
-static integer def_height =424;
+static integer def_height = 424;
+
+void setposfig(integer *i,integer *j)
+{
+  def_width =*i;
+  def_height =*j;
+  if (def_width*def_height==0){
+    def_width =600;
+    def_height =424;
+  }
+}
+
+
 
 void C2F(getwindowdimPos)(integer *verbose, integer *x, integer *narg, double *dummy)
 {     
@@ -278,7 +291,7 @@ void C2F(getclipPos)(integer *verbose, integer *x, integer *narg, double *dummy)
 
 void C2F(setabsourelPos)(integer *num, integer *v2, integer *v3, integer *v4)
 {
-  if (*num == 0 )
+  if (*num ==  CoordModeOrigin )
     ScilabGCPos.CurVectorStyle =  CoordModeOrigin;
   else 
     ScilabGCPos.CurVectorStyle =  CoordModePrevious ;
@@ -695,6 +708,7 @@ void C2F(setgccolormapPos)(struct BCG *Xgc,integer m, double *a)
   Xgc->IDLastPattern = m - 1;
   Xgc->NumForeground = m;
   Xgc->NumBackground = m + 1;
+  FPRINTF((file,"\n/WhiteLev %d def",Xgc->IDLastPattern));
   WriteColorRGB("R",a,0);
   WriteColorRGB("G",a,1);
   WriteColorRGB("B",a,2);
@@ -715,20 +729,25 @@ void C2F(setcolormapPos)(integer *v1, integer *v2, integer *v3, integer *v4, int
   m = *v1;
   C2F(setgccolormapPos)(&ScilabGCPos,m, a);
 }
+
 /* NG beg */
+
 void setcolormapgPos(struct  BCG *Xgc,integer *m,integer *v2, double *a) /* NG */
 {
 
   C2F(setgccolormapPos)(Xgc,*m, a);
 }
+
 /* NG end */
+
 static void WriteColorRGB(char *str, double *tab, int ind)
 {
+  /* RGB are the columns of tab */ 
   int i;
   FPRINTF((file,"\n/Color%s [",str));
   for ( i=0; i < ScilabGCPos.Numcolors; i++)
     {
-      FPRINTF((file,"%f ",(float) tab[3*i+ind]));
+      FPRINTF((file,"%f ",(float) tab[i+ ScilabGCPos.Numcolors*ind]));
       if ( (i % 10 ) == 0 ) FPRINTF((file,"\n"));
     }
   FPRINTF((file,"0.0 1.0] def"));
@@ -970,11 +989,13 @@ void C2F(ScilabGCGetorSetPos)(char *str, integer flag, integer *verbose, integer
 	 { if ( j <= 0)
 	     {
 	       sciprint("\nUnknow Postscript operator <%s>\r\n",str);
+	       *x1=1;*x2=0;
 	       return;
 	     }
 	 }
      }
   sciprint("\n Unknow Postscript operator <%s>\r\n",str);
+  *x1=1;*x2=0;
 }
 
 /*-----------------------------------------------------------
@@ -1009,19 +1030,10 @@ void C2F(displaystringPos)(char *string, integer *x, integer *y, integer *v1, in
   
   FPRINTF((file,"\n%%Latex:\\myput{%d}{%d}{%d}{%s}",
 	   (int)*x,def_height*prec_fact - yn, 
-	   fontsizePos (),
+	   fontsizePos ()/2,
 	   string));
  }
 
-
-double bsizePos[6][4]= {{ 0.0,-7.0,4.63,9.0  },  /* normalement inutilise ici avec les modifs suivantes */
-		{ 0.0,-9.0,5.74,12.0 },          
-		{ 0.0,-11.0,6.74,14.0},
-		{ 0.0,-12.0,7.79,15.0},
-		{0.0, -15.0,9.72,19.0 },
-		{0.0,-20.0,13.41,26.0}};
-
-
 /*** ajouts q&d en attendant mieux.... Bruno (le 24 Nov 2002) ***/
 
 struct posfont  /* a data type for handling a postscript font in scilab */
@@ -1068,7 +1080,7 @@ typedef struct posfont PosFont;
    
  /**   datas for postscript font : Times-Roman   **/
  static int WidthTimesR[] = { 250 , 333 , 408 , 500 , 500 , 833 , 778 , 333 , 333 , 333 ,
-                              500 , 564 , 250 , 333 , 250 , 278 , 500 , 500 , 500 , 500 ,
+                              500 , 564 , 250 , 564 , 250 , 278 , 500 , 500 , 500 , 500 ,
                               500 , 500 , 500 , 500 , 500 , 500 , 278 , 278 , 564 , 564 ,
                               564 , 444 , 921 , 722 , 667 , 667 , 722 , 611 , 556 , 722 ,
                               722 , 333 , 389 , 722 , 611 , 889 , 722 , 722 , 556 , 722 ,
@@ -1106,7 +1118,7 @@ typedef struct posfont PosFont;
    
  /**   datas for postscript font : Times-Bold   **/
  static int WidthTimesB[] = { 250 , 333 , 555 , 500 , 500 ,1000 , 833 , 333 , 333 , 333 ,
-                              500 , 570 , 250 , 333 , 250 , 278 , 500 , 500 , 500 , 500 ,
+                              500 , 570 , 250 , 570 , 250 , 278 , 500 , 500 , 500 , 500 ,
                               500 , 500 , 500 , 500 , 500 , 500 , 333 , 333 , 570 , 570 ,
                               570 , 500 , 930 , 722 , 667 , 722 , 722 , 667 , 611 , 778 ,
                               778 , 389 , 500 , 778 , 667 , 944 , 722 , 778 , 611 , 778 ,
@@ -1125,7 +1137,7 @@ typedef struct posfont PosFont;
    
  /**   datas for postscript font : Times-BoldItalic   **/
  static int WidthTimesBI[] = { 250 , 389 , 555 , 500 , 500 , 833 , 778 , 333 , 333 , 333 ,
-                               500 , 570 , 250 , 333 , 250 , 278 , 500 , 500 , 500 , 500 ,
+                               500 , 570 , 250 , 606 , 250 , 278 , 500 , 500 , 500 , 500 ,
                                500 , 500 , 500 , 500 , 500 , 500 , 333 , 333 , 570 , 570 ,
                                570 , 500 , 832 , 667 , 667 , 667 , 722 , 667 , 667 , 722 ,
                                778 , 389 , 500 , 667 , 611 , 889 , 722 , 722 , 611 , 722 ,
@@ -1141,8 +1153,86 @@ typedef struct posfont PosFont;
                              0,           /* Is Fixed Pitch */
                              WidthTimesBI };
    
-#define NB_MAX_POS_FONT 6
-static PosFont *FontArray[NB_MAX_POS_FONT] = {&Courier, &Symbol, &TimesR, &TimesI, &TimesB, &TimesBI};
+ /**   datas for postscript font : Helvetica   **/
+ static int WidthHelvetica[] = { 278 , 278 , 355 , 556 , 556 , 889 , 667 , 222 , 333 , 333 ,
+                                 389 , 584 , 278 , 333 , 278 , 278 , 556 , 556 , 556 , 556 ,
+                                 556 , 556 , 556 , 556 , 556 , 556 , 278 , 278 , 584 , 584 ,
+                                 584 , 556 ,1015 , 667 , 667 , 722 , 722 , 667 , 611 , 778 ,
+                                 722 , 278 , 500 , 667 , 556 , 833 , 722 , 778 , 667 , 778 ,
+                                 722 , 667 , 611 , 722 , 667 , 944 , 667 , 667 , 611 , 278 ,
+                                 278 , 278 , 469 , 556 , 222 , 556 , 556 , 500 , 556 , 556 ,
+                                 278 , 556 , 556 , 222 , 222 , 500 , 222 , 833 , 556 , 556 ,
+                                 556 , 556 , 333 , 500 , 278 , 556 , 500 , 722 , 500 , 500 ,
+                                 500 , 334 , 260 , 334 , 584 };
+ static PosFont Helvetica = { "Helvetica",
+                               775,         /* Ascender */
+                              -220,         /* Descender */
+                               526,         /* Mean Width */
+                               0,           /* Is Fixed Pitch */
+                               WidthHelvetica };
+   
+   
+ /**   datas for postscript font : Helvetica-Bold   **/
+ static int WidthHelveticaB[] = { 278 , 333 , 474 , 556 , 556 , 889 , 722 , 278 , 333 , 333 ,
+                                  389 , 584 , 278 , 333 , 278 , 278 , 556 , 556 , 556 , 556 ,
+                                  556 , 556 , 556 , 556 , 556 , 556 , 333 , 333 , 584 , 584 ,
+                                  584 , 611 , 975 , 722 , 722 , 722 , 722 , 667 , 611 , 778 ,
+                                  722 , 278 , 556 , 722 , 611 , 833 , 722 , 778 , 667 , 778 ,
+                                  722 , 667 , 611 , 722 , 667 , 944 , 667 , 667 , 611 , 333 ,
+                                  278 , 333 , 584 , 556 , 278 , 556 , 611 , 556 , 611 , 556 ,
+                                  333 , 611 , 611 , 278 , 278 , 556 , 278 , 889 , 611 , 611 ,
+                                  611 , 611 , 389 , 556 , 333 , 611 , 556 , 778 , 556 , 556 ,
+                                  500 , 389 , 280 , 389 , 584 };
+ static PosFont HelveticaB = { "Helvetica-Bold",
+                                775,         /* Ascender */
+                               -217,         /* Descender */
+                                551,         /* Mean Width */
+                                0,           /* Is Fixed Pitch */
+                                WidthHelveticaB };
+   
+   
+ /**   datas for postscript font : Helvetica-Oblique   **/
+ static int WidthHelveticaO[] = { 278 , 278 , 355 , 556 , 556 , 889 , 667 , 222 , 333 , 333 ,
+                                  389 , 584 , 278 , 333 , 278 , 278 , 556 , 556 , 556 , 556 ,
+                                  556 , 556 , 556 , 556 , 556 , 556 , 278 , 278 , 584 , 584 ,
+                                  584 , 556 ,1015 , 667 , 667 , 722 , 722 , 667 , 611 , 778 ,
+                                  722 , 278 , 500 , 667 , 556 , 833 , 722 , 778 , 667 , 778 ,
+                                  722 , 667 , 611 , 722 , 667 , 944 , 667 , 667 , 611 , 278 ,
+                                  278 , 278 , 469 , 556 , 222 , 556 , 556 , 500 , 556 , 556 ,
+                                  278 , 556 , 556 , 222 , 222 , 500 , 222 , 833 , 556 , 556 ,
+                                  556 , 556 , 333 , 500 , 278 , 556 , 500 , 722 , 500 , 500 ,
+                                  500 , 334 , 260 , 334 , 584 };
+ static PosFont HelveticaO = { "Helvetica-Oblique",
+                                775,         /* Ascender */
+                               -220,         /* Descender */
+                                526,         /* Mean Width */
+                                0,           /* Is Fixed Pitch */
+                                WidthHelveticaO };
+   
+   
+ /**   datas for postscript font : Helvetica-BoldOblique   **/
+ static int WidthHelveticaBO[] = { 278 , 333 , 474 , 556 , 556 , 889 , 722 , 278 , 333 , 333 ,
+                                   389 , 584 , 278 , 333 , 278 , 278 , 556 , 556 , 556 , 556 ,
+                                   556 , 556 , 556 , 556 , 556 , 556 , 333 , 333 , 584 , 584 ,
+                                   584 , 611 , 975 , 722 , 722 , 722 , 722 , 667 , 611 , 778 ,
+                                   722 , 278 , 556 , 722 , 611 , 833 , 722 , 778 , 667 , 778 ,
+                                   722 , 667 , 611 , 722 , 667 , 944 , 667 , 667 , 611 , 333 ,
+                                   278 , 333 , 584 , 556 , 278 , 556 , 611 , 556 , 611 , 556 ,
+                                   333 , 611 , 611 , 278 , 278 , 556 , 278 , 889 , 611 , 611 ,
+                                   611 , 611 , 389 , 556 , 333 , 611 , 556 , 778 , 556 , 556 ,
+                                   500 , 389 , 280 , 389 , 584 };
+ static PosFont HelveticaBO = { "Helvetica-BoldOblique",
+                                 775,         /* Ascender */
+                                -217,         /* Descender */
+                                 551,         /* Mean Width */
+                                 0,           /* Is Fixed Pitch */
+                                 WidthHelveticaBO };
+
+   
+#define NB_MAX_POS_FONT 10
+static PosFont *FontArray[NB_MAX_POS_FONT] = {&Courier, &Symbol, 
+					      &TimesR,    &TimesI,     &TimesB,     &TimesBI,
+                                              &Helvetica, &HelveticaO, &HelveticaB, &HelveticaBO};
 
 #define NB_MAX_SIZES 6
 static int Font_Size_in_pts[NB_MAX_SIZES] = {8, 10, 12, 14, 18, 24};
@@ -1205,12 +1295,8 @@ static double PosStrAsc(integer id_font, integer id_size)
 }
 /*** fin des ajouts de Bruno  ***/
 
-/** To get the bounding rectangle of a string **/
-/** we can't ask Postscript directly so we have an **/
-/** approximative result in Postscript : use the X11 driver **/
-/** with the same current font to have a good result **/
 
-/*** modified by Bruno by using the previus datas and functions ***/
+/** To get the bounding rectangle of a string (modified by Bruno by using the previus datas and functions) **/
 void C2F(boundingboxPos)(char *string, integer *x, integer *y, integer *rect, integer *v5, 
 			 integer *v6, integer *v7, double *dv1, double *dv2, double *dv3, double *dv4)
 {
@@ -1223,35 +1309,27 @@ void C2F(boundingboxPos)(char *string, integer *x, integer *y, integer *rect, in
   rect[1]= (integer)(*y-h*prec_fact);
   rect[2]= (integer)(w*prec_fact);
   rect[3]= (integer)(h*prec_fact);
-  /* old code 
-     rect[0]= (int)(*x+bsizePos[font[1]][0]*((double) prec_fact));
-     rect[1]= (int)(*y+bsizePos[font[1]][1]*((double) prec_fact));
-     rect[2]= (int)(bsizePos[font[1]][2]*((double)prec_fact)*(int)strlen(string));
-     rect[3]= (int)(bsizePos[font[1]][3]*((double)prec_fact));
-  */
 }
 
-/* approximation of ascent using (asc + dsc) /2  */ 
-/** modified by bruno **/
+/* approximation of ascent using (asc + dsc) /2  (modified by bruno) */
 static double ascentPos() 
 { 
   static integer verbose=0,nargs,font[2];
   C2F(xgetfontPos)(&verbose,font,&nargs,vdouble);
   return (PosStrAsc(font[0], font[1]) * prec_fact);
-  /* old: return ((bsizePos[font[1]][1] +(bsizePos[font[1]][3]/2.0) ))*((double) prec_fact); */
 }
 
-/** Draw a single line in current style **/
 
+/** Draw a single line in current style **/
 void C2F(drawlinePos)(integer *xx1, integer *yy1, integer *x2, integer *y2)
 {
     FPRINTF((file,"\n %d %d %d %d L",(int)*xx1,(int)*yy1,(int)*x2,(int)*y2));
   }
 
+
 /** Draw a set of segments **/
 /** segments are defined by (vx[i],vy[i])->(vx[i+1],vy[i+1]) **/
 /** for i=0 step 2 **/
-
 void C2F(drawsegmentsPos)(char *str, integer *vx, integer *vy, integer *n, integer *style, integer *iflag, integer *v7, double *dv1, double *dv2, double *dv3, double *dv4)
 {
   integer verbose=0,Dnarg,Dvalue[10],NDvalue;
@@ -1435,6 +1513,7 @@ void C2F(drawpolylinesPos)(char *str, integer *vectsx, integer *vectsy, integer
 	{ /** on utilise la marque de numero associ\'ee **/
 	  NDvalue = - drawvect[i];
 	  C2F(xsetmarkPos)(&NDvalue,symb+1,PI0,PI0);
+	 
 	  C2F(drawpolymarkPos)(str,p,vectsx+(*p)*i,vectsy+(*p)*i,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
 	}
       else
@@ -1543,6 +1622,10 @@ void C2F(initgraphicPos)(char *string, integer *v2, integer *v3, integer *v4, in
       fnum=3;      C2F(loadfamilyPos)("Times-Italic",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
       fnum=4;      C2F(loadfamilyPos)("Times-Bold",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0);
       fnum=5;      C2F(loadfamilyPos)("Times-BoldItalic",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
+      fnum=6;      C2F(loadfamilyPos)("Helvetica",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
+      fnum=7;      C2F(loadfamilyPos)("Helvetica-Oblique",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
+      fnum=8;      C2F(loadfamilyPos)("Helvetica-Bold",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
+      fnum=9;      C2F(loadfamilyPos)("Helvetica-BoldOblique",&fnum,PI0,PI0,PI0,PI0,PI0,PD0,PD0,PD0,PD0); 
 
     }
   FileInit();
@@ -1558,6 +1641,7 @@ void FileInit(void)
   verbose = 0; 
   C2F(getwindowdimPos)(&verbose,x,&narg,vdouble);
   ColorInit();
+  FPRINTF((file,"\n%%scipos_w=%d\n%%scipos_h=%d",(int)x[0]/2,(int)x[1]/2));
   FPRINTF((file,"\n%% Dessin en bas a gauche de taille %d,%d",(int)x[0]/2,(int)x[1]/2));
   FPRINTF((file,"\n[0.5 %d div 0 0 0.5 %d div neg  0 %d %d div] concat",
 	  (int)prec_fact, (int)prec_fact,(int)x[1]/2,(int) prec_fact ));
@@ -1587,7 +1671,7 @@ void FileInit(void)
 	  FPRINTF((file,"%f ",r));
 	  if ( (i % 10 ) == 0 ) FPRINTF((file,"\n"));
 	}
-      FPRINTF((file,"0.0 1.0 ] def"));
+      FPRINTF((file,"0.0 1.0] def"));
       FPRINTF((file,"\n/ColorG ["));
       for ( i=0; i < m ; i++) 
 	{
@@ -1605,9 +1689,13 @@ void FileInit(void)
 	}
       FPRINTF((file,"0.0 1.0] def"));
     }
-  FPRINTF((file,"\n%%Latex:\\begin{picture}(%d,%d)(0,0)",
+  FPRINTF((file,"\n%%Latex:\\setlength{\\unitlength}{%4.2fpt}",
+	   1.0/(prec_fact*2)));
+  FPRINTF((file,"\n%%Latex:\\begin{picture}(%d,%d)(%d,0)",
 	   def_width*prec_fact,
-	   def_height*prec_fact));
+	   def_height*prec_fact,
+	   def_width/3  /* not so clear XXX */
+	   ));
 }
 
 /*--------------------------------------------------------
@@ -1649,7 +1737,7 @@ void InitScilabGCPos(integer *v1, integer *v2, integer *v3, integer *v4)
   /** we force CurColorStatus to the opposite value of col 
     to force usecolorPos to perform initialisations 
     **/
-  ScilabGCPos.graphicsversion = 0;/* NG */ /* old mode */
+  ScilabGCPos.graphicsversion = (versionflag==1) ? 0:1;/* NG */ 
 
   ScilabGCPos.CurColorStatus = (col == 1) ? 0: 1;
   C2F(usecolorPos)(&col,PI0,PI0,PI0);
@@ -1836,12 +1924,12 @@ void C2F(Write2VectPos)(integer *vx, integer *vy, integer from, integer n, char
 
 /** Global variables to deal with fonts **/
 
-#define FONTNUMBER 7
+#define FONTNUMBER 11
 #define FONTMAXSIZE 6
 #define SYMBOLNUMBER 10
 integer FontsListPos[FONTNUMBER][FONTMAXSIZE];
 struct SciFontInfo { integer ok;
-		  char fname[20];} FontInfoTabPos[FONTNUMBER];
+		  char fname[21];} FontInfoTabPos[FONTNUMBER];
 
 static char *sizePos[] = { "08" ,"10","12","14","18","24"};
 static int  isizePos[] = { 8 ,10,12,14,18,24};
@@ -1854,21 +1942,23 @@ static int fontsizePos (void)
 }
 	 
 
-
 void C2F(xsetfontPos)(integer *fontid, integer *fontsize, integer *v3, integer *v4)
-{ integer i,fsiz;
+/* modified by bruno (Jan 2004) */
+{ 
+  integer i,fsiz;
   i = Min(FONTNUMBER-1,Max(*fontid,0));
   fsiz = Min(FONTMAXSIZE-1,Max(*fontsize,0));
   if ( FontInfoTabPos[i].ok !=1 )
-    Scistring("\n Sorry This Font is Not available ");
-  else 
-   {
-     ScilabGCPos.FontId = i;
-     ScilabGCPos.FontSize = fsiz;
-     FPRINTF((file,"\n/%s findfont %d scf mul scalefont setfont",
-	     FontInfoTabPos[i].fname,
-	     (int) (isizePos[fsiz]*prec_fact)));
-   }
+    {
+      /* currently this case occurs only when i=FONTNUMBER-1 */
+      Scistring("\n Sorry This Font is Not available: use default font (Times)\n");
+      i = 2;
+    }
+  ScilabGCPos.FontId = i;
+  ScilabGCPos.FontSize = fsiz;
+  FPRINTF((file,"\n/%s findfont %d scf mul scalefont setfont",
+	   FontInfoTabPos[i].fname,
+	   (int) (isizePos[fsiz]*prec_fact)));
 }
 
 /** To get the values id and size of the current font **/
