@@ -49,7 +49,11 @@ static void sci_factory_add_last_menu_entry(GtkItemFactory *ifactory,menu_entry
 static menu_entry *main_menu_entries = NULL;
 static GtkItemFactory  *main_item_factory= NULL;
 
-void create_main_menu() 
+/*
+ * used when the menu is plugged 
+ */
+
+void create_plugged_main_menu() 
 {
   static GtkWidget *menubar = NULL; 
   static int first = 0; 
@@ -89,6 +93,45 @@ void create_main_menu()
 
 }
 
+
+
+/*
+ * used when zterm is plugged 
+ */
+
+GtkWidget *create_main_menu( GtkWidget  *window)
+{
+  static int first = 0;
+  static GtkWidget *menubar = NULL; 
+  static GtkItemFactory *item_factory;
+  GtkAccelGroup *accel_group = NULL ; 
+  
+  /* Make an accelerator group (shortcut keys) */
+  if ( window != NULL)  accel_group = gtk_accel_group_new ();
+
+  main_item_factory= item_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, "<main>", 
+							  accel_group);
+  if ( first == 0 ) {
+    main_menu_entries = sci_window_initial_menu();
+    if ( main_menu_entries == NULL) return NULL;
+    first = 1;
+  }
+
+  /* This function generates the menu items from scilab description */
+  /* Attention il faut aussi gerer les menu en set unset XXXXX */
+
+  sci_menu_to_item_factory(item_factory, main_menu_entries);
+  
+  /* Finally, return the actual menu bar created by the item factory. */ 
+  if ( menubar != NULL) gtk_widget_destroy(menubar);
+  menubar = gtk_item_factory_get_widget (item_factory, "<main>");
+  if ( window != NULL )  gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
+  return menubar;
+
+}
+
+
+
 /*--------------------------------------------------------------
  * Graphic window menu in main menu 
  *--------------------------------------------------------------*/
@@ -473,6 +516,8 @@ void submenu_add(menu_entry *me,menu_entry *more)
  * Add a menu in a menu_item list
  *  win_num     : graphic window number or -1 for main scilab window
  *  name        : label of menu button
+ *                if entries is empty then name can be 
+ *                   "name|accelerator|specific_action"
  *  entries     : labels of submenus if any. each entry is a string 
  *                "entry_name" or "entry_name|accelerator|specific_action"
  * 
@@ -483,6 +528,35 @@ void submenu_add(menu_entry *me,menu_entry *more)
  *  fname;      : name of the action function  
  ****************************************************/
 
+
+static menu_entry *gtksci_new_menu_entry(char *entry_name,int winid,int pos,int action_type,char *fname)
+{
+  menu_entry *menu ; 
+  char *entry=NULL,*accel=NULL,*action=NULL;
+  entry=strdup(entry_name);
+  accel = strchr(entry,'|');
+  if (accel != NULL) 
+    {
+      *accel = '\0'; accel +=1;
+      action =  strchr(accel,'|');
+      if ( action != NULL ) 
+	{ 
+	  *action = '\0'; action+=1;
+	}
+    }
+  if (action == NULL) action = fname ;
+  menu = new_menu_entry(entry,accel,1,pos+1,NULL,winid,action_type,action);
+  if ( menu == NULL) 
+    {
+      /* XXXXX clean and return */
+      if(entry != NULL) free(entry);
+      return NULL;
+    }
+  return menu;
+}
+
+
+
 static int sci_menu_add(menu_entry **m,int winid,char *name,char** entries,int ne, 
 			int action_type,char *fname)
 {  
@@ -493,49 +567,24 @@ static int sci_menu_add(menu_entry **m,int winid,char *name,char** entries,int n
   /* first build the sub_menus */
   for (i=0 ; i < ne ;i++) 
     {
-      char *accel;
-      entry=strdup(entries[i]);
-      accel = strchr(entry,'|');
-
-      if (accel != NULL) 
-	{
-	  char * action =  strchr(accel+1,'|');
-	  *accel = '\0';
-	  if ( action != NULL ) 
-	    { 
-	      *action = '\0';
-	      if ( action == accel + 1 ) 
-		me2 = new_menu_entry(entry,NULL,1,i+1,NULL,winid,
-				     action_type,action+1);
-	      else 
-		me2 = new_menu_entry(entry,accel+1,1,i+1,NULL,winid,
-				     action_type,action+1);
-	      *action = '|';
-	    }
-	  else 
-	    {
-	      me2 = new_menu_entry(entry,accel+1,1,i+1,NULL,winid,
-				   action_type,fname);
-	    }
-	  *accel='|';
-	}
-      else 
-	{
-	  me2 = new_menu_entry(entry,NULL,1,i+1,NULL,winid,
-			       action_type,fname);
-	}
+      me2 = gtksci_new_menu_entry(entries[i],winid,i,action_type,fname);
       if ( me2 == NULL) 
 	{
-	  /* XXXXX clean and return */
-	  if(entry != NULL) free(entry);
 	  return 1;
 	}
       if ( i != 0) me1->next = me2;
       else { subs = me2;}
       me1=me2;
     }
-  /* now the menu entry */
-  top = new_menu_entry(name,NULL,1,1,subs,winid,action_type,fname);
+  if ( ne == 0 ) 
+    {
+      top = gtksci_new_menu_entry(name,winid,0,action_type,fname);
+    }
+  else
+    {
+      /* now the menu entry */
+      top = new_menu_entry(name,NULL,1,1,subs,winid,action_type,fname);
+    }
   if ( top == NULL) 
     {
       /* XXXXX clean and return */
@@ -651,7 +700,7 @@ static void sci_menu_default_callback (gpointer  callback_data,
 	sprintf(buf,"execstr(%s(%d))",m->fname,m->nsub);
       else 
 	sprintf(buf,"execstr(%s_%d(%d))",m->fname,m->winid,m->nsub);
-      StoreCommand1(buf,1);
+      StoreCommand(buf);
     }
   else if (m->action_type == 2) 
     { 
@@ -660,7 +709,7 @@ static void sci_menu_default_callback (gpointer  callback_data,
 	sprintf(buf,"%s(%d)",m->fname,m->nsub);
       else 
 	sprintf(buf,"%s(%d,%d)",m->fname,m->nsub,m->winid);
-      StoreCommand1(buf,2);
+      StoreCommand(buf);
     }
   else 
     { 
@@ -769,7 +818,7 @@ static void * sci_window_initial_menu()
   char *control_entries[] = { "Resume||$resume",
 			      "Abort||$abort",
 			      "Restart||$restart",
-			      "Stop||$stop" } ;
+			      "Stop||$stop" };
   char *graphic_entries[] = { "Create or Select||$gwselect",
 			      "Raise||$gwraise", 
 			      "Delete||$gwdelete",
@@ -826,7 +875,7 @@ void scig_deletegwin_handler_sci (int win)
   SciGc = GetWindowXgcNumber(win);
   if (strlen(SciGc->EventHandler)!=0) {
     sprintf(buf,"%s(%d,0,0,-1000)",SciGc->EventHandler,win);
-    StoreCommand1(buf,0);
+    StoreCommand(buf);
     }
 };
 static Scig_deletegwin_handler scig_deletegwin_handler = scig_deletegwin_handler_sci;
@@ -847,12 +896,17 @@ void reset_scig_deletegwin_handler()
 
 /* delete action */
 
+extern void  delete_sgwin_entities(int winid,int v_flag);
+
+
 static void scig_menu_delete(int winid) 
 {
+  int v_flag = 1;
   scig_erase(winid);
+  if (version_flag() == 0) {DeleteObjs(winid); v_flag = 0;}
   scig_deletegwin_handler(winid);
   DeleteSGWin(winid);
-
+  delete_sgwin_entities(winid,v_flag);
 }
 
 /* for Fortran call */
@@ -988,7 +1042,7 @@ static void sci_menu_fileops()
   rep = sci_get_file_window(NULL,&file,".",0,1,&ierr,"File operations");
   if ( ierr == 0 && rep == TRUE ) 
     { 
-      StoreCommand(file); 
+      StoreCommand1(file,1);  /* we want the command to appear in the window */
       free(file); 
       file =NULL; 
     }
@@ -1005,7 +1059,7 @@ static void scig_menu_zoom(int winid)
   SetUnsetMenu(&winid,"3D Rot.",&ne,False);
   SetUnsetMenu(&winid,"UnZoom",&ne,False);
   SetUnsetMenu(&winid,"File",&ne,False);
-  scig_2dzoom(winid);
+  if ( scig_2dzoom(winid)==1) return; /* the window has been closed */
   SetUnsetMenu(&winid,"Zoom",&ne,True);
   SetUnsetMenu(&winid,"3D Rot.",&ne,True);
   SetUnsetMenu(&winid,"UnZoom",&ne,True);
@@ -1037,7 +1091,7 @@ static void scig_menu_rot3d(int winid)
   SetUnsetMenu(&winid,"UnZoom",&ne,False);
   SetUnsetMenu(&winid,"Zoom",&ne,False);
   SetUnsetMenu(&winid,"File",&ne,False);
-  scig_3drot(winid);
+  if (scig_3drot(winid)==1) return; /* the window has been closed */
   SetUnsetMenu(&winid,"3D Rot.",&ne,True);
   SetUnsetMenu(&winid,"UnZoom",&ne,True);
   SetUnsetMenu(&winid,"Zoom",&ne,True);
@@ -1142,10 +1196,10 @@ static int call_predefined_callbacks(char *name, int winid)
   else if (strcmp(name,"$gwplus")== 0)  sci_menu_gwplus();
   else if (strcmp(name,"$gwminus")== 0)  sci_menu_gwminus();
   else if (strcmp(name,"$about")== 0)  create_scilab_about ();
-  else if (strcmp(name,"$resume")== 0)  StoreCommand("resume");
-  else if (strcmp(name,"$abort")== 0)   StoreCommand("abort");
-  else if (strcmp(name,"$restart")== 0) StoreCommand("exec SCI/scilab.star;");
-  else if (strcmp(name,"$quit")== 0) StoreCommand("quit;");
+  else if (strcmp(name,"$resume")== 0) StoreCommand1("resume",1);
+  else if (strcmp(name,"$abort")== 0)  StoreCommand1("abort",1); 
+  else if (strcmp(name,"$restart")== 0) StoreCommand1("exec SCI/scilab.star;",1);
+  else if (strcmp(name,"$quit")== 0)  StoreCommand1("quit;",1);
   else return 0;
   return 1;
 }
