@@ -66,12 +66,7 @@ c     get arg2
       il2=iadr(lstk(top))
       il2r=il2
       if(istk(il2).lt.0) then
-         k=istk(il2+2)
-         if(k.ne.0) then
-            vol2=lstk(k+1)-lstk(k)
-         else
-            vol2=istk(il2+3)
-         endif
+         vol2=istk(il2+3)
          il2=iadr(istk(il2+1))
       else
          vol2=lstk(top+1)-lstk(top)
@@ -260,7 +255,6 @@ c     .  variables at the top of the stack
          if(err.gt.0) return
          rhs=2+m1i
       endif
-
       if(k+1.lt.m1) then
 c     put (ik+2)..(in) in the stack for further use
          ll=sadr(il1+3+m1)+istk(il1+1+(k+2))-1
@@ -315,9 +309,8 @@ c     - save context for recursion
       if (ptover(1,psiz)) return
       pstk(pt)=ilrec
       istk(ilrec)=2
-
       fun=0
-      fin=-3
+      fin=-5
       rstk(pt)=406
 c     *call* allops
       return
@@ -343,10 +336,15 @@ c     save context for recursion
       istk(ilrec)=4
       rstk(pt)=407
       rhs=3
+      fin=2
+      if (istk(iadr(lstk(top))).eq.1) then
+c     *call* matops insertion in an empty matrix
+         icall=4
+         return
+      endif
 c     *call* intl_i
       goto 05
  55   continue
-
 c     top variable  contains new Temp2 value
       pt=pt-1
 c     put Temp1=A3(i1)..(ik)  at the top of the stack
@@ -432,8 +430,11 @@ c     .  set lstk pointers to the newly created variable
 c     .  store it
             lhs=1
 c     .     modification according to those in run.f 22/08/00
-            if(rstk(pt).eq.601) then
+            if(rstk(pt).eq.607) then
 c     .        called by run
+               call stackp(istk(pstk(pt)),0)
+            elseif(rstk(pt).eq.601) then
+c     .        called by run version 2.7 and earlier
                call stackp(istk(pstk(pt)+1),0)
             else
 c     .        called by parse
