@@ -58,9 +58,10 @@ c     fclear    what    sciargs  chdir getwd ieee typename
 c     40         41       42     43     44     45    46
 c     global   clearglobal isglobal gstacksize getdate intppty
 c     47         48          49        50        51       52
-c     lasterror version
-c     53         54
-
+c     lasterror version loadhistory savehistory gethistory resethistory sendtobrowser macr2tree
+c     53         54        55          56         57          58        59            60
+c     hidetoolbar use_as_command    
+c     61             62
       if (ddt .eq. 4) then
          write(buf(1:4),'(i4)') fin
          call basout(io,wte,' matsys '//buf(1:4))
@@ -74,7 +75,8 @@ c
      +      251,300,320,350,370,380,390,400,410,420,
      +      450,500,510,600,610,620,630,640,650,660,
      +      670,680,681,682,683,684,690,691,692,693,
-     +      694,695,697,698),fin
+     +      694,695,697,698,699,700,701,702,703,704,
+     +      705,706),fin
 c     
 c     debug
  10   call intdebug()
@@ -249,6 +251,22 @@ c     mtlb_mode
       goto 999
  698  call intversion('version')
       goto 999
+ 699  call loadhistory('loadhistory')
+      goto 999
+ 700  call savehistory('savehistory')
+      goto 999
+ 701  call gethistory('gethistory')
+      goto 999
+ 702  call resethistory('resethistory')
+      goto 999
+ 703  call openbrowser('openbrowser')
+      goto 999    
+ 704  call macr2tree('macr2tree')
+      goto 999
+ 705  call hidetoolbar('hidetoolbar')
+      goto 999             
+ 706  call useascommand('use_as_command')
+      goto 999             
 
  998  continue
 c     fake calls : only to force the 
@@ -897,11 +915,21 @@ c
       logical checkrhs,checklhs,getrhsvar
       include '../stack.h'
       nbvars=0
-      if(.not.checkrhs(fname,1,1)) return
+      if(.not.checkrhs(fname,0,1)) return
       if(.not.checklhs(fname,1,1)) return
+      if(rhs.eq.0) then
+         if(.not.createvar(1,'i',1,1,l2)) return
+         istk(l2)=0
+         lhsvar(1)=1
+         if(.not.putlhsvar()) return
+         return 
+      endif
+ 
       if(.not.getrhsvar(1,'c',m1,n1,lr)) return 
+      call cluni0(cstk(lr:lr+m1*n1), buf,lp)
+      buf(lp+1:lp+1)=char(0)
       if(.not.createvar(2,'i',1,1,l2)) return
-      call scichdir(cstk(lr:lr+m1*n1),istk(l2))
+      call scichdir(buf(1:lp+1),istk(l2))
       if(istk(l2) .gt. 0) then 
          buf = fname // ': Internal Error' 
          call error(998)
@@ -1444,7 +1472,11 @@ c     *call* parse  macro
          istk(il)=0
          lhs=0
          err2=err1
-         err1=0
+         if(errct.eq.0) then
+            err1=0
+         else
+            top=top-1
+         endif
          return
       endif
       il=iadr(lstk(top))
@@ -1526,9 +1558,17 @@ c     on supprime tous les points d'arret de la macro
      $           bptlg(lgptrs(kmac)),1)
             do 356 kk=kmac,nmacs-1
                call icopy(nsiz,macnms(1,kk+1),1,macnms(1,kk),1)
-               lgptrs(kk)=lgptrs(kk+1)
+c Francois VOGEL, May 2004
+c the following statement was wrong - replaced with the next line
+c               lgptrs(kk)=lgptrs(kk+1)
+               lgptrs(kk+1)=lgptrs(kk)+lgptrs(kk+2)-lgptrs(kk+1)
  356        continue
-            lgptrs(nmacs)=lgptrs(nmacs+1)
+c            lgptrs(nmacs)=lgptrs(nmacs+1)
+            lgptrs(nmacs+1)=0
+c FV, May 2004
+c else part (just these two lines) added to cure bugzilla #718
+         else
+            lgptrs(nmacs+1)=0
          endif
          nmacs=nmacs-1
       else
@@ -1542,15 +1582,22 @@ c     on supprime le point d'arret specifie
  357     continue
          if(kk.eq.kk1) goto 360
 
+         kk2=kk-kk1-1
          if(kmac.lt.nmacs) then
             l0=lgptrs(kmac+1)
             do 358 kk=kmac+1,nmacs
-               call icopy(lgptrs(kk+1)-l0,bptlg(l0),1,bptlg(l0-1),1)
+c FV, May 2004
+c changed to remove at once multiple breakpoints on a single line
+c               call icopy(lgptrs(kk+1)-l0,bptlg(l0),1,bptlg(l0-1),1)
+               call icopy(lgptrs(kk+1)-l0,bptlg(l0),1,bptlg(l0-kk2),1)
                l0=lgptrs(kk+1)
-               lgptrs(kk+1)=lgptrs(kk+1)-1
+c               lgptrs(kk+1)=lgptrs(kk+1)-1
+               lgptrs(kk)=lgptrs(kk)-kk2
  358        continue
          endif
-         lgptrs(kmac+1)=lgptrs(kmac+1)-1
+c         lgptrs(kmac+1)=lgptrs(kmac+1)-1
+         lgptrs(nmacs+1)=lgptrs(nmacs+1)-kk2
+         lgptrs(nmacs+2)=0
          if(lgptrs(kmac+1).eq.lgptrs(kmac)) then
             if(kmac.lt.nmacs) then
                do 359 kk=kmac,nmacs-1
@@ -1559,6 +1606,7 @@ c     on supprime le point d'arret specifie
  359           continue
             endif
             lgptrs(nmacs)=lgptrs(nmacs+1)
+            lgptrs(nmacs+1)=0
             nmacs=nmacs-1
          endif
       endif
@@ -1952,7 +2000,7 @@ c     .  check if the variable is already defined in global area
          fin=-5
          call stackg(id)
          if(err.gt.0) return
-         if (gtop+1.gt.isizt) then
+         if (gtop+2.gt.isizt) then
             call error(262)
             return
          endif
@@ -1964,6 +2012,13 @@ c     .     check if it is defined in local area
             if(err.gt.0) return
             if(fin.eq.0) then
 c     .        no, create an empty variable in the global area
+               vol=5
+               if (lstk(gtop+1)+vol.gt.lstk(gbot)) then
+c     .           not enought memory, realloc
+                  mem=lstk(gbot)-lstk(isiz+2)+max(vol+1,10000)
+                  call reallocglobal(mem)
+                  if(err.gt.0) return
+               endif
                gtop=gtop+1
                call putid(idstk(1,gtop),id)
                infstk(gtop)=0
@@ -1976,8 +2031,9 @@ c     .        no, create an empty variable in the global area
             else
 c     .        yes, move it to the global area
                vol=lstk(fin+1)-lstk(fin)
-               if (lstk(gtop+1)+vol.gt.lstk(gbot)) then
-                  mem=lstk(gbot)-lstk(isiz+2)+vol+1
+               if (lstk(gtop+1)+vol+10.ge.lstk(gbot)) then
+c     .           max(vol+1,100000) to avoid too many reallocation
+                  mem=lstk(gbot)-lstk(isiz+2)+max(vol+1,10000)
                   call reallocglobal(mem)
                   if(err.gt.0) return
                endif
@@ -2489,6 +2545,10 @@ c     resume in a pause
          pt=pt-3
          k=lpt(1)-(13+nsiz)
          bot=lin(k+5)
+         if(macr.ne.0.or.paus.ne.0) then
+            lpts=lpt(1)
+            lpt(1)=lin(k+1)
+         endif
          mrhs=rhs
          rhs=0
          paus=paus-1
@@ -2497,6 +2557,9 @@ c     resume in a pause
             pt=pt-1
  155     continue
          paus=paus+1
+         if(macr.ne.0.or.paus.ne.0) then
+            lpt(1)=lpts
+         endif
          lin(k+5)=bot
          top=top-count
       else
@@ -2538,24 +2601,61 @@ c
 c      if(rhs.eq.1) lnb=1
       if(nmacs.gt.0) then
          do 323 kmac=1,nmacs
-            if(eqid(macnms(1,kmac),id)) goto 325
+c Francois VOGEL, May 2004
+c            if(eqid(macnms(1,kmac),id)) goto 325
+            if(eqid(macnms(1,kmac),id)) goto 324
  323     continue
       endif
+C Serge Steer May 2004
+      if (nmacs.ge.maxdb) then
+         buf='Too many functions contain breakpoints'
+         call error(9999)
+         return
+      endif
+
       nmacs=nmacs+1
       call putid(macnms(1,nmacs),id)
+C Serge Steer May 2004
+      if (lgptrs(nmacs)+1.gt.maxbpt) then
+         buf='Too many defined  breakpoints'
+         call error(9998)
+         return
+      endif
+  
       lgptrs(nmacs+1)=lgptrs(nmacs)+1
       bptlg(lgptrs(nmacs))=lnb
       goto 330
+c FV, May 2004
+c do statement added to avoid definition of duplicate bpts
+ 324  do 3241 kk=lgptrs(kmac),lgptrs(kmac+1)-1
+          if (bptlg(kk).eq.lnb) goto 330
+ 3241 continue
  325  if(kmac.eq.nmacs) then
          lgptrs(nmacs+1)=lgptrs(nmacs+1)+1
+C Serge Steer May 2004
+         if (lgptrs(nmacs+1)-1.gt.maxbpt) then
+            buf='Too many defined  breakpoints'
+            call error(9998)
+            return
+         endif
          bptlg(lgptrs(nmacs+1)-1)=lnb
       else
+C Serge Steer May 2004
+        if (lgptrs(nmacs+1)-1.gt.maxbpt) then
+            buf='Too many defined  breakpoints'
+            call error(9998)
+            return
+         endif
+  
          do 326 kk=nmacs,kmac,-1
             l0=lgptrs(kk)
             call icopy(lgptrs(kk+1)-l0,bptlg(l0),-1,bptlg(l0+1),-1)
             lgptrs(kk+1)=lgptrs(kk+1)+1
  326     continue
-         bptlg(lgptrs(kmac+1)-1)=lnb
+c FV, May 2004
+c this statement was wrong - replaced with next line
+c         bptlg(lgptrs(kmac+1)-1)=lnb
+         bptlg(lgptrs(kmac))=lnb
       endif
  330  continue
       call objvide('setbpt',top)
@@ -2588,6 +2688,11 @@ c
       if(.not.getscalar('stacksize',top,top,l)) return
       top=top-1
 c
+      if (stk(l).lt.1000.or.stk(l).gt.2.0d0**31) then
+         buf='Out of bounds value for stacksize argument'
+         call error(1504)
+         return
+      endif
       mem=stk(l)
       memold=lstk(isiz)-lstk(1)
       if (mem.eq.memold) goto 50
@@ -2930,9 +3035,9 @@ c     .  get stored variables
       subroutine intgetdate()
 c     Copyright INRIA
       include '../stack.h'
-      parameter (nf=9)
+      parameter (nf=10)
       integer w(nf),dt
-      logical checkrhs,checklhs,cremat,getscalar
+      logical checkrhs,checklhs,cremat,getscalar,getrmat
       integer gettype
 c
       rhs=max(0,rhs)
@@ -2945,12 +3050,20 @@ c
             top=top-1
             n=1
          else 
-            if(.not.getscalar('getdate', top,top, lr)) return
-            dt=stk(lr)
-            call convertdate(dt,w)
-            n=nf
+            if(.not.getrmat('getdate', top, top, m1, n1, lr)) return
+            top=top+1
+            if(.not.cremat('getdate',top,0,m1*n1,nf,l,lc)) return
+            do 05 i=0,m1*n1-1
+               dt=stk(lr+i)
+               call convertdate(dt,w)
+c     .         dt contains a number of seconds, number of milliseconds
+C     .         w(10) must be 0
+               w(10)=0
+               call int2db(nf,w,1,stk(l+i),m1*n1)
+ 05         continue
+            call copyobj('getdate',top,top-1)
             top=top-1
-            goto 10
+            return
          endif
       else
          job=1
@@ -3008,3 +3121,54 @@ c     set
       endif
       return
       end
+
+      subroutine useascommand(fname)
+c     Copyright INRIA
+      include '../stack.h'
+      logical checkrhs,checklhs,cremat,getscalar,getsmat,checkval
+      integer topk,id(nsiz)
+      integer iadr,sadr
+      character*1 opt
+      character*(*) fname
+c
+c    
+      iadr(l)=l+l-1
+      sadr(l)=(l/2)+1
+c
+      rhs=max(0,rhs)
+      if(.not.checkrhs(fname,1,2)) return
+      if(.not.checklhs(fname,1,1)) return
+
+      job=1
+      topk=top
+      
+      if(rhs.eq.2) then
+         if(.not.getsmat(fname,topk,top,m,n,1,1,l,nl))return
+         if (nl.ne.1) then
+            err=2
+            call error(36)
+            return
+         endif
+         call cvstr(nl,istk(l),opt,1)
+         top=top-1
+
+         if(opt.eq.'a') then
+            job=1
+         elseif (opt.eq.'d') then
+            job=2
+         else
+            err=2
+            call error(36)
+            return
+         endif
+      endif
+      if(.not.getsmat(fname,topk,top,m,n,1,1,l,n1)) return
+      if(.not.checkval(fname,m*n,1) ) return
+      call namstr(id,istk(l),n1,0)
+      call comand(id,job)
+      if(err.gt.0) return
+      il=iadr(lstk(top))
+      istk(il)=0
+      lstk(top+1)=lstk(top)+1
+      return
+      end
