@@ -9,9 +9,12 @@
 
 #include <string.h>
 #include <stdio.h>
-#include "../stack-c.h"
+#include "../stack-c.h" 
 #include "../sun/men_Sutils.h" 
 
+#ifdef WIN32
+#define abs(x) ((x) >= 0 ? (x) : -(x)) /* pour abs  C2F(mvfromto) line 2689 */
+#endif
 /* Table of constant values */
 
 static integer cx1 = 1;
@@ -1195,9 +1198,9 @@ int C2F(setworksize)(number,size)
     return FALSE_ ;
   }
   *lstk(lw1+1) = *lstk(lw1) + *size ;
-  C2F(intersci).ntypes[lw1 - 1] = '$';
-  C2F(intersci).iwhere[lw1 - 1] = *lstk(lw1);
-  C2F(intersci).lad[lw1 - 1] = 0; /* not to be used XXXX */ 
+  C2F(intersci).ntypes[*number - 1] = '$';
+  C2F(intersci).iwhere[*number - 1] = *lstk(lw1);
+  C2F(intersci).lad[*number - 1] = 0; /* not to be used XXXX */ 
   return TRUE_; 
 }
 
@@ -2215,8 +2218,7 @@ int C2F(scibuiltin)(number, ifun, ifin, mlhs, mrhs)
     goto L9999;
   }
   if (Top - Lhs + 1 > 0) {
-    C2F(iset)(&Lhs, &cx0, &C2F(vstk).Infstk[Top - Lhs], &
-	      cx1);
+    C2F(iset)(&Rhs, &cx0, &C2F(vstk).Infstk[Top - Lhs], &cx1);
   }
  L91:
   k = C2F(com).fun;
@@ -2638,7 +2640,8 @@ int C2F(putlhsvar)()
 static int C2F(mvfromto)(itopl, ix)
      integer *itopl, *ix;
 {
-  integer ix1, m,n,it,lcs,lrs,l,ilp,size,pointed;
+  integer ix1, m,n,it,lcs,lrs,l,size,pointed;
+  unsigned long int ilp;
   unsigned char Type ;
   double wsave;
 
@@ -2825,7 +2828,7 @@ void strcpy_tws(str1,str2,len)
      int len;
 {
   int i; 
-  for ( i =0 ; i  < strlen(str2); i++ ) str1[i]=str2[i];
+  for ( i =0 ; i  < (int)strlen(str2); i++ ) str1[i]=str2[i];
   for (i = strlen(str2) ; i < len ; i++) str1[i]=' ';
   str1[len-1] ='\0';
 }
@@ -3150,7 +3153,7 @@ int C2F(createdata)(lw, n)
   return TRUE_; 
 }
 
-
+ 
 void *GetData(lw)
      /* Usage: header = (int *) GetData(lw); header[0] = type of variable lw etc */
      int lw;
