@@ -53,6 +53,7 @@ int C2F(readmat)(namex, m, n, scimat, name_len)
  *                      scimat(3)=Amat(3,1) 
  *                      scimat(4)=Amat(1,2) ... 
  *                      scimat(5)=Amat(3,2) 
+ *                      scimat(6)=Amat(3,2) 
  *----------------------------------------------------------------*/
 
 int C2F(creadmat)(namex, m, n, scimat, name_len)
@@ -81,6 +82,60 @@ int C2F(creadmat)(namex, m, n, scimat, name_len)
 
     return TRUE_;
 }
+/*----------------------------------------------------------------
+ * creadcmat reads vector/matrix in scilab's internal stack 
+ * calling sequence 
+ *     logic=creadcmat('matrixname',m,n,scimat) 
+ *  matrixname: character string; name of the scilab variable. 
+ *  m: number of rows (output of readmat) 
+ *  n: number of columns (output of readmat) 
+ *  scimat: matrix entries stored columnwise (output of readmat) 
+ *    Example of use: 
+ *    Amat is a real 2 x 3 scilab matrix 
+ *    your subroutine should be as follows: 
+ *    subroutine mysubr(...) 
+ *    ... 
+ *    call readmat('Amat',m,n,scimat) 
+ *    => m=3 , n=2, and scimat(1)=Amat(1,1) 
+ *                      scimat(2)=Amat(2,1) 
+ *                      scimat(3)=Amat(3,1) 
+ *                      scimat(4)=Amat(1,2) ... 
+ *                      scimat(5)=Amat(3,2) 
+ *
+ * Note d'Albert Y
+ * 20/12/2003
+ *    Cette routine est une simple copie de creadmat et lgrement
+ *    modifie pour les matrices complexes
+ *
+ *----------------------------------------------------------------*/
+
+int C2F(creadcmat)(namex, m, n, scimat, name_len)
+     char *namex;
+     integer *m, *n;
+     double *scimat;
+     unsigned long name_len;
+{
+    integer l, ix1;
+    integer id[nsiz];
+
+    C2F(str2name)(namex, id, name_len);
+    /* read   : from scilab stack -> fortran variable */
+    Fin = -1;
+    C2F(stackg)(id);
+    if (Err > 0) return FALSE_ ; 
+    if (Fin == 0) {
+      Scierror(4,"Undefined variable %s\r\n",get_fname(namex,name_len));
+      return FALSE_;
+    }
+    if ( *infstk(Fin ) == 2)  Fin = *istk(iadr(*lstk(Fin )) + 1 +1);
+    /* get matrix data pointer */
+    if (! C2F(getcmat)("creadcmat", &Fin, &Fin, m, n, &l, 8L)) 	return FALSE_;
+    ix1 = *m * *n;
+    C2F(dmcopy)(stk(l ), m, scimat, m, m, n);
+    C2F(dmcopy)(stk(l+ix1 ), m, scimat+ix1, m, m, n);
+
+    return TRUE_;
+}
 
 /*----------------------------------------------------------------
  * cwritemat writes vector/matrix in scilab's internal stack
@@ -125,7 +180,7 @@ int C2F(putvar)(number, namex, name_len)
      unsigned long name_len;
 {
   integer Rhs_k = Rhs , Top_k = Top ;
-  integer l4, id[nsiz], lc, lr, cx0=1;
+  integer l4, id[nsiz],/* lc, lr,*/ cx0=1;
   
   C2F(str2name)(namex, id, name_len);
   Top = *number + Top -Rhs;
@@ -380,6 +435,109 @@ int C2F(cmatptr)(namex, m, n, lp, name_len)
     return TRUE_ ;
 }
 
+/*----------------------------------------------------------------
+ * !purpose 
+ *     cmatcptr returns the adress of complex matrix "name" 
+ *     in scilab's internal stack 
+ *     m=number of rows 
+ *     n=number of columns 
+ *     stk(lp),stk(lp+1),...,stk(lp+m*n-1)= entries (columnwise) 
+ *     If matrix "name" not in Scilab stack, returns m=n=-1. 
+ *    Example of use: 
+ *    Amat is a real 2 x 3 scilab matrix 
+ *    your subroutine should be as follows: 
+ *    subroutine mysubr(...) 
+ *    ... 
+ *    logic= cmatptr('Amat',m,n,lp) 
+ *    => m=3 , n=2, and stk(lp)=Amat(1,1) 
+ *                      stk(lp+1)=Amat(2,1) 
+ *                      stk(lp+2)=Amat(3,1) 
+ *                      stk(lp+3)=Amat(1,2) ... 
+ *                      stk(lp+5)=Amat(3,2) 
+ *   see example in fydot.f file 
+ *   see also  readmat.f, matz.f
+ * 
+ * Note d'Albert Y
+ * 20/12/2003
+ *    Cette routine est une simple copie de creadmat et lgrement
+ *    modifie pour les matrices complexes
+ *
+ *----------------------------------------------------------------*/
+
+int C2F(cmatcptr)(namex, m, n, lp, name_len)
+     char *namex;
+     integer *m, *n, *lp;
+     unsigned long name_len;
+{
+    integer id[nsiz];
+    C2F(str2name)(namex, id, name_len);
+    /* get the position in fin */
+    Fin = -1;
+    C2F(stackg)(id);
+    if (Fin == 0) {
+      Scierror(4,"Undefined variable %s\r\n",get_fname(namex,name_len));
+      *m = -1;
+      *n = -1;
+      return FALSE_;
+    }
+    /* get data */
+    if (*infstk(Fin ) == 2) {
+	Fin = *istk(iadr(*lstk(Fin )) + 1 +1);
+    }
+    if (! C2F(getcmat)("creadmat", &Fin, &Fin, m, n, lp, 8L)) {
+	return FALSE_;
+    }
+    return TRUE_ ;
+}
+
+/*----------------------------------------------------------------
+ * !purpose 
+ *     matptr returns the adress of real matrix "name" 
+ *     in scilab's internal stack 
+ *     m=number of rows 
+ *     n=number of columns 
+ *     stk(lp),stk(lp+1),...,stk(lp+m*n-1)= entries (columnwise) 
+ *     If matrix "name" not in Scilab stack, returns m=n=-1. 
+ *    Example of use: 
+ *    Amat is a real 2 x 3 scilab matrix 
+ *    your subroutine should be as follows: 
+ *    subroutine mysubr(...) 
+ *    ... 
+ *    logic= cmatptr('Amat',m,n,lp) 
+ *    => m=3 , n=2, and stk(lp)=Amat(1,1) 
+ *                      stk(lp+1)=Amat(2,1) 
+ *                      stk(lp+2)=Amat(3,1) 
+ *                      stk(lp+3)=Amat(1,2) ... 
+ *                      stk(lp+5)=Amat(3,2) 
+ *   see example in fydot.f file 
+ *   see also  readmat.f, matz.f 
+ *----------------------------------------------------------------*/
+
+int C2F(cmatsptr)(namex, m, n, ix, j, lp, nlr, name_len)
+     char *namex;
+     integer *m, *n, *lp, *ix, *j, *nlr;
+     unsigned long name_len;
+{
+    integer id[nsiz];
+    C2F(str2name)(namex, id, name_len);
+    /* get the position in fin */
+    Fin = -1;
+    C2F(stackg)(id);
+    if (Fin == 0) {
+      Scierror(4,"Undefined variable %s\r\n",get_fname(namex,name_len));
+      *m = -1;
+      *n = -1;
+      return FALSE_;
+    }
+    /* get data */
+    if (*infstk(Fin ) == 2) {
+	Fin = *istk(iadr(*lstk(Fin )) + 1 +1);
+    }
+    if (! C2F(getsmat)("creadmat", &Fin, &Fin, m, n, ix, j, lp, nlr, 8L)) {
+	return FALSE_;
+    }
+    return TRUE_ ;
+}
 
 void *Name2ptr(namex)
      char *namex;
@@ -457,7 +615,7 @@ int C2F(str2name)(namex, id, name_len)
     integer ix;
     integer lon;
     lon = 0;
-    for (ix = 0 ; ix < name_len ; ix++ ) {
+    for (ix = 0 ; ix < (integer) name_len ; ix++ ) {
       if ( namex[ix] == '\0') break;
       ++lon;
     }
