@@ -1,5 +1,11 @@
 #include <string.h>
+#ifdef __STDC__
+#include <stdlib.h>
+#else
 #include <malloc.h>
+#endif
+
+extern void cerro();
 
 #include "../machine.h"
 
