@@ -2,8 +2,11 @@
 typedef struct {
   double* x;      /* continuous  state */
   integer* xptr;  /* vector of pointers on block states */
+  integer* zcptr;  /* vector of pointers on block zero crosses */
   double* z;      /* discrete state */
   integer* zptr;  /* vector of pointers on block states */
+  integer* mod;      /* modes of the blocks */
+  integer* modptr;  /* vector of pointers */
   integer* iz;      /* unused */
   integer* izptr;  /* vector of pointers on iz */
   integer* inpptr; /* vector of pointers on block inputs */
@@ -36,4 +39,5 @@ typedef struct {
   integer *ordptr; /* block types */
   integer *critev; /* block types */
   integer *iwa; /* integer work space 2*nblk */
+  integer *mask; /* integer work space ng for mask */
 } ScicosImport;
