@@ -6,7 +6,7 @@ c     Copyright INRIA
       integer start,run,finish,flag,linear
       parameter (start=28,run=27,finish=15,linear=21)
       integer id(nsiz)
-      double precision simpar(6)
+      double precision simpar(7)
       integer pointi
       integer funnum
       external funnum
@@ -57,7 +57,7 @@ c       --   subvariable z0(state) --
         n1e3 = istk(il1e3+1)
         l1e3 = sadr(il1e3+4)
 c      
-c       --   subvariable iz0(state)  NO MORE USED --
+c       --   subvariable work(state) --
         il1e4=iadr(l1+istk(il1+5)-1)
         n1e4 = istk(il1e4+1)
         l1e4 = sadr(il1e4+4)
@@ -82,6 +82,8 @@ c       --   subvariable outtb(state) --
         n1e8 = istk(il1e8+1)
         nout = n1e8
         l1e8 = sadr(il1e8+4)
+
+c      
 c       checking variable tcur (number 2)
 c       
         il2 = iadr(lstk(top-rhs+2))
@@ -141,7 +143,7 @@ c       --   subvariable zptr(sim) --
         n4e4 = istk(il4e4+1)
         l4e4 = sadr(il4e4+4)
 c      
-c       --   subvariable izptr (sim) NO MORE USED --
+c       --   subvariable zcptr (sim) 
         il4e5=iadr(l4+istk(il4+6)-1)
         n4e5 = istk(il4e5+1)
         l4e5 = sadr(il4e5+4)
@@ -243,7 +245,7 @@ c       --   subvariable critev(sim) --
         n4e22 = istk(il4e22+1)
         l4e22 = sadr(il4e22+4)
 c      
-c       --   subvariable nblk(sim) --
+c       --   subvariable nb(sim) --
         il4e23=iadr(l4+istk(il4+24)-1)
         l4e23 = sadr(il4e23+4)
 c
@@ -303,6 +305,14 @@ c       --   subvariable labels(sim) --
            nlab=1
            call iset(n4e30,1,istk(labptr),1)
         endif
+
+c       --   subvariable modptr(sim) --
+        il4e31=iadr(l4+istk(il4+32)-1)
+        n4e31 = istk(il4e31+1)
+        l4e31 = sadr(il4e31+4)
+c      
+c 
+
 c
 c       checking variable flag (number 5)
         il5 = iadr(lstk(top-rhs+5))
@@ -332,7 +342,7 @@ c       checking variable flag (number 5)
 
         if(rhs.ge.6) then
 c     checking variable simpar (number 6) 
-c      [atol  rtol ttol, deltat, scale, impl]
+c      [atol  rtol ttol, deltat, scale, impl, hmax]
 c     
            il6 = iadr(lstk(top-rhs+6))
            if (istk(il6) .ne. 1) then
@@ -341,7 +351,7 @@ c
               return
            endif
            m6 = istk(il6+1)*istk(il6+2)
-           if (m6 .ne. 5.and. m6.ne.4.and. m6.ne.6) then
+           if (m6 .ne. 5.and. m6.ne.4.and. m6.ne.6.and. m6.ne.7) then
               err = 6
               call error(89)
               return
@@ -359,6 +369,10 @@ c
           call error(42)
           return
         endif
+        if (n4e3 .ne. n4e5) then
+          call error(42)
+          return
+        endif
         if (n4e3 .ne. n4e6) then
           call error(42)
           return
@@ -416,8 +430,7 @@ c       cross equal output variable checking
 c       not implemented yet
         call entier(n4e3,stk(l4e3),istk(iadr(l4e3)))
         call entier(n4e4,stk(l4e4),istk(iadr(l4e4)))
-c        call entier(n1e4,stk(l1e4),istk(iadr(l1e4)))
-c        call entier(n4e5,stk(l4e5),istk(iadr(l4e5)))
+        call entier(n4e5,stk(l4e5),istk(iadr(l4e5)))
         call entier(n1e6,stk(l1e6),istk(iadr(l1e6)))
         call entier(n4e6,stk(l4e6),istk(iadr(l4e6)))
         call entier(n4e7,stk(l4e7),istk(iadr(l4e7)))
@@ -429,7 +442,7 @@ c        call entier(n4e5,stk(l4e5),istk(iadr(l4e5)))
         call entier(n4e14,stk(l4e14),istk(iadr(l4e14)))
         call entier(n4e15,stk(l4e15),istk(iadr(l4e15)))
         call entier(n4e16,stk(l4e16),istk(iadr(l4e16)))
-c        call entier(n4e17*m4e17,stk(l4e17),istk(iadr(l4e17)))
+        call entier(n4e31,stk(l4e31),istk(iadr(l4e31)))
         call entier(n4e18*m4e18,stk(l4e18),istk(iadr(l4e18)))
         call entier(n4e19*m4e19,stk(l4e19),istk(iadr(l4e19)))
         call entier(n4e20*m4e20,stk(l4e20),istk(iadr(l4e20)))
@@ -449,75 +462,31 @@ c
            call dcopy(4,stk(l6),1,simpar,1)
            simpar(5)=  0.d0
            simpar(6)=  0.d0
+           simpar(7)=  0.d0
         elseif(m6.eq.5) then
            call dcopy(5,stk(l6),1,simpar,1)
            simpar(6)=  0.d0
-        else
+           simpar(7)=  0.d0
+        elseif(m6.eq.6) then
            call dcopy(6,stk(l6),1,simpar,1)
+           simpar(7)=  0.d0
+        else
+           call dcopy(7,stk(l6),1,simpar,1)
         endif
         solver=simpar(6)
 c
         lfunpt=iadr(lw)
         lw=sadr(lfunpt+nblk)
 c
-        ncst = n1e2
-        ndst = n1e3
         linpptr=iadr(l4e6)
-        linplnk=iadr(l4e8)
         llnkptr=iadr(l4e10)
         iloutptr=iadr(l4e7)
 c
-c        niz = n1e4
-c        liz0=iadr(l1e4)
 
-        ng=0
-c        do 02 kfun = ncblk+ndblk+1,nblk
-        do 02 kfun = 1,nblk
-           if(istk(ilztyp+kfun-1).eq.1) then
-c     .    loop on block input ports
-              do 01 kport=istk(linpptr-1+kfun),istk(linpptr+kfun)-1
-c     .       get corresponding link pointer 
-                 klink=istk(linplnk-1+kport)
-                 ng=ng+istk(llnkptr+klink)-istk(llnkptr-1+klink)
- 01           continue
-           endif
- 02     continue
-c     
-c     maximum block state and input sizes      
-c        ilst=iadr(l4e3)
+c
+c        ng=istk(iadr(l4e5)+n4e5-1)-1
+
         ilinp=iadr(l4e4)
-c        ilout=iadr(l4e5)
-c        ilclk=iadr(l4e11)
-    
-        if(solver.eq.0) then 
-c     .    see also paragraph f below.
-c     .    nout is for flag 6 point fix iteration and
-c     .    temp storage in cossim
-c     .    22+ncst*max(16,ncst + 9)+3*ng is for lsodar RWORK
-           nn42=nout+22+ncst*max(16,ncst + 9)+3*ng 
-           lw42=lw
-           lw=lw+nn42
-c     .    lsodar IWORK 20 + neq
-           nn43= 20 + ncst + 2*ng
-           lw43=lw
-           lw=lw+nn43
-           nn44=istk(iadr(l4e15)+n4e15-1)
-           lw44=lw
-           lw=lw+sadr(nn44)+1
-        elseif(solver.eq.100) then
-c     .    daskr
-           ncst=ncst/2
-           MAXORD=5
-           nn42=nout+60+max(MAXORD+4,7)*ncst+ncst**2+3*ng
-           lw42=lw
-           lw=lw+nn42
-           nn43=40 +ncst+ ncst + 2*ng
-           lw43=lw
-           lw=lw+nn43
-           nn44=istk(iadr(l4e15)+n4e15-1)
-           lw44=lw
-           lw=lw+sadr(nn44)+1
-        endif
         err=lw-lstk(bot)
         if (err .gt. 0) then
           call error(17)
@@ -566,7 +535,9 @@ C     Block is defined by a predefined scilab function
 c
         if(ddt.ne.0) idb=1
 c
-        call scicos(stk(l1e2),istk(iadr(l4e3)),stk(l1e3),istk(ilinp),
+        call scicos(stk(l1e2),istk(iadr(l4e3)),stk(l1e3),
+     $       stk(l1e4),istk(ilinp),
+     $       istk(iadr(l4e31)),
      &       istk(llab),istk(labptr),stk(l2),stk(l3),stk(l1e5),
      $       istk(iadr(l1e6)),n1e5,pointi,stk(l1e8),nout,
      $       istk(lfunpt),istk(iadr(l4e28)),istk(linpptr),
@@ -577,9 +548,8 @@ c
      $       istk(iadr(l4e18)),istk(iadr(l4e19)),n4e19,
      $       istk(iadr(l4e29)),n4e29,
      $       istk(iadr(l4e20)),n4e20,istk(iadr(l4e21)),n4e21,
-     $       istk(iadr(l4e22)),nblk,istk(iadr(l4e24)),ng,
-     $       istk(iadr(l4e27)),n4e27,simpar,stk(lw42),stk(lw43),
-     $       stk(lw44),flag,ierr)
+     $       istk(iadr(l4e22)),nblk,istk(iadr(l4e24)),istk(iadr(l4e5)),
+     $       istk(iadr(l4e27)),n4e27,simpar,flag,ierr)
         idb=0
         if (ierr .gt. 0 ) then
            if(ierr.eq.1) then
@@ -609,6 +579,16 @@ c
            elseif(ierr.eq.4) then
               buf='algrebraic loop detected'
               kfun=0
+           elseif(ierr.eq.5) then
+              buf='cannot allocate memory'
+              kfun=0
+           elseif(ierr.eq.21) then
+              write(buf,'(''cannot allocate memory in block='',i5)') 
+     $             kfun
+              kfun=0
+           elseif(ierr.eq.22) then
+              buf='sliding mode condition, cannot integrate'
+              kfun=0
            else
               buf='scicos unexpected error,please report...'
               kfun=0
