@@ -1,5 +1,11 @@
 #include <string.h>
 
+#ifdef WIN32
+	#include <windows.h>
+	#pragma comment(lib, "winmm.lib")
+#endif
+
+
 #include "../stack-c.h"
 #include "sox.h" 
 #include "stdio.h" 
@@ -14,6 +20,7 @@ extern int C2F(cluni0) __PARAMS((char *name, char *nams, integer *ln, long int n
 #endif 
 
 
+
 /******************************************
  * SCILAB function : savewave, 
  ******************************************/
@@ -105,6 +112,46 @@ int intsloadwave(char *fname)
   return 0;
 }
 
+/* Play Sound for windows */
+/* Allan CORNET 18/01/2004 */
+int C2F(playsound)(char * filename)
+{
+	#ifdef WIN32
+	// Stop Playing
+	PlaySound(NULL,NULL,SND_PURGE);	
+
+	// Play Wav file	
+     	PlaySound(filename,NULL,SND_ASYNC|SND_FILENAME);
+     	#endif
+     	
+	return 0;
+}
+
+
+
+/******************************************
+ * SCILAB function : PlaySound
+ * Allan CORNET 18/01/2004 
+ ******************************************/
+int intPlaysound (char *fname)
+{
+  
+  int m1,n1,l1;
+  CheckRhs(1,1);
+  
+  /*  checking variable file */
+  GetRhsVar(1,"c",&m1,&n1,&l1);
+  /*** first call to get the size **/
+  lout=FILENAME_MAX;
+  C2F(cluni0)(cstk(l1), filename, &out_n,m1*n1,lout);
+  
+  C2F(playsound)(filename);
+  
+  LhsVar(0)=0;
+  PutLhsVar();
+  return 0;
+}
+
 /******************************************
  * SCILAB function : mopen, 
  ******************************************/
@@ -477,6 +524,28 @@ int intsmclearerr(char *fname)
   PutLhsVar();
   return 0;
 }
+/******************************************
+ * SCILAB function : merror, 
+ ******************************************/
+
+int intsmerror(char *fname)
+{
+  int m1,n1,l1,un=1,lr;
+  int fd=-1;
+  Nbvars=0;
+  CheckRhs(0,1);
+  CheckLhs(1,1);
+  if ( Rhs >= 1) 
+    {
+      GetRhsVar(1,"i",&m1,&n1,&l1);
+      fd  = *istk(l1);
+    }
+  CreateVar(Rhs+1,"d",&un,&un,&lr);
+  C2F(merror)(&fd,stk(lr));
+  LhsVar(1)= Rhs+1;
+  PutLhsVar();
+  return 0;
+}
 
 extern int int_objprintf __PARAMS((char *));
 extern int int_objfprintf __PARAMS((char *));
@@ -516,6 +585,9 @@ static TabF Tab[]={
  {int_objfscanfMat,"fscanfMat"},
  {int_objfprintfMat,"fprintfMat"},
  {int_objnumTokens,"NumTokens"},
+ {intPlaysound,"PlaySound"},
+ {intsmerror, "merror"}
+ 
 };
 
 int C2F(soundi)(void)
