@@ -282,12 +282,6 @@ c     [m,n] given
          endif
          top=top-1
          lw=lstk(top+1)
-      else
-         il=iadr(lstk(top))
-         if(istk(il+1)*istk(il+2).eq.0) then
-            top=top-1
-            return
-         endif
       endif
       
       ilij=iadr(lstk(top-1))
@@ -296,8 +290,7 @@ c     [m,n] given
          call error(52)
          return
       endif
-      if(istk(ilij+1).ne.0.and.
-     $     istk(ilij+1).ne.2.and.istk(ilij+2).ne.2) then
+      if(istk(ilij+1).ne.0.and.istk(ilij+2).ne.2) then
          err=2
          call error(60)
          return
@@ -308,6 +301,15 @@ c     [m,n] given
       if(nel.gt.0) then
          call entier(nel*2,stk(lij),istk(ilij))
       endif
+c     test if indices are all strictly positive
+      do 05 i=0,2*nel-1
+         if (istk(ilij+i).le.0) then
+            call error(21)
+            return
+         endif
+ 05   continue
+
+c     compute number of rows if is not given
       if(rhs.eq.2) then
          mm=0
          do 10 i=0,nel-1
@@ -1363,6 +1365,7 @@ c
       include '../stack.h'
       integer id(nsiz),top0,tops
       integer iadr, sadr
+      double precisionx sz, szr
 c
       iadr(l)=l+l-1
       sadr(l)=(l/2)+1
@@ -1448,8 +1451,11 @@ c     checking variable sp
       m=istk(il1+1)
       n=istk(il1+2)
 
-
-      if(m*n.ne.mr*nr) then
+C     to avoid integer overflow
+      sz=dble(m)*dble(n)
+      szr=dble(mr)*dble(nr)
+      
+      if(sz.ne.szr) then
          call error(60)
          return
       endif
