@@ -81,7 +81,6 @@ c     .     error has occurred in an external
          elseif(rstk(p).eq.502) then 
             if(rstk(p-1).eq.903) then
 c     .     error has occurred in execstr
-
                errtyp=0
                pt0=p
             elseif(rstk(p-1).eq.904.or.rstk(p-1).eq.901) then
@@ -108,7 +107,7 @@ c depilement de l'environnement
       goto(36,36,37) r-500
       if(r.eq.904) then
          if (ids(2,pt).ne.0) then
-c     .     fermeture du fichier dans le cas getf(  'c')
+c     .     getf(  'c') case, close the file
             mode(1)=0
             call clunit(-ids(2,pt),buf,mode)
          endif
@@ -294,12 +293,12 @@ c
       go to 999
    33 call msgout(io,lunit,'too many '':''')
       go to 999
-   34 call msgout(io,lunit,'incorrect clause ')
+   34 call msgout(io,lunit,'incorrect control intruction syntax')
       errtyp=1
       go to 999
    35 continue
       call cvname(ids(1,pt),buf,1)
-      call msgout(io,lunit,'error in '//buf(1:nlgh))
+      call msgout(io,lunit,'Syntax error in '//buf(1:nlgh))
       errtyp=1
       go to 999
    36 if(err.ne.1) then
@@ -1221,17 +1220,25 @@ C     errors from semidef
       endif
       goto 999
  272  continue
+      call msgout(io,lunit, 'endfunction is missing')
       goto 999
  273  continue
+      call msgout(io,lunit,
+     $     'Instruction left hand side: '//
+     $     'waiting for a dot or a left parenthesis')
       goto 999
  274  continue
+      call msgout(io,lunit, 
+     $     'Instruction left hand side: waiting for a name')
       goto 999
  275  continue
+      call msgout(io,lunit, 'varargout keyword cannot be used here')
       goto 999
  276  continue
+      call msgout(io,lunit, 'Missing operator, comma, or semicolon')
       goto 999
-
  277  continue
+      call msgout(io,lunit, 'Too many commands defined')
       goto 999
  278  continue
       goto 999
@@ -1276,7 +1283,7 @@ c
 c     depile une macro pu un execstr
       include '../stack.h'
       integer lunit
-      logical trace,first
+      logical trace,first,callback
       integer sadr,ll
 
 c
@@ -1327,21 +1334,29 @@ c
             buf='in  execstr instruction'
             m=26
          endif
-         buf(m+1:m+14)=' called by :'
-         m=m+14
+         callback=rstk(pt-1).eq.706.or.rstk(pt-1).eq.606
+         if(callback) then
+            buf(1:26)='While executing a callback'
+            m=26
+         else
+            buf(m+1:m+14)=' called by :'
+            m=m+14
+         endif
          call basout(io,lunit,buf(1:m))
          lct(8)=lin(k+12+nsiz)
 c     
-         call whatln(lpt(1),lpt(2),lpt(6),nlc,l1,ifin)
-         m=ifin-l1+1
-         if(m.gt.ll) then
-            l1=max(l1,lpt(2)-ll/2)
-            m=min(ifin-l1,ll)
-         endif
+         if (.not.callback) then
+            call whatln(lpt(1),lpt(2),lpt(6),nlc,l1,ifin)
+            m=ifin-l1+1
+            if(m.gt.ll) then
+               l1=max(l1,lpt(2)-ll/2)
+               m=min(ifin-l1,ll)
+            endif
 
-         if(l1.gt.0.and.m.gt.0.and.m+l1-1.le.lsiz) then
-            call cvstr(m,lin(l1),buf(1:m),1)
-            call basout(io,lunit,buf(1:m))
+            if(l1.gt.0.and.m.gt.0.and.m+l1-1.le.lsiz) then
+               call cvstr(m,lin(l1),buf(1:m),1)
+               call basout(io,lunit,buf(1:m))
+            endif
          endif
       endif
 c
@@ -1445,7 +1460,6 @@ c
       write(line(m1+11:m1+15),'(i5)') n
       line(m1+16:m1+16)=bel
       call basout(io,lunit,line(1:m1+16))
-      if(hio.gt.0) call basout(io,hio,line(1:m1+15))
       return
       end
 
