@@ -7,8 +7,8 @@ c     Copyright INRIA
       parameter (nz1=nsiz-1,nz2=nsiz-2)
 c     
       integer op,r,blank,sign,plus,minus,name,colon,eye(nsiz),ou,et
-      integer equal,less,great,not,eol
-      logical eptover
+      integer equal,less,great,not,eol,p,gettype
+      logical eptover, istrue,skip, compil,ifexpr
       data colon/44/,blank/40/,plus/45/,minus/46/,ou/57/,et/58/
       data equal/50/,less/59/,great/60/,not/61/
       data eye/672014862,nz1*673720360/,name/1/,eol/99/
@@ -20,9 +20,10 @@ c
       endif
 c     
       r = rstk(pt)
+      if(r.eq.204) goto 85
       ir=r/100
       if(ir.ne.1) goto 01
-      goto(05,06,25,26,61,73,74,82,83,86,87,102,104,105),r-100
+      goto(05,06,25,26,61,73,74,82,83,86,87,102,104,105,22),r-100
 c     
  01   if(sym.ge.ou.and.sym.le.great) then
          call error(40)
@@ -68,9 +69,15 @@ c     blank or tab is delimiter inside angle brackets
       if (abs(lin(ls)).eq.blank.and.abs(lin(lpt(3))).ne.blank) go to 50
  21   op = sym
       call getsym
-      pt = pt+1
+      pt=pt+1
       pstk(pt) = op + 256*kount
-      rstk(pt) = 103
+      if(sym.ne.not) goto 23
+      rstk(pt)=115
+c     *call* lfact
+      goto 85
+ 22   goto 25
+c
+ 23   rstk(pt) = 103
       icall=2
 c     *call* term
       return
@@ -117,9 +124,26 @@ c     in-line lexpr
       endif
  72   continue
       if (eptover(1,psiz-1)) return
+      ids(1,pt)=0
+      ids(2,pt)=err1
       if(sym.eq.ou) then
 c     call getsym
          pstk(pt)=ou
+         if(ifexpr()) then
+c     .     checking for possible logical 'if expression' 
+c     .     evaluation shortcut
+            if(comp(1).ne.0) then
+               if (compil(30,1,0,0,0)) then 
+                  if (err.gt.0) return
+                  ids(1,pt)=comp(1)
+               endif
+            elseif (gettype(top).ne.8 .and. istrue(0)) then
+c     .        first term is true there is no use to evaluate the other
+               ids(1,pt)=1
+c     .        err1 <>0 sets interpretation without evaluation
+               err1=1
+            endif
+         endif
       else
          pstk(pt)=0
       endif
@@ -132,6 +156,11 @@ c     *call* lterm
       kount = pstk(pt)/256
       pt=pt-1
       if(op.eq.0) goto 75
+      if(comp(1).eq.0.and.ids(1,pt+1).eq.1) then
+c     . term has not been evaluated
+         err1=ids(2,pt+1)
+         goto 75
+      endif
       icall=4
       fin=ou
       rhs=2
@@ -142,6 +171,11 @@ c     *call* allops(ou)
       return
  74   continue
       kount=pstk(pt)
+      if(comp(1).ne.0) then
+         if (compil(30,0,ids(1,pt)-1,0,0)) then 
+            if (err.gt.0) return
+         endif
+      endif
       pt=pt-1
  75   if(sym.eq.ou) goto 72
       goto 50
@@ -155,8 +189,25 @@ c     in-line lterm
       endif
  81   continue
       if (eptover(1,psiz-1))  return
+      ids(1,pt)=0
+      ids(2,pt)=err1
       if(sym.eq.et) then
          pstk(pt)=et
+         if(ifexpr()) then
+c          . if expression evaluation, checking for possible
+c          . logical expression evaluation shortcut
+            if(comp(1).ne.0) then
+               if (compil(30,0,0,0,0)) then 
+                  if (err.gt.0) return
+                  ids(1,pt)=comp(1)
+               endif
+            elseif (gettype(top).ne.8 .and. .not.istrue(0)) then
+c     .        first term is false there is no use to evaluate the other
+               ids(1,pt)=1
+c     .        err1 <>0 sets interpretation without evaluation
+               err1=1
+            endif
+         endif
       else
          pstk(pt)=0
       endif
@@ -169,6 +220,12 @@ c     *call* lfact
       kount = pstk(pt)/256
       pt=pt-1
       if(op.eq.0) goto 84
+      if(comp(1).eq.0.and.ids(1,pt+1).eq.1) then
+c     . term has not been evaluated
+         err1=ids(2,pt+1)
+         goto 84
+      endif
+
       icall=4
       fin=et
       rhs=2
@@ -179,6 +236,11 @@ c     *call* allops(et)
       return
  83   continue
       kount=pstk(pt)
+      if(comp(1).ne.0) then
+         if (compil(30,0,ids(1,pt)-1,0,0)) then 
+            if (err.gt.0) return
+         endif
+      endif
       pt=pt-1
  84   if(sym.ne.et) goto 73
       goto 81
@@ -216,6 +278,9 @@ c     *call* allops(not)
       return
  87   kount=pstk(pt)
       pt=pt-1
+C     next two lines to handle a+~b and a*~b,...
+      if(rstk(pt).eq.115) goto 22
+      if(rstk(pt).eq.204) return
       goto 82
 c     
 c     in-line lprim
@@ -271,3 +336,17 @@ c 999  call error(22)
 c      if (err .gt. 0) return
 c      return
       end
+
+      logical function ifexpr()
+      INCLUDE '../stack.h'
+      integer p
+      if(err1.ne.0) goto 20
+      p=pt
+ 10   p=p-1
+      if (p.eq.0) goto 20
+      if (rstk(p).ne.803) goto 10
+      ifexpr=.true.
+      return
+ 20   ifexpr=.false.
+      return
+      end
