@@ -5,12 +5,14 @@ c     Copyright INRIA
       integer cblock,rblock,fcount
       parameter (rblock=30,cblock=rblock*50)
       integer quote,eol,equal,lparen,rparen,comma,semi,left,right,dot
+      integer blank
       integer psym,qcount,strcnt,pchar
       integer func(nsiz),endfunc(nsiz),iadr,sadr
       logical cresmat,eqid,last,eof
-      data quote/53/,eol/99/,name/1/
+      integer name,num
+      data quote/53/,eol/99/,name/1/,num/0/
       data equal/50/,lparen/41/,rparen/42/
-      data comma/52/,semi/43/,left/54/,right/55/,dot/51/
+      data comma/52/,semi/43/,left/54/,right/55/,dot/51/,blank/40/
 
 
       data func/202841615,387453469,nz2*673720360/
@@ -120,10 +122,10 @@ c     statements of the function
       if(sym.eq.eol) then
          if (lpt(4).ge.lpt(6)) then
             if(comp(1).ne.0) then 
-               call getlin(2)
+               call getlin(2,0)
                eof=.false.
             else
-               call getlin(2)
+               call getlin(2,0)
                eof=fin.eq.-2
             endif
          else
@@ -178,8 +180,13 @@ c     statements of the function
          n=lpt(4)-l4
          if (eof) then
 c     .     endfunction omitted
-            last=.true.
-            goto 72
+            if(macr.eq.0) then
+               last=.true.
+               goto 72
+            else
+               call error(272)
+               return
+            endif
          endif
          goto 72
       else
@@ -187,7 +194,8 @@ c     .     endfunction omitted
       endif
 
 c     store a line
- 72   if(last.and.n.le.0) goto 73
+ 72   continue
+      if(last.and.n.le.0) goto 73
       if(ilp+nr+1.ge.ilw) then
 c     .  allocate memory for rblock more rows
          ilw=ilw+rblock
@@ -216,7 +224,7 @@ c     . allocate memory for cblock more characters
       nr=nr+1
       if(.not.last) then
          if(lpt(4).ge.lpt(6)) then
-            call getlin(2)
+            call getlin(2,0)
             eof=fin.eq.-2
             l4=lpt(1)
          else
