@@ -39,6 +39,7 @@ c     ippty: interfaces properties
       integer byptr(mxbyptr),nbyptr
       common /ippty/ byptr,nbyptr
 
+      integer graphicsmodels
       logical first
       double precision dlamch
       integer i,k,l,nc,mode(2),vsizg
@@ -144,21 +145,8 @@ c     .  wte = unit number for terminal output
          wte=9999
       endif
       wio = 0
-c     .  hio =unit for history output
+c     .  hio =unit for history output (no more used)
       hio = 0
-      i   = 0
-      buf = ' '
-      call inffic(4,buf,nc)
-      nc=max(1,nc)
-      mode(1)=3
-      call clunit(i,buf(1:nc),mode)
-      if(err.gt.0) then
-         call error(err)
-         hio=0
-         err=0
-      else
-         hio=i
-      endif
 c     
 c     .  banner 
 c     .  ------
@@ -215,12 +203,13 @@ c     .  ------------------
 c     .  initial interface properties
 c     .  ----------------------------
       call setippty(0)
+      ier= graphicsmodels()
 c     
 c     .  Stack
 c     .  -----
 c     
 c     . initial values for number of local and global variables
-      isiz=isizt-256
+      isiz=isizt-768
 
 c     .  memory allocation
       stk(1)=1.0d0
