@@ -49,7 +49,7 @@ c     gestion des clause sur plusieurs lignes
             endif
 c     get the following line
             if(lpt(4).eq.lpt(6))  then
-               call getlin(1)
+               call getlin(1,0)
                if(err.gt.0) return
             else
                lpt(4)=lpt(4)+1
@@ -59,6 +59,10 @@ c     get the following line
             bcount=bcount+1
          else if (sym.eq.right) then
             bcount=bcount-1
+            if(bcount.lt.0) then
+               call error(46)
+               return
+            endif
          else if (sym.eq.quote) then
 c     .  check if transpose or beginning of a string
             pchar=lin(lpt(3)-2)
