@@ -22,10 +22,14 @@ c
  10   continue
       if(lc.le.ni)  then
          op=istk(lc)
-
          icount=icount+1
 c     
-         if(op.eq.1) then
+         if(op.eq.0) then
+c     nop
+            icount=icount-1
+            lc=lc+istk(lc+1)
+            goto 10
+         elseif(op.eq.1) then
 c     stackp
             lc=lc+1+nsiz
             goto 10
@@ -74,8 +78,8 @@ c     select
             nc=istk(lc+1)
             lc=lc+nc
             goto 10
-         elseif(op.ge.12.and.op.le.15) then
-c     pause,break,abort,eol
+         elseif((op.ge.12.and.op.le.15).or.op.eq.28) then
+c     pause,break,abort,eol,continue
             lc=lc+1
             goto 10
          elseif(op.eq.16) then 
@@ -91,6 +95,11 @@ c     mark named argument
 c     form recursive extraction list
             lc=lc+3
             goto 10
+         elseif(op.eq.20) then 
+c     exit
+            lc=lc+1
+            goto 10
+
          elseif(op.eq.21) then 
 c     begrhs (ignored)
             lc=lc+1
@@ -123,6 +132,16 @@ c     vector of strings
 c     varfun
             lc=lc+3+nsiz
             goto 10
+         elseif(op.eq.29) then
+c     affectation
+            n=istk(lc+1)
+            lc=lc+3+n*(nsiz+1)
+            goto 10
+        elseif(op.eq.30) then
+c     skip logical ops (not reported by tradsl)
+            lc=lc+3
+            icount=icount-1
+            goto 10
          elseif(op.ge.100) then
 c     matfns
             lc=lc+4
