@@ -60,7 +60,7 @@ c     acquisition d'une ligne du fichier
 
  11   buf=' '
       if(ltype.eq.1) then
-         call basin(ierr,lunit,buf(1:lrecl),'*')
+         call basin(ierr,lunit,buf(1:lrecl),'*',0)
          if(ierr.eq.1) goto 60
          if(ierr.eq.2) goto 90
          n=lnblnk(buf(1:lrecl))
@@ -195,8 +195,12 @@ c     fin de conversion de la ligne
       if(istk(l).eq.blank) goto 28
       l=l+1
       if(l-1.le.l0) then
-         istk(l)=comma
-         l=l+1
+         if (istk(l-1).ne.comma.and.
+     +        istk(l-1).ne.semi.and.
+     +        istk(l-1).ne.left) then
+            istk(l)=comma
+            l=l+1
+         endif
       endif
       do 29 i=0,icount
 c     la gestion de icount a ete ajoute pour maintenir un compteur de ligne
