@@ -12,7 +12,7 @@
 #include "tksci.h"
 #include "TK_uicontrol.h"
 
-
+extern int cf_type;
 
 void LAB_figure()
 
@@ -34,7 +34,7 @@ void LAB_figure()
   int FirstField=0;
   
   NbParam = Interf.NbParamIn;
-  
+  cf_type=0;/* current figure is a tksci one */
   if ( (NbParam >0) && MatrixIsNumeric(Interf.Param[0]) )
     /* the first parameter is a figure handle */
     {
@@ -42,14 +42,14 @@ void LAB_figure()
       FirstField = 1;
       sprintf(MyCommand, "set MyTmpBertrand [FigureSelect %d];", FigureHandle);
       Tcl_Eval(TKinterp,MyCommand);
-      StrHandle = Tcl_GetVar(TKinterp, "MyTmpBertrand", 0);
+      StrHandle = (char*)Tcl_GetVar(TKinterp, "MyTmpBertrand", 0);
       Handle = (int)atoi(StrHandle);
 
     } else {
       /* creation of a figure */
       sprintf(MyCommand, "set MyTmpBertrand [CreateFigure 0];"); 
       Tcl_Eval(TKinterp,MyCommand);
-      StrHandle = Tcl_GetVar(TKinterp, "MyTmpBertrand", 0);
+      StrHandle = (char*) Tcl_GetVar(TKinterp, "MyTmpBertrand", 0);
       Handle = (int)atoi(StrHandle);
     }
 
