@@ -14,7 +14,7 @@
 
 
 
-void LAB_gcf()
+int LAB_gcf()
 
 
 {
@@ -22,10 +22,10 @@ void LAB_gcf()
  
   char MyCommand[2000];
   char *StrHandle;
-  int Handle;
 
-  Matrix *MOutputHandle;
-  double *OutputHandle;
+
+
+
 
 
 
@@ -34,17 +34,8 @@ void LAB_gcf()
 
 
   Tcl_Eval(TKinterp,MyCommand);
-  StrHandle = Tcl_GetVar(TKinterp, "MyTmpBertrand", 0);
-  Handle = (int)atoi(StrHandle);
-
-  MOutputHandle = MatrixCreate(1,1,"real");
-  OutputHandle = (double *)MatrixGetPr(MOutputHandle);
-  *OutputHandle = Handle;
-
-  ReturnParam(MOutputHandle);
-
-
-
+  StrHandle = (char *) Tcl_GetVar(TKinterp, "MyTmpBertrand", 0);
+  return (int)atoi(StrHandle);
 }
 
 
