@@ -6,23 +6,18 @@
 #include "tksci.h"
 
 
-void LAB_set()
-
-
+void LAB_set(void)
 {
-
-
   Matrix *MHandle;
   int Handle;
-
   Matrix *Mfield;
-  char *field;
-
   Matrix *Mvalue;
-  char *value;
 
- 
-  
+  if (Interf.NbParamIn < 3)
+    {
+      InterfError("Wrong number of input arguments");
+      return;
+    }
   MHandle = (Matrix *)Interf.Param[0];
   if (!MatrixIsReal(MHandle) )
     {
