@@ -2,7 +2,11 @@
 /* scilab-tk link main module */
 /* Bertrand Guiheneuf INRIA 1997 */
 
+#if WIN32
+#include <windows.h>
+#endif
 
+#include <stdio.h>
 #include "tksci.h"
 #include "TK_ScilabCallback.h"
 #include <stdio.h>
@@ -23,11 +27,11 @@
 
 Tcl_Interp *TKinterp=NULL;
 Tk_Window TKmainWindow=NULL;
-int XTKsocket;
+int XTKsocket=0;
 
 Matrix *UserData[MAX_HANDLE];
 
-
+extern void Cout(char *str);
 
 int TK_Wait=0;
 int TK_NbEv=10;
@@ -36,7 +40,9 @@ int TK_Started=0;
 
 void flushTKEvents()
 {
-  while (Tcl_DoOneEvent(TCL_ALL_EVENTS | TCL_DONT_WAIT)==1) {}
+  while (Tcl_DoOneEvent(TCL_ALL_EVENTS | TCL_DONT_WAIT)==1)
+  {
+  }
 }
 
 
@@ -65,7 +71,7 @@ int OpenTksci()
 #ifdef TCL_MINOR_VERSION
 #if TCL_MAJOR_VERSION >= 8
 #if TCL_MINOR_VERSION > 0
-  Tcl_FindExecutable(NULL);
+  Tcl_FindExecutable(" ");
 #endif
 #endif
 #endif
