@@ -6,7 +6,7 @@
 
 /* INTERFACE ROUTINE */
 typedef void (*voidf)();
-
+extern void Cout(char *str);
 extern void LAB_uicontrol();
 extern void LAB_TK_DoOneEvent();
 extern void LAB_TK_EvalStr();
@@ -20,9 +20,10 @@ extern void LAB_get();
 extern void LAB_figure();
 extern void LAB_close();
 extern void LAB_uimenu();
-extern void LAB_gcf();
+/*extern void LAB_gcf();*/
 extern void LAB_setgvar();
 extern void LAB_getgvar();
+extern void sci_tk_activate(void);
 
 voidf FuncI[] ={
   LAB_uicontrol,
@@ -38,18 +39,30 @@ voidf FuncI[] ={
   LAB_figure,
   LAB_close,
   LAB_uimenu,
-  LAB_gcf,
+  LAB_get,
   LAB_setgvar,
   LAB_getgvar
 };
      
 void C2F(tksciInterf)()
 {
+  static int first =0;
   InterfInit();
-  if (TK_Started==1)
-    (*FuncI[Interf.FuncIndex -1])();
-  else 
-    Cout("Sorry, TK has not been enabled this the session.\n");
+  if (TK_Started != 1 )
+    {
+      if ( first == 0) 
+	{
+	  sci_tk_activate();first++;
+	  if ( TK_Started != 1 ) 
+	    {
+	      Cout("You have started Scilab in a mode in which TK not initialized.\n");
+	      Cout("I've tried initialization but it failed\n");
+	      return ;
+	    }
+	}
+    }
 
+  (*FuncI[Interf.FuncIndex -1])();
   InterfDone();
+
 }
