@@ -1,108 +1,9 @@
-/* Copyright (C) 1998-2002 Chancelier Jean-Philippe */
-/* Scilab wgmenu.c 
-
- *  Menus for graphic window ( from wmenu.c ) 
- *  Jean-Philippe Chancelier 
- */
-
-#include <stdio.h>
-#ifndef STRICT
-#define STRICT
-#endif
-/*#include <windows.h>
-  #include <windowsx.h>*/
-#include <string.h>		/* only use  items */
-
-#ifdef __CYGWIN32__
-#include <unistd.h>		/* for getpid */
-#endif
-#if (defined __MSC__) || (defined __MINGW32__)
-#include <process.h>		/* for getpid */
-#endif
-
-#ifdef __ABSC__
-#define getpid() getpid_()
-#endif
-
-#ifdef __STDC__
-#include <stdlib.h>
-#else
-int system ();
-#endif
-
-/*#include "wgnuplib.h"*/
-#include "wresource.h"
-#include "wcommon.h"
-#include <commdlg.h>
-#include "../graphics/Graphics.h"
-#include "../sun/men_Sutils.h"
-extern TW textwin;
-
-/* limits */
-#define MAXSTR 255
-#define MACROLEN 5000
-/* #define NUMMENU 256  defined in wresourc.h */
-#define MENUDEPTH 3
-/* menu tokens */
-
-#define CMDMIN 129
-#define ZOOM 129
-#define UNZOOM 130
-/** Warning must be like OPEN and SAVE in the wmenu.c file */
-#define LOADSCG 131
-#define SAVESCG 132
-#define COPYCLIP 133
-#define COPYCLIP1 134
-#define REDRAW 135
-#define ROT3D 136
-#define PRINT 137
-#define CLEARWG 138
-#define EOS     139
-#define SCIPS   140
-#define SCIPR   141
-#define SCIGSEL 142
-#define UPDINI  143
-#define CLOSE   144
-#define CMDMAX 144
-
-static char *keyword[] =
-{
-  "[ZOOM]", "[UNZOOM]", "[ROT3D]", "[PRINT]", "[COPYCLIP]", "[COPYCLIP1]",
-  "[REDRAW]", "[LOADSCG]", "[SAVESCG]", "[CLEARWG]", "[SCIPS]", "[SCIPR]",
-  "[SCIGSEL]", "[UPDINI]", "[EOS]", "[CLOSE]",
-  "{ENTER}", "{ESC}", "{TAB}",
-  "{^A}", "{^B}", "{^C}", "{^D}", "{^E}", "{^F}", "{^G}", "{^H}",
-  "{^I}", "{^J}", "{^K}", "{^L}", "{^M}", "{^N}", "{^O}", "{^P}",
-  "{^Q}", "{^R}", "{^S}", "{^T}", "{^U}", "{^V}", "{^W}", "{^X}",
-  "{^Y}", "{^Z}", "{^[}", "{^\\}", "{^]}", "{^^}", "{^_}",
-  NULL};
-
-static BYTE keyeq[] =
-{
-  ZOOM, UNZOOM, ROT3D, PRINT, COPYCLIP, COPYCLIP1,
-  REDRAW, LOADSCG, SAVESCG, CLEARWG, SCIPS, SCIPR, SCIGSEL, UPDINI, EOS,
-  CLOSE,
-  13, 27, 9,
-  1, 2, 3, 4, 5, 6, 7, 8,
-  9, 10, 11, 12, 13, 14, 15, 16,
-  17, 18, 19, 20, 21, 22, 23, 24,
-  25, 26, 28, 29, 30, 31,
-  0 /* NULL */ };
-
-static void dos2win32 (char *filename, char *filename1);
-static void ExploreMenu (HMENU hmen, BYTE ** macro);
-static void SciDelMenu (LPMW lpmw, char *name);
-static void SciChMenu (LPMW lpmw, char *name, char *new_name);
-static void SciSetMenu (HMENU hmen, char *name, int num, int flag);
-static void SciChMenu (LPMW lpmw, char *name, char *new_name);
-static void SciDelMenu (LPMW lpmw, char *name);
-static void SavePs (struct BCG *ScilabGC);
-static void PrintPs (struct BCG *ScilabGC);
+#include "wgmenu.h"
 
+/*-----------------------------------------------------------------------------------*/
 /*********************************
  * Send a macro to the text window 
  *********************************/
-
 void SendGraphMacro (struct BCG *ScilabGC, UINT m)
 {
   BYTE *s;
@@ -122,19 +23,36 @@ void SendGraphMacro (struct BCG *ScilabGC, UINT m)
       if (*s >= CMDMIN && *s <= CMDMAX)
 	{
 	  int ierr = 0;
+	  
 /** Special cases **/
 	  switch (*s)
 	    {
+		  case TOOLBARGRAPH:
+			  if (ScilabGC->lpmw.LockToolBar == FALSE)
+				  {
+					if (ScilabGC->lpmw.ShowToolBar)	HideGraphToolBar(ScilabGC);
+					else ShowGraphToolBar(ScilabGC);
+				  }
+			  s++;
+	      break;
+		case NEWFIG:
+			SaveCurrentLine(TRUE);
+			NewFigure(ScilabGC);
+			s++;
+	      break;
 	    case ZOOM:
 	      scig_2dzoom (ScilabGC->CurWindow);
+		  
 	      s++;
 	      break;
 	    case UNZOOM:
 	      scig_unzoom (ScilabGC->CurWindow);
+		  
 	      s++;
 	      break;
 	    case ROT3D:
 	      scig_3drot (ScilabGC->CurWindow);
+		  
 	      s++;
 	      break;
 	    case PRINT:
@@ -170,7 +88,7 @@ void SendGraphMacro (struct BCG *ScilabGC, UINT m)
 	      s++;
 	      break;
 	    case LOADSCG:
-	      flag = SciOpenSave (ScilabGC->hWndParent, &s, &d, &ierr);
+	      flag = SciOpenSave (ScilabGC->hWndParent, &s,FALSE,&d, &ierr);
 	      if (flag == 0 || ierr == 1)
 		{
 		  LocalFree (buf);
@@ -180,7 +98,7 @@ void SendGraphMacro (struct BCG *ScilabGC, UINT m)
 	      scig_loadsg (ScilabGC->CurWindow, buf);
 	      break;
 	    case SAVESCG:
-	      flag = SciOpenSave (ScilabGC->hWndParent, &s, &d, &ierr);
+	      flag = SciOpenSave (ScilabGC->hWndParent, &s,TRUE,&d, &ierr);
 	      if (flag == 0 || ierr == 1)
 		{
 		  LocalFree (buf);
@@ -219,8 +137,9 @@ void SendGraphMacro (struct BCG *ScilabGC, UINT m)
     added menu **/
   ScilabMenuAction (buf);
   LocalFree (buf);
-}
 
+}
+/*-----------------------------------------------------------------------------------*/
 /******************************
  * The following function 
  * for standard buf : stores expression in a Queue via the StoreCommand 
@@ -237,7 +156,8 @@ void ScilabMenuAction (char *buf)
       if (buf[1] == '0')
 	{
 	  /* Interpreted mode : we store the action on a queue */
-	  StoreCommand1 (buf + 2, 2);
+	  StoreCommand1 (buf + 2, 0);
+	
 	}
       else
 	{
@@ -274,26 +194,18 @@ void ScilabMenuAction (char *buf)
 	StoreCommand1 (buf, 1);
     }
 }
-
+/*-----------------------------------------------------------------------------------*/
 /************************************
  * Send a string to scilab interaction window
  * as if it was typed by the user 
  ************************************/
-
 void write_scilab (char *buf)
 {
-  char *d;
-  if (buf[0] != '\0')
-    {
-      d = buf;
-      while (*d)
-	{
-	  SendMessage (textwin.hWndText, WM_CHAR, *d, 1L);
-	  d++;
-	}
-    }
+  if ( IsWindowInterface() ) Write_Scilab_Window(buf);
+  else Write_Scilab_Console(buf);
+  
 }
-
+/*-----------------------------------------------------------------------------------*/
 /************************************
  * Translate string to tokenized macro 
  ************************************/
@@ -313,16 +225,10 @@ static void TranslateMacro (char *string)
 	}
     }
 }
-
+/*-----------------------------------------------------------------------------------*/
 /**************************************************
  * Load Macros, and create Menu from Menu file
  **************************************************/
-
-#define BUGGOTOCLEAN(str) \
-      wsprintf(buf,str,nLine,ScilabGC->lpgw->szMenuName); \
-      MessageBox(ScilabGC->hWndParent,(LPSTR) buf,ScilabGC->lpgw->Title,MB_ICONEXCLAMATION);\
-      goto errorcleanup;
-
 void LoadGraphMacros (struct BCG *ScilabGC)
 {
   GFILE *menufile;
@@ -475,12 +381,11 @@ cleanup:
     Gfclose (menufile);
   return;
 }
-
+/*-----------------------------------------------------------------------------------*/
 /************************************
  * Find a free position for storing 
  * a new menu data
  ************************************/
-
 int WGFindMenuPos (BYTE ** macros)
 {
   int i;
@@ -491,12 +396,11 @@ int WGFindMenuPos (BYTE ** macros)
     }
   return (NUMMENU);
 }
-
+/*-----------------------------------------------------------------------------------*/
 /************************************
  * Cleaning everything : used 
  * A Rajouter quand on d'etruit une fenetre graphique XXXXX 
  ************************************/
-
 void CloseGraphMacros (struct BCG *ScilabGC)
 {
   int i;
@@ -518,7 +422,7 @@ void CloseGraphMacros (struct BCG *ScilabGC)
 	}
     }
 }
-
+/*-----------------------------------------------------------------------------------*/
 /***********************************
  * functions to change the menu state 
  ***********************************/
@@ -545,8 +449,8 @@ static void ExploreMenu (HMENU hmen, BYTE ** hmacro)
 	}
     }
 }
+/*-----------------------------------------------------------------------------------*/
 
-extern struct BCG *GetWindowXgcNumber (integer i);
 
 /***********************************
  * activate or deactivate a menu (scilab interface)
@@ -573,7 +477,7 @@ int C2F (setmen) (integer * win_num, char *button_name,
     }
   return (0);
 }
-
+/*-----------------------------------------------------------------------------------*/
 int C2F (unsmen) (integer * win_num, char *button_name, integer * entries,
 		  integer * ptrentries, integer * ne, integer * ierr)
 {
@@ -594,7 +498,7 @@ int C2F (unsmen) (integer * win_num, char *button_name, integer * entries,
     }
   return (0);
 }
-
+/*-----------------------------------------------------------------------------------*/
 static void SciSetMenu (HMENU hmen, char *name, int num, int flag)
 {
   int i, is, Nums = GetMenuItemCount (hmen);
@@ -622,7 +526,7 @@ static void SciSetMenu (HMENU hmen, char *name, int num, int flag)
 	}
     }
 }
-
+/*-----------------------------------------------------------------------------------*/
 /***********************************
  * change a name in a top level menu 
  * used for keeping track of the graphic window 
@@ -648,7 +552,7 @@ int C2F (chmenu) (integer * win_num, char *old_name, char *new_name)
     }
   return (0);
 }
-
+/*-----------------------------------------------------------------------------------*/
 static void SciChMenu (LPMW lpmw, char *name, char *new_name)
 {
   int i, is, id, Nums = GetMenuItemCount (lpmw->hMenu);
@@ -664,7 +568,7 @@ static void SciChMenu (LPMW lpmw, char *name, char *new_name)
 	}
     }
 }
-
+/*-----------------------------------------------------------------------------------*/
 /***********************************
  * delete a menu (scilab interface)
  ***********************************/
@@ -688,7 +592,7 @@ int C2F (delbtn) (integer * win_num, char *button_name)
     }
   return (0);
 }
-
+/*-----------------------------------------------------------------------------------*/
 static void SciDelMenu (LPMW lpmw, char *name)
 {
   int i, is, id, Nums = GetMenuItemCount (lpmw->hMenu);
@@ -749,7 +653,7 @@ static void SciDelMenu (LPMW lpmw, char *name)
 	}
     }
 }
-
+/*-----------------------------------------------------------------------------------*/
 /*********************************************************
    Add a menu in  window  number wun_num or in Main window
    win_num     : graphic window number or -1 for main scilab window
@@ -850,7 +754,7 @@ void AddMenu (integer * win_num, char *button_name, char **entries,
 		if (*typ==0) 
 		  sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ, fname, i + 1);
 		else if (*typ==2) 
-		  sprintf ((char *) macroptr, "@0%s(%d,%d)",fname, i + 1,*win_num);
+		  sprintf ((char *) macroptr, "@0%s(%d)",fname, i + 1);
 		else
 		  sprintf ((char *) macroptr, "@%dexecstr(%s(%d))", *typ,fname, i + 1);
 	      else
@@ -871,7 +775,7 @@ void AddMenu (integer * win_num, char *button_name, char **entries,
     }
   DrawMenuBar (hwnd);
 }
-
+/*-----------------------------------------------------------------------------------*/
 /* Scilab interface for the AddMenu function 
    Add a menu in  window  number win_num or in Main window
 
@@ -891,6 +795,7 @@ int C2F (addmen) (integer * win_num, char *button_name, integer * entries,
 		  integer * ierr)
 {
   char **menu_entries;
+  menu_entries=NULL;
   *ierr = 0;
   if (*ne != 0)
     {
@@ -898,41 +803,16 @@ int C2F (addmen) (integer * win_num, char *button_name, integer * entries,
       if (*ierr == 1)
 	return (0);
     }
-  AddMenu (win_num, button_name, menu_entries, ne, typ, fname, ierr);
+  /* Modification Allan CORNET */
+  /* Rinitialisation Menu Console Principale */
+  if ( (strcmp(button_name,"RESETMENU")==0) && (*win_num==-1) )
+  {
+	ResetMenu();	
+  }
+  else AddMenu (win_num, button_name, menu_entries, ne, typ, fname, ierr);
   return (0);
 }
-
-/********************************************
- *  save to Postscript or Send to A printer 
- *  for Xwindow the associated code is in jpc_SGraph + menusX 
- ****************************************/
-
-/*****************************
-  menu for exporting to ps or xfig 
-  ***************************/
-
-typedef struct tagLS
-{
-  int colored;
-  int land;
-  int use_printer;
-  int ps_type;
-}
-LS;
-
-static LS ls =
-{1, 0, 0, 0};
-
-static char *Print_Formats[] =
-{
-  "Postscript",
-  "Postscript No Preamble",
-  "Postscript-Latex",
-  "Xfig",
-  "GIF",
-  "PPM",
-};
-
+/*-----------------------------------------------------------------------------------*/
 /****************************************************
  * Event handler function for the line style window 
  * uses GetWindowLong(hwnd, 4) and SetWindowLong
@@ -959,7 +839,7 @@ EXPORT BOOL CALLBACK
 			  ls.land, 0L);
       if (ls.use_printer == 0)
 	{
-	  for (i = 0; i < 5; i++)
+	  for (i = 0; i < 8; i++)
 	    SendDlgItemMessage (hdlg, PS_TYPE, CB_ADDSTRING, 0,
 				(LPARAM) ((LPSTR) Print_Formats[i]));
 	  SendDlgItemMessage (hdlg, PS_TYPE, CB_SETCURSEL,
@@ -993,7 +873,7 @@ EXPORT BOOL CALLBACK
     }
   return FALSE;
 }
-
+/*-----------------------------------------------------------------------------------*/
 /****************************************************
  * Export style dialog box 
  ****************************************************/
@@ -1013,9 +893,7 @@ BOOL ExportStyle (struct BCG * ScilabGC)
     }
   return status;
 }
-
-static char filename[MAXSTR], filename1[MAXSTR];
-
+/*-----------------------------------------------------------------------------------*/
 static void SavePs (struct BCG *ScilabGC)
 {
   char *d, ori;
@@ -1030,7 +908,7 @@ static void SavePs (struct BCG *ScilabGC)
   d = filename;
   TranslateMacro (str);
   s = str;
-  flag = SciOpenSave (ScilabGC->hWndParent, &s, &d, &ierr);
+  flag = SciOpenSave (ScilabGC->hWndParent, &s,TRUE,&d, &ierr);
   if (flag == 0 || ierr == 1)
     {
       return;
@@ -1085,9 +963,21 @@ static void SavePs (struct BCG *ScilabGC)
       wininfo ("end of PPM file generation");
       SetCursor (LoadCursor (NULL, IDC_CROSS));
       break;
+	case 6:
+	  SetCursor (LoadCursor (NULL, IDC_WAIT));
+      ExportBMP(ScilabGC,filename);
+      wininfo ("end of BMP file generation");
+      SetCursor (LoadCursor (NULL, IDC_CROSS));
+	  break;
+	case 7:
+      SetCursor (LoadCursor (NULL, IDC_WAIT));
+      ExportEMF(ScilabGC,filename);
+      wininfo ("end of EMF file generation");
+      SetCursor (LoadCursor (NULL, IDC_CROSS));
+	  break;
     }
 }
-
+/*-----------------------------------------------------------------------------------*/
 static void dos2win32 (char *filename, char *filename1)
 {
 #ifdef CVT_PATH_BEG
@@ -1107,7 +997,7 @@ static void dos2win32 (char *filename, char *filename1)
     }
   *filename1 = '\0';
 }
-
+/*-----------------------------------------------------------------------------------*/
 static void PrintPs (struct BCG *ScilabGC)
 {
   char *p1;
@@ -1135,7 +1025,7 @@ static void PrintPs (struct BCG *ScilabGC)
     }
 /** filename is destroyed when we quit scilab **/
 }
-
+/*-----------------------------------------------------------------------------------*/
 /* used by command_handler in metanet */
 
 static void scig_command_scilabgc (int number, void f (struct BCG *))
@@ -1144,27 +1034,142 @@ static void scig_command_scilabgc (int number, void f (struct BCG *))
   if (ScilabGC != NULL && ScilabGC->CWindow && IsWindow (ScilabGC->CWindow))
     f (ScilabGC);
 }
-
+/*-----------------------------------------------------------------------------------*/
 void scig_h_winmeth_print (integer number)
 {
   scig_command_scilabgc (number, CopyPrint);
 }
-
+/*-----------------------------------------------------------------------------------*/
 void scig_h_copyclip (integer number)
 {
   scig_command_scilabgc (number, NewCopyClip);
 }
-
+/*-----------------------------------------------------------------------------------*/
 void scig_h_copyclip1 (integer number)
 {
   scig_command_scilabgc (number, CopyClip);
 }
-
+/*-----------------------------------------------------------------------------------*/
 void scig_print (integer number)
 {
   scig_command_scilabgc (number, PrintPs);
 }
+/*-----------------------------------------------------------------------------------*/
 void scig_export (integer number)
 {
   scig_command_scilabgc (number, SavePs);
 }
+/*-----------------------------------------------------------------------------------*/
+void UpdateFileGraphNameMenu(struct BCG *ScilabGC)
+{
+	#define FILEGRAPHMENUFRENCH "wgscilabF.mnu"
+	#define FILEGRAPHMENUENGLISH "wgscilabE.mnu"
+	
+	char szModuleName[MAX_PATH];
+	LPSTR tail;
+	
+	HINSTANCE hInstance=NULL;
+	extern char ScilexWindowName[MAX_PATH];
+	LPTW lptw;
+	HWND hWndTmpScilex=FindWindow(NULL,ScilexWindowName);
+	int LangCode=0; /*English*/
+
+	if (IsWindowInterface())
+	{
+	if (hWndTmpScilex)
+		{
+			lptw = (LPTW) GetWindowLong (FindWindow(NULL,ScilexWindowName), 0);
+			LangCode=lptw->lpmw->CodeLanguage;
+		}
+		else LangCode=0;
+	}
+	else LangCode=0;
+	ScilabGC->lpmw.CodeLanguage=LangCode;
+
+	hInstance=(HINSTANCE) GetModuleHandle(NULL);   		
+	
+	
+	GetModuleFileName (hInstance,szModuleName, MAX_PATH);
+	
+	if ((tail = strrchr (szModuleName, '\\')) != (LPSTR) NULL)
+	{
+		tail++;
+		*tail = '\0';
+	}
+	
+	if (ScilabGC->lpgw->szMenuName!=NULL) free(ScilabGC->lpgw->szMenuName);
+	ScilabGC->lpgw->szMenuName = (LPSTR) malloc (strlen (szModuleName) + strlen (FILEGRAPHMENUENGLISH) + 1);
+	strcpy (ScilabGC->lpgw->szMenuName, szModuleName);
+
+	
+	switch (LangCode)
+	{
+		case 1:
+			strcat (ScilabGC->lpgw->szMenuName, FILEGRAPHMENUFRENCH);
+		break;
+		default : case 0:
+			strcat (ScilabGC->lpgw->szMenuName, FILEGRAPHMENUENGLISH);
+		break;
+	}
+	
+}
+/*-----------------------------------------------------------------------------------*/
+void NewFigure(struct BCG * ScilabGC)
+{
+	
+	char Command[MAX_PATH];
+	int FreeWindow=0;
+
+	FreeWindow=FindFreeGraphicWindow(ScilabGC);
+	wsprintf(Command,"xset(\"window\",%d);",FreeWindow);
+	StoreCommand1(Command,0);
+	
+}
+	
+/*-----------------------------------------------------------------------------------*/
+/* Retourne un numro valide de fenetre graphique libre */
+int FindFreeGraphicWindow(struct BCG * ScilabGC)
+{
+	int FreeNumber=-1;
+	integer iflag =0,ids,num,un=1;
+
+	if (ScilabGC->graphicsversion == 0)
+	{
+		HWND hWndGraph=NULL;
+		int Num=0;
+		char NameWindow[MAX_PATH];
+
+		wsprintf(NameWindow,"%s%d","ScilabGraphic",Num);
+		while ( FindWindow(NULL,NameWindow) )
+		{
+			Num++;
+			wsprintf(NameWindow,"%s%d","ScilabGraphic",Num);
+		}
+		FreeNumber=Num;
+	}
+	else
+	{
+		integer *tab=NULL;
+		int sizetab=0;
+		int i=0;
+
+		iflag = 0; 
+		C2F(getwins)(&num,&ids ,&iflag);
+		sizetab=num;
+
+		tab=(integer*)malloc(sizeof(integer)*sizetab);
+		for(i=0;i<sizetab;i++) tab[i]=0;
+
+		iflag = 1; 
+		C2F(getwins)(&num,tab,&iflag);
+
+		for(i=0;i<sizetab;i++)
+		{
+			if(FreeNumber<tab[i]) FreeNumber=tab[i];	
+		}
+		FreeNumber=FreeNumber+1;
+		free(tab);
+    } 
+	return FreeNumber;
+}
+/*-----------------------------------------------------------------------------------*/
\ No newline at end of file
