@@ -8,7 +8,7 @@
  *	Digital Equipment Corporation
  *	treese@crl.dec.com
  *
- *	$Source: /usr/local/cvsroot/scilab2.7/routines/xsci/wf_w_dir.c,v $
+ *	$Source: /usr/local/cvsroot/scilab/routines/xsci/wf_w_dir.c,v $
  *
  *	COPYRIGHT 1990  DIGITAL EQUIPMENT CORPORATION, MAlYNARD, MASSACHUSETTS
  *	  ALL RIGHTS RESERVED.
