@@ -75,8 +75,10 @@
 #include "All-extern.h"
 
 #define CTRL_B                0x0002  /* back a character */
+#define CTRL_C                0x0003  /* redo line */
 #define CTRL_D                0x0004  /* delete next char */
 #define CTRL_K                0x000b  /* delete to end of line */
+#define CTRL_Z                0x0020  /* stop */
 
 
 /** JPC **/
@@ -89,9 +91,11 @@ typedef int XtGravity;
 static Char buffer[BUF_SIZE];
 static Char *bptr = buffer;
 static int bcnt = 0;
-
+extern int getdiary();
+void C2F(diary) __PARAMS((char *str,int *n));
+void diary_nnl __PARAMS((char *str,int *n));
 typedef  int (*osc_func) ();
-
+extern int C2F(ismenu)();
 /*
  * Check for both EAGAIN and EWOULDBLOCK, because some supposedly POSIX
  * systems are broken and return EWOULDBLOCK when they should return EAGAIN.
@@ -225,7 +229,6 @@ static void HandleBell  __PARAMS((Widget w, XEvent *event, String *params, Cardi
 static void HandleVisualBell  __PARAMS((Widget w, XEvent *event, String *params, Cardinal *param_count));  
 static void HandleIgnore  __PARAMS((Widget w, XEvent *event, String *params, Cardinal *param_count));  
 static void DoSetSelectedFont  __PARAMS((Widget w, XtPointer client_data, Atom *selection, Atom *type, XtPointer value, long unsigned int *length, int *format));  
-extern void C2F(diary) __PARAMS((char *str, int *n, int nn));
 
 
 /*
@@ -504,11 +507,9 @@ WidgetClass xtermWidgetClass = (WidgetClass) & xtermClassRec;
 
 /* I/O Function for scilab : this function are used when Xscilab is on */
 
-int in_put();
-
-int XEvorgetchar()
+int XEvorgetchar(int interrupt)
 {
-  return (in_put());
+  return (in_put(interrupt));
 }
 
 void Xputstring(str,n)
@@ -519,9 +520,7 @@ void Xputstring(str,n)
   for ( i =0 ; i < n; i++) Xputchar(str[i]);
 }
 
-void C2F(xscisncr)(str,n,dummy)
-     char *str;
-     integer *n,dummy;
+void C2F(xscisncr)(char *str,integer *n,integer dummy)
 {
   int i;
   for ( i =0 ; i < *n; i++) {
@@ -531,9 +530,7 @@ void C2F(xscisncr)(str,n,dummy)
 
 /** print str on Scilab window \n are changed to \r\n **/
 
-void C2F(xscisrn)(str,n,dummy)
-     char *str;
-     integer *n,dummy;
+void C2F(xscisrn)(char *str,integer *n,integer dummy)
 {
   int i;
   for ( i =0 ; i < *n; i++) {
@@ -545,10 +542,7 @@ void C2F(xscisrn)(str,n,dummy)
   }
 }
 
-void C2F(xscistring)(str,n,dummy)
-     char *str;
-     int *n;
-     long int dummy;
+void C2F(xscistring)(char *str,integer *n,long int dummy)
 {
   int i ;
   for ( i =0 ; i < *n; i++) {
@@ -566,7 +560,7 @@ void C2F(xscimore)(n)
   *n=0;
   ln=strlen(MORESTR);
   Xputstring(MORESTR,ln);
-  n1=XEvorgetchar();
+  n1=XEvorgetchar(1);
   if ( n1 == 110 )  *n=1;
   Xputstring("\r\n",2);
 }
@@ -633,8 +627,6 @@ void sciprint(va_alist) va_dcl
   va_start(ap);
   fmt = va_arg(ap, char *);
 #endif
-
-  /* next three lines added for diary SS*/
   (void ) vsprintf(s_buf, fmt, ap );
   lstr=strlen(s_buf);
 
@@ -645,17 +637,10 @@ void sciprint(va_alist) va_dcl
     }
   else 
     {
-      C2F(xscisncr)(s_buf,&lstr,0L);
+      C2F(xscisrn)(s_buf,&lstr,0L);
+      /* C2F(xscisncr)(s_buf,&lstr,0L); */
     }
-  /* \r\n -> \n for diary */ 
-  if ( lstr >= 2 && s_buf[lstr-1]== '\n' && s_buf[lstr-2]== '\r') 
-    {
-      s_buf[lstr-2]= '\n';
-      s_buf[lstr-1]= '\0';
-      lstr--;
-    }
-  C2F(diary)(s_buf,&lstr,0L);
-
+  if (getdiary()) diary_nnl(s_buf,&lstr);
   va_end(ap);
 }
 
@@ -691,7 +676,8 @@ void sciprint_nd(va_alist) va_dcl
     }
   else 
     {
-      C2F(xscisncr)(s_buf,&lstr,0L);
+      C2F(xscisrn)(s_buf,&lstr,0L);
+      /* C2F(xscisncr)(s_buf,&lstr,0L); */
     }
   va_end(ap);
 }
@@ -721,9 +707,6 @@ int sciprint2(va_alist) va_dcl
   iv = va_arg(ap,int);
   fmt = va_arg(ap, char *);
 #endif
-  /* next three lines added for diary SS*/
-  (void ) vsprintf(s_buf, fmt, ap );
-  lstr=strlen(s_buf);
 
   C2F(xscion)(&i);
   if (i == 0) 
@@ -732,18 +715,16 @@ int sciprint2(va_alist) va_dcl
     }
   else 
     {
-      /* Next two lines suppressed:see above SS
-	 retval= vsprintf(s_buf, fmt, ap );*/
+      retval= vsprintf(s_buf, fmt, ap );
+      lstr=strlen(s_buf);
       C2F(xscisncr)(s_buf,&lstr,0L);
     }
-  /* \r\n -> \n for diary */ 
-  if ( lstr >= 2 && s_buf[lstr-1]== '\n' && s_buf[lstr-2]== '\r') 
-    {
-      s_buf[lstr-2]= '\n';
-      s_buf[lstr-1]= '\0';
-      lstr--;
-    }
-  C2F(diary)(s_buf,&lstr,0L);
+  if (getdiary()) {
+    retval= vsprintf(s_buf, fmt, ap );
+    lstr=strlen(s_buf);
+    diary_nnl(s_buf,&lstr);
+  }
+
   va_end(ap);
   return retval;
 }
@@ -1250,7 +1231,7 @@ void Xputchar(c)
 
   case CASE_OSC:
     /* Operating System Command: ESC ] */
-    do_osc((osc_func) in_put());
+    do_osc((osc_func) in_put(0));
     parsestate = groundtable;
     break;
 
@@ -1338,7 +1319,27 @@ static int pty_read_bytes;
   
 ************************************************************************/
    
-extern int ctrl_action();
+static int ctrl_action(int i)
+{
+  int j = SIGINT;
+  if(iscntrl(i) ) {
+    /* stroke is line editing command */
+    switch(i) {
+    case CTRL_C:
+	/* fprintf(stderr,"zzledt1 : CTRL_C\n"); */
+	C2F(sigbas)(&j);
+	return(1);
+	break;
+    case CTRL_Z:
+	/* doesn't work on sun4 */
+	fprintf(stderr,"zzledt1 : CTRL_Z\n");
+	return(1);
+	break;
+      };
+  };
+  return(0);
+}
+
 
 
 void xevents1()
@@ -1368,7 +1369,7 @@ void xevents1()
  * returns a char and deal with events 
  ****************************************/
 
-int in_put()
+int in_put(int interrupt)
 {
   register TScreen *screen = &term->screen;
   register int i;
@@ -1398,6 +1399,9 @@ int in_put()
       cok = 0;
       break;
     }
+    /* escape if we accept input interruption and an event had been detected */
+    if (interrupt&&(C2F(ismenu)()==1)) return(-1);
+
     pty_read_bytes = 0;
     /* update the screen */
     if (screen->scroll_amt)
@@ -2247,7 +2251,7 @@ void VTInit1(parent)
   XtOverrideTranslations(parent, XtParseTranslationTable(xterm_trans));
   (void) XSetWMProtocols(XtDisplay(parent), XtWindow(parent),
 			 &wm_delete_window, 1);
-  set_scilab_icon();
+  /*set_scilab_icon(); Old icon... no more used V.C. 04/02/2004*/
   size_hints.min_width = 400;
   size_hints.min_height = 300;
   size_hints.flags =  PMinSize;
@@ -3171,7 +3175,7 @@ void HandleSetFont(w, event, params, param_count)
       Bell();
       return;
     }
-    if (*param_count > maxparams)
+    if (*param_count > (Cardinal)maxparams)
     {				/* see if extra args given */
       Bell();
       return;
